from nicegui import ui
from biblemateweb.css.original import ORIGINAL_CSS
from biblemateweb.fx.bible import *
from biblemateweb.fx.original import *
from biblemateweb.js.sync_scrolling import *
import re


def original_interlinear(b=1, c=1, v=1, area=1, tab1=None, tab2=None, **_):

    # listen for custom event "luW"
    ui.on('luW', luW)
    ui.on('luV', luV)
    ui.on('lex', lex)
    ui.on('bdbid', bdbid)
    ui.on('etcbcmorph', etcbcmorph)
    ui.on('rmac', rmac)
    ui.on('searchWord', searchWord)
    ui.on('searchLexicalEntry', searchLexicalEntry)

    # Your provided HTML snippet [for TESTING only; only real data when deloy]
    hebrew_content = """<verse><vid id="v19.117.1" onclick="luV(1)">1</vid> <br><div class="int"><wform><heb id="wh331049" class="ch70320 GE70639 H1984" onclick="luW(1,'331049','70320','70639','verb.piel.impv.p2.m.pl','H1984')" onmouseover="hl1('h331049','h70320','E70639')" onmouseout="hl0('h331049','h70320','E70639')" ondblclick="searchWord(1,331049)">הַֽלְל֣וּ</heb></wform><br><wsbl>halû</wsbl><br><wphono>hˈallˈû</wphono><br><ref onclick="lex('E70639')" ondblclick="searchLexicalEntry('E70639')"><wlex><heb>הלל</heb></wlex></ref><br><ref onclick="etcbcmorph('verb.piel.impv.p2.m.pl')"><wmorph>verb.piel.impv.p2.m.pl</wmorph></ref><br><ref onclick="bdbid('H1984')"><wsn>H1984</wsn></ref><br><wgloss>[you]+ praise</wgloss><br><wtrans>Praise</wtrans></div><heb> </heb><div class="int"><wform><heb id="wh331050" class="ch70320 GE70005 H853" onclick="luW(1,'331050','70320','70005','prep','H853')" onmouseover="hl1('h331050','h70320','E70005')" onmouseout="hl0('h331050','h70320','E70005')" ondblclick="searchWord(1,331050)">אֶת</heb><heb>־</heb></wform><br><wsbl>ʾet</wsbl><br><wphono>ʔeṯ-</wphono><br><ref onclick="lex('E70005')" ondblclick="searchLexicalEntry('E70005')"><wlex><heb>אֵת</heb></wlex></ref><br><ref onclick="etcbcmorph('prep')"><wmorph>prep</wmorph></ref><br><ref onclick="bdbid('H853')"><wsn>H853</wsn></ref><br><wgloss>[object marker]</wgloss><br><wtrans></wtrans></div><div class="int"><wform><heb id="wh331051" class="ch70320 GE70113 H3068" onclick="luW(1,'331051','70320','70113','nmpr.m.sg.a','H3068')" onmouseover="hl1('h331051','h70320','E70113')" onmouseout="hl0('h331051','h70320','E70113')" ondblclick="searchWord(1,331051)">יְ֭הוָה</heb></wform><br><wsbl>[yhwāh]</wsbl><br><wphono>[ˈyhwāh]</wphono><br><ref onclick="lex('E70113')" ondblclick="searchLexicalEntry('E70113')"><wlex><heb>יְהוָה</heb></wlex></ref><br><ref onclick="etcbcmorph('nmpr.m.sg.a')"><wmorph>nmpr.m.sg.a</wmorph></ref><br><ref onclick="bdbid('H3068')"><wsn>H3068</wsn></ref><br><wgloss>YHWH</wgloss><br><wtrans>the LORD,</wtrans></div><heb> </heb><div class="int"><wform><heb id="wh331052" class="ch70321 GE70078 H3605" onclick="luW(1,'331052','70321','70078','subs.m.sg.c','H3605')" onmouseover="hl1('h331052','h70321','E70078')" onmouseout="hl0('h331052','h70321','E70078')" ondblclick="searchWord(1,331052)">כָּל</heb><heb>־</heb></wform><br><wsbl>kol</wsbl><br><wphono>kol-</wphono><br><ref onclick="lex('E70078')" ondblclick="searchLexicalEntry('E70078')"><wlex><heb>כֹּל</heb></wlex></ref><br><ref onclick="etcbcmorph('subs.m.sg.c')"><wmorph>subs.m.sg.c</wmorph></ref><br><ref onclick="bdbid('H3605')"><wsn>H3605</wsn></ref><br><wgloss>whole</wgloss><br><wtrans>all you</wtrans></div><div class="int"><wform><heb id="wh331053" class="ch70321 GE70500 H1471" onclick="luW(1,'331053','70321','70500','subs.m.pl.a','H1471')" onmouseover="hl1('h331053','h70321','E70500')" onmouseout="hl0('h331053','h70321','E70078')" ondblclick="searchWord(1,331053)">גֹּויִ֑ם</heb></wform><br><wsbl>gôyim</wsbl><br><wphono>gôyˈim</wphono><br><ref onclick="lex('E70500')" ondblclick="searchLexicalEntry('E70500')"><wlex><heb>גֹּוי</heb></wlex></ref><br><ref onclick="etcbcmorph('subs.m.pl.a')"><wmorph>subs.m.pl.a</wmorph></ref><br><ref onclick="bdbid('H1471')"><wsn>H1471</wsn></ref><br<wgloss>people</wgloss><br><wtrans>nations!</wtrans></div><heb> </heb><div class="int"><wform><heb id="wh331054" class="ch70322 GE76864 H7623" onclick="luW(1,'331054','70322','76864','verb.piel.impv.p2.m.pl.prs.p3.m.sg','H7623')" onmouseover="hl1('h331054','h70322','E76864')" onmouseout="hl0('h331054','h70322','E76864')" ondblclick="searchWord(1,331054)">שַׁ֝בְּח֗וּהוּ</heb></wform><br><wsbl>šabĕḥûhû</wsbl><br><wphono>ˈšabbᵊḥˈûhû</wphono><br><ref onclick="lex('E76864')" ondblclick="searchLexicalEntry('E76864')"><wlex><heb>שׁבח</heb></wlex></ref><br><ref onclick="etcbcmorph('verb.piel.impv.p2.m.pl.prs.p3.m.sg')"><wmorph>verb.piel.impv.p2.m.pl.prs.p3.m.sg</wmorph></ref><br><ref onclick="bdbid('H7623')"><wsn>H7623</wsn></ref><br><wgloss>[you]+ praise +[him]</wgloss><br><wtrans>Extol Him,</wtrans></div><heb> </heb><div class="int"><wform><heb id="wh331055" class="ch70323 GE70078 H3605" onclick="luW(1,'331055','70323','70078','subs.m.sg.c','H3605')" onmouseover="hl1('h331055','h70323','E70078')" onmouseout="hl0('h331055','h70323','E70078')" ondblclick="searchWord(1,331055)">כָּל</heb><heb>־</heb></wform><br><wsbl>kol</wsbl><br><wphono>kol-</wphono><br><ref onclick="lex('E70078')" ondblclick="searchLexicalEntry('E70078')"><wlex><heb>כֹּל</heb></wlex></ref><br><ref onclick="etcbcmorph('subs.m.sg.c')"><wmorph>subs.m.sg.c</wmorph></ref><br><ref onclick="bdbid('H3605')"><wsn>H3605</wsn></ref><br><wgloss>whole</wgloss><br><wtrans>all you</wtrans></div><div class="int"><wform><heb id="wh331056" class="ch70323 GE70006 H9009" onclick="luW(1,'331056','70323','70006','art','H9009')" onmouseover="hl1('h331056','h70323','E70006')" onmouseout="hl0('h331056','h70323','E70006')" ondblclick="searchWord(1,331056)">הָ</heb><heb></heb></wform><br><wsbl>hā</wsbl><br><wphono>hā</wphono><br><ref onclick="lex('E70006')" ondblclick="searchLexicalEntry('E70006')"><wlex><heb>הַ</heb></wlex></ref><br><ref onclick="etcbcmorph('art')"><wmorph>art</wmorph></ref><br><ref onclick="bdbid('H9009')"><wsn>H9009</wsn></ref><br><wgloss>the</wgloss><br><wtrans></wtrans></div><div class="int"><wform><heb id="wh331057" class="ch70323 GE71088 H523" onclick="luW(1,'331057','70323','71088','subs.f.pl.a','H523')" onmouseover="hl1('h331057','h70323','E71088')" onmouseout="hl0('h331057','h70323','E71088')" ondblclick="searchWord(1,331057)">אֻמִּֽים</heb><heb>׃</heb></wform><br><wsbl>ʾumîm</wsbl><br><wphono>ʔummˈîm</wphono><br><ref onclick="lex('E71088')" ondblclick="searchLexicalEntry('E71088')"><wlex><heb>אֻמָּה</heb></wlex></ref><br><ref onclick="etcbcmorph('subs.f.pl.a')"><wmorph>subs.f.pl.a</wmorph></ref><br><ref onclick="bdbid('H523')"><wsn>H523</wsn></ref><br><wgloss>clan</wgloss><br><wtrans>peoples!</wtrans></div><heb> </heb><br></verse> <verse><vid id="v19.117.2" onclick="luV(2)">2</vid> <br><div class="int"><wform><heb id="wh331058" class="ch70324 GE70023 H3588" onclick="luW(2,'331058','70324','70023','conj','H3588')" onmouseover="hl1('h331058','h70324','E70023')" onmouseout="hl0('h331058','h70324','E70023')" ondblclick="searchWord(1,331058)">כִּ֥י</heb></wform><br><wsbl>kî</wsbl><br><wphono>kˌî</wphono><br><ref onclick="lex('E70023')" ondblclick="searchLexicalEntry('E70023')"><wlex><heb>כִּי</heb></wlex></ref><br><ref onclick="etcbcmorph('conj')"><wmorph>conj</wmorph></ref><br><ref onclick="bdbid('H3588')"><wsn>H3588</wsn></ref><br><wgloss>that</wgloss><br><wtrans>For</wtrans></div><heb> </heb><div class="int"><wform><heb id="wh331059" class="ch70324 GE70414 H1396" onclick="luW(2,'331059','70324','70414','verb.qal.perf.p3.m.sg','H1396')" onmouseover="hl1('h331059','h70324','E70414')" onmouseout="hl0('h331059','h70324','E70414')" ondblclick="searchWord(1,331059)">גָ֘בַ֤ר</heb></wform><br><wsbl>gābar</wsbl><br><wphono>ḡˈāvˈar</wphono><br><ref onclick="lex('E70414')" ondblclick="searchLexicalEntry('E70414')"><wlex><heb>גבר</heb></wlex></ref><br><ref onclick="etcbcmorph('verb.qal.perf.p3.m.sg')"><wmorph>verb.qal.perf.p3.m.sg</wmorph></ref><br><ref onclick="bdbid('H1396')"><wsn>H1396</wsn></ref><br><wgloss>[he]+ be superior</wgloss><br><wtrans>great is</wtrans></div><heb> </heb><div class="int"><wform><heb id="wh331060" class="ch70324 GE70014 H5921" onclick="luW(2,'331060','70324','70014','prep.prs.p1.u.pl','H5921')" onmouseover="hl1('h331060','h70324','E70014')" onmouseout="hl0('h331060','h70324','E70014')" ondblclick="searchWord(1,331060)">עָלֵ֨ינוּ</heb><heb>׀</heb></wform><br><wsbl>ʿālêynû</wsbl><br><wphono>ʕālˌênû</wphono><br><ref onclick="lex('E70014')" ondblclick="searchLexicalEntry('E70014')"><wlex><heb>עַל</heb></wlex></ref><br><ref onclick="etcbcmorph('prep.prs.p1.u.pl')"><wmorph>prep.prs.p1.u.pl</wmorph></ref><br><ref onclick="bdbid('H5921')"><wsn>H5921</wsn></ref><br><wgloss>upon +[us]</wgloss><br><wtrans>to us,</wtrans></div><heb> </heb><div class="int"><wform><heb id="wh331061" class="ch70324 GE70897 H2617" onclick="luW(2,'331061','70324','70897','subs.m.sg.a.prs.p3.m.sg','H2617')" onmouseover="hl1('h331061','h70324','E70897')" onmouseout="hl0('h331061','h70324','E70897')" ondblclick="searchWord(1,331061)">חַסְדֹּ֗ו</heb></wform><br><wsbl>ḥasdô</wsbl><br><wphono>ḥasdˈô</wphono><br><ref onclick="lex('E70897')" ondblclick="searchLexicalEntry('E70897')"><wlex><heb>חֶסֶד</heb></wlex></ref><br><ref onclick="etcbcmorph('subs.m.sg.a.prs.p3.m.sg')"><wmorph>subs.m.sg.a.prs.p3.m.sg</wmorph></ref><br><ref onclick="bdbid('H2617')"><wsn>H2617</wsn></ref><br><wgloss>+[his] loyalty</wgloss><br><wtrans>His loving devotion</wtrans></div><heb> </heb><div class="int"><wform><heb id="wh331062" class="ch70325 GE70008 H9000" onclick="luW(2,'331062','70325','70008','conj','H9000')" onmouseover="hl1('h331062','h70325','E70008')" onmouseout="hl0('h331062','h70325','E70008')" ondblclick="searchWord(1,331062)">וֶֽ</heb><heb></heb></wform><br><wsbl>we</wsbl><br><wphono>wˈe</wphono><br><ref onclick="lex('E70008')" ondblclick="searchLexicalEntry('E70008')"><wlex><heb>וְ</heb></wlex></ref><br><ref onclick="etcbcmorph('conj')"><wmorph>conj</wmorph></ref><br><ref onclick="bdbid('H9000')"><wsn>H9000</wsn></ref><br><wgloss>and</wgloss><br><wtrans>and</wtrans></div><div class="int"><wform><heb id="wh331063" class="ch70325 GE71035 H571" onclick="luW(2,'331063','70325','71035','subs.f.sg.c','H571')" onmouseover="hl1('h331063','h70325','E71035')" onmouseout="hl0('h331063','h70325','E71035')" ondblclick="searchWord(1,331063)">אֱמֶת</heb><heb>־</heb></wform><br><wsbl>ʾĕmet</wsbl><br><wphono>ʔᵉmeṯ-</wphono><br><ref onclick="lex('E71035')" ondblclick="searchLexicalEntry('E71035')"><wlex><heb>אֶמֶת</heb></wlex></ref><br><ref onclick="etcbcmorph('subs.f.sg.c')"><wmorph>subs.f.sg.c</wmorph></ref><br><ref onclick="bdbid('H571')"><wsn>H571</wsn></ref><br><wgloss>trustworthiness</wgloss><br><wtrans>the faithfulness</wtrans></div><div class="int"><wform><heb id="wh331064" class="ch70325 GE70113 H3068" onclick="luW(2,'331064','70325','70113','nmpr.m.sg.a','H3068')" onmouseover="hl1('h331064','h70325','E70113')" onmouseout="hl0('h331064','h70325','E70113')" ondblclick="searchWord(1,331064)">יְהוָ֥ה</heb></wform><br><wsbl>[yĕhwāh]</wsbl><br><wphono>[yᵊhwˌāh]</wphono><br><ref onclick="lex('E70113')" ondblclick="searchLexicalEntry('E70113')"><wlex><heb>יְהוָה</heb></wlex></ref><br><ref onclick="etcbcmorph('nmpr.m.sg.a')"><wmorph>nmpr.m.sg.a</wmorph></ref><br><ref onclick="bdbid('H3068')"><wsn>H3068</wsn></ref><br><wgloss>YHWH</wgloss><br><wtrans>of the LORD</wtrans></div><heb> </heb><div class="int"><wform><heb id="wh331065" class="ch70325 GE70028 H9005" onclick="luW(2,'331065','70325','70028','prep','H9005')" onmouseover="hl1('h331065','h70325','E70028')" onmouseout="hl0('h331065','h70325','E70028')" ondblclick="searchWord(1,331065)">לְ</heb><heb></heb></wform><br<wsbl>lĕ</wsbl><br><wphono>lᵊ</wphono><br><ref onclick="lex('E70028')" ondblclick="searchLexicalEntry('E70028')"><wlex><heb>לְ</heb></wlex></ref><br><ref onclick="etcbcmorph('prep')"><wmorph>prep</wmorph></ref><br><ref onclick="bdbid('H9005')"><wsn>H9005</wsn></ref><br><wgloss>to</wgloss><br><wtrans></wtrans></div><div class="int"><wform><heb id="wh331066" class="ch70325 GE70253 H5769" onclick="luW(2,'331066','70325','70253','subs.m.sg.a','H5769')" onmouseover="hl1('h331066','h70325','E70253')" onmouseout="hl0('h331066','h70325','E70253')" ondblclick="searchWord(1,331066)">עֹולָ֗ם</heb></wform><br><wsbl>ʿôlām</wsbl><br><wphono>ʕôlˈām</wphono><br><ref onclick="lex('E70253')" ondblclick="searchLexicalEntry('E70253')"><wlex><heb>עֹולָם</heb></wlex></ref><br><ref onclick="etcbcmorph('subs.m.sg.a')"><wmorph>subs.m.sg.a</wmorph></ref><br><ref onclick="bdbid('H5769')"><wsn>H5769</wsn></ref><br><wgloss>eternity</wgloss><br><wtrans>endures forever.</wtrans></div><heb> </heb><div class="int"><wform><heb id="wh331067" class="ch70326 GE70639 H1984" onclick="luW(2,'331067','70326','70639','verb.piel.impv.p2.m.pl','H1984')" onmouseover="hl1('h331067','h70326','E70639')" onmouseout="hl0('h331067','h70326','E70639')" ondblclick="searchWord(1,331067)">הַֽלְלוּ</heb><heb>־</heb></wform><br><wsbl>halû</wsbl><br><wphono>hˈallû-</wphono><br><ref onclick="lex('E70639')" ondblclick="searchLexicalEntry('E70639')"><wlex><heb>הלל</heb></wlex></ref><br><ref onclick="etcbcmorph('verb.piel.impv.p2.m.pl')"><wmorph>verb.piel.impv.p2.m.pl</wmorph></ref><br><ref onclick="bdbid('H1984')"><wsn>H1984</wsn></ref><br><wgloss>[you]+ praise</wgloss><br><wtrans>Hallelujah!</wtrans></div><div class="int"><wform><heb id="wh331068" class="ch70326 GE72038 H3050" onclick="luW(2,'331068','70326','72038','nmpr.m.sg.a','H3050')" onmouseover="hl1('h331068','h70326','E72038')" onmouseout="hl0('h331068','h70326','E72038')" ondblclick="searchWord(1,331068)">יָֽהּ</heb><heb>׃</heb></wform><br><wsbl>yāh</wsbl><br><wphono>yˈāh</wphono><br><ref onclick="lex('E72038')" ondblclick="searchLexicalEntry('E72038')"><wlex><heb>יָהּ</heb></wlex></ref><br><ref onclick="etcbcmorph('nmpr.m.sg.a')"><wmorph>nmpr.m.sg.a</wmorph></ref><br><ref onclick="bdbid('H3050')"><wsn>H3050</wsn></ref><br><wgloss>the Lord</wgloss><br><wtrans></wtrans></div><heb> </heb><br></verse>"""

    greek_content = """<verse><vid id="v63.1.1" onclick="luV(1)">1</vid> <br><div class='int'><wform><grk id="w127242" cl='c24856' sn='G3588' morph='T-NSM' class="c24856 G3588" onclick="luW(1,'127242','24856','3588','T-NSM')" onmouseover="hl1('127242','24856','3588')" onmouseout="hl0('127242','24856','3588')" ondblclick="searchWord(2,127242)">Ὁ</grk></wform><br><wsbl>Ho</wsbl><br><wphono>o</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-NSM')"><wmorph>T-NSM</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>The</wtrans></div> <div class='int'><wform><grk id="w127243" cl='c24856' sn='G4245' morph='A-NSM' class="c24856 G4245" onclick="luW(1,'127243','24856','4245','A-NSM')" onmouseover="hl1('127243','24856','4245')" onmouseout="hl0('127243','24856','4245')" ondblclick="searchWord(2,127243)">πρεσβύτερος</grk></wform><br><wsbl>presbyteros</wsbl><br><wphono>prezviyteros</wphono><br><ref onclick="lex('G4245')" ondblclick="searchLexicalEntry('G4245')"><wlex><grk>πρεσβύτερος</grk></wlex></ref><br><ref onclick="rmac('A-NSM')"><wmorph>A-NSM</wmorph></ref><br><ref onclick="lex('G4245')" ondblclick="searchLexicalEntry('G4245')"><wsn>G4245</wsn></ref><br><wgloss>elder</wgloss><br><wtrans>elder,</wtrans></div> <div class='int'><wform><grk id="w127244" cl='c24856' sn='G1588' morph='A-DSF' class="c24856 G1588" onclick="luW(1,'127244','24856','1588','A-DSF')" onmouseover="hl1('127244','24856','1588')" onmouseout="hl0('127244','24856','1588')" ondblclick="searchWord(2,127244)">Ἐκλεκτῇ</grk></wform><br><wsbl>Eklektē</wsbl><br><wphono>eklektiy</wphono><br><ref onclick="lex('G1588')" ondblclick="searchLexicalEntry('G1588')"><wlex><grk>ἐκλεκτός</grk></wlex></ref><br><ref onclick="rmac('A-DSF')"><wmorph>A-DSF</wmorph></ref><br><ref onclick="lex('G1588')" ondblclick="searchLexicalEntry('G1588')"><wsn>G1588</wsn></ref><br><wgloss>select</wgloss><br><wtrans>To [the] elect</wtrans></div> <div class='int'><wform><grk id="w127245" cl='c24856' sn='G2959' morph='N-DSF' class="c24856 G2959" onclick="luW(1,'127245','24856','2959','N-DSF')" onmouseover="hl1('127245','24856','2959')" onmouseout="hl0('127245','24856','2959')" ondblclick="searchWord(2,127245)">κυρίᾳ</grk></wform><br><wsbl>kyria</wsbl><br><wphono>kiyriya</wphono><br><ref onclick="lex('G2959')" ondblclick="searchLexicalEntry('G2959')"><wlex><grk>Κυρία</grk></wlex></ref><br><ref onclick="rmac('N-DSF')"><wmorph>N-DSF</wmorph></ref><br><ref onclick="lex('G2959')" ondblclick="searchLexicalEntry('G2959')"><wsn>G2959</wsn></ref><br><wgloss>lady</wgloss><br><wtrans>lady</wtrans></div> <div class='int'><wform><grk id="w127246" cl='c24856' sn='G2532' morph='CONJ' class="c24856 G2532" onclick="luW(1,'127246','24856','2532','CONJ')" onmouseover="hl1('127246','24856','2532')" onmouseout="hl0('127246','24856','2532')" ondblclick="searchWord(2,127246)">καὶ</grk></wform><br><wsbl>kai</wsbl><br><wphono>ke</wphono><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wlex><grk>καί</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wsn>G2532</wsn></ref><br><wgloss>and</wgloss><br><wtrans>and</wtrans></div> <div class='int'><wform><grk id="w127247" cl='c24856' sn='G3588' morph='T-DPN' class="c24856 G3588" onclick="luW(1,'127247','24856','3588','T-DPN')" onmouseover="hl1('127247','24856','3588')" onmouseout="hl0('127247','24856','3588')" ondblclick="searchWord(2,127247)">τοῖς</grk></wform><br><wsbl>tois</wsbl><br><wphono>tiys</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-DPN')"><wmorph>T-DPN</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127248" cl='c24856' sn='G5043' morph='N-DPN' class="c24856 G5043" onclick="luW(1,'127248','24856','5043','N-DPN')" onmouseover="hl1('127248','24856','5043')" onmouseout="hl0('127248','24856','5043')" ondblclick="searchWord(2,127248)">τέκνοις</grk></wform><br><wsbl>teknois</wsbl><br><wphono>tekniys</wphono><br><ref onclick="lex('G5043')" ondblclick="searchLexicalEntry('G5043')"><wlex><grk>τέκνον</grk></wlex></ref><br><ref onclick="rmac('N-DPN')"><wmorph>N-DPN</wmorph></ref><br><ref onclick="lex('G5043')" ondblclick="searchLexicalEntry('G5043')"><wsn>G5043</wsn></ref><br><wgloss>child</wgloss><br><wtrans>children</wtrans></div> <div class='int'><wform><grk id="w127249" cl='c24856' sn='G846' morph='P-GSF' class="c24856 G846" onclick="luW(1,'127249','24856','846','P-GSF')" onmouseover="hl1('127249','24856','846')" onmouseout="hl0('127249','24856','846')" ondblclick="searchWord(2,127249)">αὐτῆς</grk></wform><br><wsbl>autēs</wsbl><br><wphono>aftiys</wphono><br><ref onclick="lex('G846')" ondblclick="searchLexicalEntry('G846')"><wlex><grk>αὐτός</grk></wlex></ref><br><ref onclick="rmac('P-GSF')"><wmorph>P-GSF</wmorph></ref><br><ref onclick="lex('G846')" ondblclick="searchLexicalEntry('G846')"><wsn>G846</wsn></ref><br><wgloss>he/she/it/self</wgloss><br><wtrans>of her,</wtrans></div> <div class='int'><wform><grk id="w127250" cl='c24857' sn='G3739' morph='R-APM' class="c24857 G3739" onclick="luW(1,'127250','24857','3739','R-APM')" onmouseover="hl1('127250','24857','3739')" onmouseout="hl0('127250','24857','3739')" ondblclick="searchWord(2,127250)">οὓς</grk></wform><br><wsbl>hous</wsbl><br><wphono>us</wphono><br><ref onclick="lex('G3739')" ondblclick="searchLexicalEntry('G3739')"><wlex><grk>ὅς, ἥ</grk></wlex></ref><br><ref onclick="rmac('R-APM')"><wmorph>R-APM</wmorph></ref><br><ref onclick="lex('G3739')" ondblclick="searchLexicalEntry('G3739')"><wsn>G3739</wsn></ref><br><wgloss>which</wgloss><br><wtrans>whom</wtrans></div> <div class='int'><wform><grk id="w127251" cl='c24857' sn='G1473' morph='P-1NS' class="c24857 G1473" onclick="luW(1,'127251','24857','1473','P-1NS')" onmouseover="hl1('127251','24857','1473')" onmouseout="hl0('127251','24857','1473')" ondblclick="searchWord(2,127251)">ἐγὼ</grk></wform><br><wsbl>egō</wsbl><br><wphono>ego</wphono><br><ref onclick="lex('G1473')" ondblclick="searchLexicalEntry('G1473')"><wlex><grk>ἐγώ</grk></wlex></ref><br><ref onclick="rmac('P-1NS')"><wmorph>P-1NS</wmorph></ref><br><ref onclick="lex('G1473')" ondblclick="searchLexicalEntry('G1473')"><wsn>G1473</wsn></ref><br><wgloss>I/we</wgloss><br><wtrans>I</wtrans></div> <div class='int'><wform><grk id="w127252" cl='c24857' sn='G25' morph='V-PAI-1S' class="c24857 G25" onclick="luW(1,'127252','24857','25','V-PAI-1S')" onmouseover="hl1('127252','24857','25')" onmouseout="hl0('127252','24857','25')" ondblclick="searchWord(2,127252)">ἀγαπῶ</grk></wform><br><wsbl>agapō</wsbl><br><wphono>agapo</wphono><br><ref onclick="lex('G25')" ondblclick="searchLexicalEntry('G25')"><wlex><grk>ἀγαπάω</grk></wlex></ref><br><ref onclick="rmac('V-PAI-1S')"><wmorph>V-PAI-1S</wmorph></ref><br><ref onclick="lex('G25')" ondblclick="searchLexicalEntry('G25')"><wsn>G25</wsn></ref><br><wgloss>to love</wgloss><br><wtrans>love</wtrans></div> <div class='int'><wform><grk id="w127253" cl='c24857' sn='G1722' morph='PREP' class="c24857 G1722" onclick="luW(1,'127253','24857','1722','PREP')" onmouseover="hl1('127253','24857','1722')" onmouseout="hl0('127253','24857','1722')" ondblclick="searchWord(2,127253)">ἐν</grk></wform><br><wsbl>en</wsbl><br><wphono>en</wphono><br><ref onclick="lex('G1722')" ondblclick="searchLexicalEntry('G1722')"><wlex><grk>ἐν</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G1722')" ondblclick="searchLexicalEntry('G1722')"><wsn>G1722</wsn></ref><br><wgloss>in/on/among</wgloss><br><wtrans>in</wtrans></div> <div class='int'><wform><grk id="w127254" cl='c24857' sn='G225' morph='N-DSF' class="c24857 G225" onclick="luW(1,'127254','24857','225','N-DSF')" onmouseover="hl1('127254','24857','225')" onmouseout="hl0('127254','24857','225')" ondblclick="searchWord(2,127254)">ἀληθείᾳ</grk></wform><br><wsbl>alētheia</wsbl><br><wphono>aliyθiya</wphono><br><ref onclick="lex('G225')" ondblclick="searchLexicalEntry('G225')"><wlex><grk>ἀλήθεια</grk></wlex></ref><br><ref onclick="rmac('N-DSF')"><wmorph>N-DSF</wmorph></ref><br><ref onclick="lex('G225')" ondblclick="searchLexicalEntry('G225')"><wsn>G225</wsn></ref><br><wgloss>truth</wgloss><br><wtrans>truth,</wtrans></div> <div class='int'><wform><grk id="w127255" cl='c24858' sn='G2532' morph='CONJ' class="c24858 G2532" onclick="luW(1,'127255','24858','2532','CONJ')" onmouseover="hl1('127255','24858','2532')" onmouseout="hl0('127255','24858','2532')" ondblclick="searchWord(2,127255)">καὶ</grk></wform><br><wsbl>kai</wsbl><br><wphono>ke</wphono><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wlex><grk>καί</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wsn>G2532</wsn></ref><br><wgloss>and</wgloss><br><wtrans>and</wtrans></div> <div class='int'><wform><grk id="w127256" cl='c24858' sn='G3756' morph='PRT-N' class="c24858 G3756" onclick="luW(1,'127256','24858','3756','PRT-N')" onmouseover="hl1('127256','24858','3756')" onmouseout="hl0('127256','24858','3756')" ondblclick="searchWord(2,127256)">οὐκ</grk></wform><br><wsbl>ouk</wsbl><br><wphono>uk</wphono><br><ref onclick="lex('G3756')" ondblclick="searchLexicalEntry('G3756')"><wlex><grk>οὐ</grk></wlex></ref><br><ref onclick="rmac('PRT-N')"><wmorph>PRT-N</wmorph></ref><br><ref onclick="lex('G3756')" ondblclick="searchLexicalEntry('G3756')"><wsn>G3756</wsn></ref><br><wgloss>no</wgloss><br><wtrans>not</wtrans></div> <div class='int'><wform><grk id="w127257" cl='c24858' sn='G1473' morph='P-1NS' class="c24858 G1473" onclick="luW(1,'127257','24858','1473','P-1NS')" onmouseover="hl1('127257','24858','1473')" onmouseout="hl0('127257','24858','1473')" ondblclick="searchWord(2,127257)">ἐγὼ</grk></wform><br><wsbl>egō</wsbl><br><wphono>ego</wphono><br><ref onclick="lex('G1473')" ondblclick="searchLexicalEntry('G1473')"><wlex><grk>ἐγώ</grk></wlex></ref><br><ref onclick="rmac('P-1NS')"><wmorph>P-1NS</wmorph></ref><br><ref onclick="lex('G1473')" ondblclick="searchLexicalEntry('G1473')"><wsn>G1473</wsn></ref><br><wgloss>I/we</wgloss><br><wtrans>I</wtrans></div> <div class='int'><wform><grk id="w127258" cl='c24858' sn='G3441' morph='A-NSM' class="c24858 G3441" onclick="luW(1,'127258','24858','3441','A-NSM')" onmouseover="hl1('127258','24858','3441')" onmouseout="hl0('127258','24858','3441')" ondblclick="searchWord(2,127258)">μόνος</grk></wform><br><wsbl>monos</wsbl><br><wphono>monos</wphono><br><ref onclick="lex('G3441')" ondblclick="searchLexicalEntry('G3441')"><wlex><grk>μόνος</grk></wlex></ref><br><ref onclick="rmac('A-NSM')"><wmorph>A-NSM</wmorph></ref><br><ref onclick="lex('G3441')" ondblclick="searchLexicalEntry('G3441')"><wsn>G3441</wsn></ref><br><wgloss>alone</wgloss><br><wtrans>only,</wtrans></div> <div class='int'><wform><grk id="w127259" cl='c24859' sn='G235' morph='CONJ' class="c24859 G235" onclick="luW(1,'127259','24859','235','CONJ')" onmouseover="hl1('127259','24859','235')" onmouseout="hl0('127259','24859','235')" ondblclick="searchWord(2,127259)">ἀλλὰ</grk></wform><br><wsbl>alla</wsbl><br><wphono>alla</wphono><br><ref onclick="lex('G235')" ondblclick="searchLexicalEntry('G235')"><wlex><grk>ἀλλά</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G235')" ondblclick="searchLexicalEntry('G235')"><wsn>G235</wsn></ref><br><wgloss>but</wgloss><br><wtrans>but</wtrans></div> <div class='int'><wform><grk id="w127260" cl='c24859' sn='G2532' morph='CONJ' class="c24859 G2532" onclick="luW(1,'127260','24859','2532','CONJ')" onmouseover="hl1('127260','24859','2532')" onmouseout="hl0('127260','24859','2532')" ondblclick="searchWord(2,127260)">καὶ</grk></wform><br><wsbl>kai</wsbl><br><wphono>ke</wphono><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wlex><grk>καί</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wsn>G2532</wsn></ref><br><wgloss>and</wgloss><br><wtrans>also</wtrans></div> <div class='int'><wform><grk id="w127261" cl='c24859' sn='G3956' morph='A-NPM' class="c24859 G3956" onclick="luW(1,'127261','24859','3956','A-NPM')" onmouseover="hl1('127261','24859','3956')" onmouseout="hl0('127261','24859','3956')" ondblclick="searchWord(2,127261)">πάντες</grk></wform><br><wsbl>pantes</wsbl><br><wphono>pantes</wphono><br><ref onclick="lex('G3956')" ondblclick="searchLexicalEntry('G3956')"><wlex><grk>πᾶς</grk></wlex></ref><br><ref onclick="rmac('A-NPM')"><wmorph>A-NPM</wmorph></ref><br><ref onclick="lex('G3956')" ondblclick="searchLexicalEntry('G3956')"><wsn>G3956</wsn></ref><br><wgloss>all</wgloss><br><wtrans>all</wtrans></div> <div class='int'><wform><grk id="w127262" cl='c24859' sn='G3588' morph='T-NPM' class="c24859 G3588" onclick="luW(1,'127262','24859','3588','T-NPM')" onmouseover="hl1('127262','24859','3588')" onmouseout="hl0('127262','24859','3588')" ondblclick="searchWord(2,127262)">οἱ</grk></wform><br><wsbl>hoi</wsbl><br><wphono>iy</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-NPM')"><wmorph>T-NPM</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>those</wtrans></div> <div class='int'><wform><grk id="w127263" cl='c24859' sn='G1097' morph='V-RAP-NPM' class="c24859 G1097" onclick="luW(1,'127263','24859','1097','V-RAP-NPM')" onmouseover="hl1('127263','24859','1097')" onmouseout="hl0('127263','24859','1097')" ondblclick="searchWord(2,127263)">ἐγνωκότες</grk></wform><br><wsbl>egnōkotes</wsbl><br><wphono>egnokotes</wphono><br><ref onclick="lex('G1097')" ondblclick="searchLexicalEntry('G1097')"><wlex><grk>γινώσκω</grk></wlex></ref><br><ref onclick="rmac('V-RAP-NPM')"><wmorph>V-RAP-NPM</wmorph></ref><br><ref onclick="lex('G1097')" ondblclick="searchLexicalEntry('G1097')"><wsn>G1097</wsn></ref><br><wgloss>to know</wgloss><br><wtrans>having known</wtrans></div> <div class='int'><wform><grk id="w127264" cl='c24859' sn='G3588' morph='T-ASF' class="c24859 G3588" onclick="luW(1,'127264','24859','3588','T-ASF')" onmouseover="hl1('127264','24859','3588')" onmouseout="hl0('127264','24859','3588')" ondblclick="searchWord(2,127264)">τὴν</grk></wform><br><wsbl>tēn</wsbl><br><wphono>tiyn</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-ASF')"><wmorph>T-ASF</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127265" cl='c24859' sn='G225' morph='N-ASF' class="c24859 G225" onclick="luW(1,'127265','24859','225','N-ASF')" onmouseover="hl1('127265','24859','225')" onmouseout="hl0('127265','24859','225')" ondblclick="searchWord(2,127265)">ἀλήθειαν</grk></wform><br><wsbl>alētheian</wsbl><br><wphono>aliyθiyan</wphono><br><ref onclick="lex('G225')" ondblclick="searchLexicalEntry('G225')"><wlex><grk>ἀλήθεια</grk></wlex></ref><br><ref onclick="rmac('N-ASF')"><wmorph>N-ASF</wmorph></ref><br><ref onclick="lex('G225')" ondblclick="searchLexicalEntry('G225')"><wsn>G225</wsn></ref><br><wgloss>truth</wgloss><br><wtrans>truth —</wtrans></div><br></verse> <verse><vid id="v63.1.2" onclick="luV(2)">2</vid> <br><div class='int'><wform><grk id="w127266" cl='c24860' sn='G1223' morph='PREP' class="c24860 G1223" onclick="luW(2,'127266','24860','1223','PREP')" onmouseover="hl1('127266','24860','1223')" onmouseout="hl0('127266','24860','1223')" ondblclick="searchWord(2,127266)">διὰ</grk></wform><br><wsbl>dia</wsbl><br><wphono>ðiya</wphono><br><ref onclick="lex('G1223')" ondblclick="searchLexicalEntry('G1223')"><wlex><grk>διά</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G1223')" ondblclick="searchLexicalEntry('G1223')"><wsn>G1223</wsn></ref><br><wgloss>through/because of</wgloss><br><wtrans>because of</wtrans></div> <div class='int'><wform><grk id="w127267" cl='c24860' sn='G3588' morph='T-ASF' class="c24860 G3588" onclick="luW(2,'127267','24860','3588','T-ASF')" onmouseover="hl1('127267','24860','3588')" onmouseout="hl0('127267','24860','3588')" ondblclick="searchWord(2,127267)">τὴν</grk></wform><br><wsbl>tēn</wsbl><br><wphono>tiyn</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-ASF')"><wmorph>T-ASF</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127268" cl='c24860' sn='G225' morph='N-ASF' class="c24860 G225" onclick="luW(2,'127268','24860','225','N-ASF')" onmouseover="hl1('127268','24860','225')" onmouseout="hl0('127268','24860','225')" ondblclick="searchWord(2,127268)">ἀλήθειαν</grk></wform><br><wsbl>alētheian</wsbl><br><wphono>aliyθiyan</wphono><br><ref onclick="lex('G225')" ondblclick="searchLexicalEntry('G225')"><wlex><grk>ἀλήθεια</grk></wlex></ref><br><ref onclick="rmac('N-ASF')"><wmorph>N-ASF</wmorph></ref><br><ref onclick="lex('G225')" ondblclick="searchLexicalEntry('G225')"><wsn>G225</wsn></ref><br><wgloss>truth</wgloss><br><wtrans>truth</wtrans></div> <div class='int'><wform><grk id="w127269" cl='c24860' sn='G3588' morph='T-ASF' class="c24860 G3588" onclick="luW(2,'127269','24860','3588','T-ASF')" onmouseover="hl1('127269','24860','3588')" onmouseout="hl0('127269','24860','3588')" ondblclick="searchWord(2,127269)">τὴν</grk></wform><br><wsbl>tēn</wsbl><br><wphono>tiyn</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-ASF')"><wmorph>T-ASF</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>-</wtrans></div> <div class='int'><wform><grk id="w127270" cl='c24860' sn='G3306' morph='V-PAP-ASF' class="c24860 G3306" onclick="luW(2,'127270','24860','3306','V-PAP-ASF')" onmouseover="hl1('127270','24860','3306')" onmouseout="hl0('127270','24860','3306')" ondblclick="searchWord(2,127270)">μένουσαν</grk></wform><br><wsbl>menousan</wsbl><br><wphono>menusan</wphono><br><ref onclick="lex('G3306')" ondblclick="searchLexicalEntry('G3306')"><wlex><grk>μένω</grk></wlex></ref><br><ref onclick="rmac('V-PAP-ASF')"><wmorph>V-PAP-ASF</wmorph></ref><br><ref onclick="lex('G3306')" ondblclick="searchLexicalEntry('G3306')"><wsn>G3306</wsn></ref><br><wgloss>to stay</wgloss><br><wtrans>abiding</wtrans></div> <div class='int'><wform><grk id="w127271" cl='c24860' sn='G1722' morph='PREP' class="c24860 G1722" onclick="luW(2,'127271','24860','1722','PREP')" onmouseover="hl1('127271','24860','1722')" onmouseout="hl0('127271','24860','1722')" ondblclick="searchWord(2,127271)">ἐν</grk></wform><br><wsbl>en</wsbl><br><wphono>en</wphono><br><ref onclick="lex('G1722')" ondblclick="searchLexicalEntry('G1722')"><wlex><grk>ἐν</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G1722')" ondblclick="searchLexicalEntry('G1722')"><wsn>G1722</wsn></ref><br><wgloss>in/on/among</wgloss><br><wtrans>in</wtrans></div> <div class='int'><wform><grk id="w127272" cl='c24860' sn='G1473' morph='P-1DP' class="c24860 G1473" onclick="luW(2,'127272','24860','1473','P-1DP')" onmouseover="hl1('127272','24860','1473')" onmouseout="hl0('127272','24860','1473')" ondblclick="searchWord(2,127272)">ἡμῖν</grk></wform><br><wsbl>hēmin</wsbl><br><wphono>iymiyn</wphono><br><ref onclick="lex('G1473')" ondblclick="searchLexicalEntry('G1473')"><wlex><grk>ἐγώ</grk></wlex></ref><br><ref onclick="rmac('P-1DP')"><wmorph>P-1DP</wmorph></ref><br><ref onclick="lex('G1473')" ondblclick="searchLexicalEntry('G1473')"><wsn>G1473</wsn></ref><br><wgloss>I/we</wgloss><br><wtrans>us</wtrans></div> <div class='int'><wform><grk id="w127273" cl='c24861' sn='G2532' morph='CONJ' class="c24861 G2532" onclick="luW(2,'127273','24861','2532','CONJ')" onmouseover="hl1('127273','24861','2532')" onmouseout="hl0('127273','24861','2532')" ondblclick="searchWord(2,127273)">καὶ</grk></wform><br><wsbl>kai</wsbl><br><wphono>ke</wphono><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wlex><grk>καί</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wsn>G2532</wsn></ref><br><wgloss>and</wgloss><br><wtrans>and</wtrans></div> <div class='int'><wform><grk id="w127274" cl='c24861' sn='G3326' morph='PREP' class="c24861 G3326" onclick="luW(2,'127274','24861','3326','PREP')" onmouseover="hl1('127274','24861','3326')" onmouseout="hl0('127274','24861','3326')" ondblclick="searchWord(2,127274)">μεθ᾽</grk></wform><br><wsbl>meth</wsbl><br><wphono>meθ</wphono><br><ref onclick="lex('G3326')" ondblclick="searchLexicalEntry('G3326')"><wlex><grk>μετά</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G3326')" ondblclick="searchLexicalEntry('G3326')"><wsn>G3326</wsn></ref><br><wgloss>with/after</wgloss><br><wtrans>with</wtrans></div> <div class='int'><wform><grk id="w127275" cl='c24861' sn='G1473' morph='P-1GP' class="c24861 G1473" onclick="luW(2,'127275','24861','1473','P-1GP')" onmouseover="hl1('127275','24861','1473')" onmouseout="hl0('127275','24861','1473')" ondblclick="searchWord(2,127275)">ἡμῶν</grk></wform><br><wsbl>hēmōn</wsbl><br><wphono>iymon</wphono><br><ref onclick="lex('G1473')" ondblclick="searchLexicalEntry('G1473')"><wlex><grk>ἐγώ</grk></wlex></ref><br><ref onclick="rmac('P-1GP')"><wmorph>P-1GP</wmorph></ref><br><ref onclick="lex('G1473')" ondblclick="searchLexicalEntry('G1473')"><wsn>G1473</wsn></ref><br><wgloss>I/we</wgloss><br><wtrans>us</wtrans></div> <div class='int'><wform><grk id="w127276" cl='c24861' sn='G1510' morph='V-FDI-3S' class="c24861 G1510" onclick="luW(2,'127276','24861','1510','V-FDI-3S')" onmouseover="hl1('127276','24861','1510')" onmouseout="hl0('127276','24861','1510')" ondblclick="searchWord(2,127276)">ἔσται</grk></wform><br><wsbl>estai</wsbl><br><wphono>este</wphono><br><ref onclick="lex('G1510')" ondblclick="searchLexicalEntry('G1510')"><wlex><grk>εἰμί</grk></wlex></ref><br><ref onclick="rmac('V-FDI-3S')"><wmorph>V-FDI-3S</wmorph></ref><br><ref onclick="lex('G1510')" ondblclick="searchLexicalEntry('G1510')"><wsn>G1510</wsn></ref><br><wgloss>to be</wgloss><br><wtrans>that will be</wtrans></div> <div class='int'><wform><grk id="w127277" cl='c24861' sn='G1519' morph='PREP' class="c24861 G1519" onclick="luW(2,'127277','24861','1519','PREP')" onmouseover="hl1('127277','24861','1519')" onmouseout="hl0('127277','24861','1519')" ondblclick="searchWord(2,127277)">εἰς</grk></wform><br><wsbl>eis</wsbl><br><wphono>iys</wphono><br><ref onclick="lex('G1519')" ondblclick="searchLexicalEntry('G1519')"><wlex><grk>εἰς</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G1519')" ondblclick="searchLexicalEntry('G1519')"><wsn>G1519</wsn></ref><br><wgloss>toward</wgloss><br><wtrans>to</wtrans></div> <div class='int'><wform><grk id="w127278" cl='c24861' sn='G3588' morph='T-ASM' class="c24861 G3588" onclick="luW(2,'127278','24861','3588','T-ASM')" onmouseover="hl1('127278','24861','3588')" onmouseout="hl0('127278','24861','3588')" ondblclick="searchWord(2,127278)">τὸν</grk></wform><br><wsbl>ton</wsbl><br><wphono>ton</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-ASM')"><wmorph>T-ASM</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127279" cl='c24861' sn='G165' morph='N-ASM' class="c24861 G165" onclick="luW(2,'127279','24861','165','N-ASM')" onmouseover="hl1('127279','24861','165')" onmouseout="hl0('127279','24861','165')" ondblclick="searchWord(2,127279)">αἰῶνα</grk></wform><br><wsbl>aiōna</wsbl><br><wphono>eona</wphono><br><ref onclick="lex('G165')" ondblclick="searchLexicalEntry('G165')"><wlex><grk>αἰών</grk></wlex></ref><br><ref onclick="rmac('N-ASM')"><wmorph>N-ASM</wmorph></ref><br><ref onclick="lex('G165')" ondblclick="searchLexicalEntry('G165')"><wsn>G165</wsn></ref><br><wgloss>an age</wgloss><br><wtrans>age:</wtrans></div><br></verse> <verse><vid id="v63.1.3" onclick="luV(3)">3</vid> <br><div class='int'><wform><grk id="w127280" cl='c24862' sn='G1510' morph='V-FDI-3S' class="c24862 G1510" onclick="luW(3,'127280','24862','1510','V-FDI-3S')" onmouseover="hl1('127280','24862','1510')" onmouseout="hl0('127280','24862','1510')" ondblclick="searchWord(2,127280)">Ἔσται</grk></wform><br><wsbl>Estai</wsbl><br><wphono>este</wphono><br><ref onclick="lex('G1510')" ondblclick="searchLexicalEntry('G1510')"><wlex><grk>εἰμί</grk></wlex></ref><br><ref onclick="rmac('V-FDI-3S')"><wmorph>V-FDI-3S</wmorph></ref><br><ref onclick="lex('G1510')" ondblclick="searchLexicalEntry('G1510')"><wsn>G1510</wsn></ref><br><wgloss>to be</wgloss><br><wtrans>Will be</wtrans></div> <div class='int'><wform><grk id="w127281" cl='c24862' sn='G3326' morph='PREP' class="c24862 G3326" onclick="luW(3,'127281','24862','3326','PREP')" onmouseover="hl1('127281','24862','3326')" onmouseout="hl0('127281','24862','3326')" ondblclick="searchWord(2,127281)">μεθ᾽</grk></wform><br><wsbl>meth</wsbl><br><wphono>meθ</wphono><br><ref onclick="lex('G3326')" ondblclick="searchLexicalEntry('G3326')"><wlex><grk>μετά</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G3326')" ondblclick="searchLexicalEntry('G3326')"><wsn>G3326</wsn></ref><br><wgloss>with/after</wgloss><br><wtrans>with</wtrans></div> <div class='int'><wform><grk id="w127282" cl='c24862' sn='G1473' morph='P-1GP' class="c24862 G1473" onclick="luW(3,'127282','24862','1473','P-1GP')" onmouseover="hl1('127282','24862','1473')" onmouseout="hl0('127282','24862','1473')" ondblclick="searchWord(2,127282)">ἡμῶν</grk></wform><br><wsbl>hēmōn</wsbl><br><wphono>iymon</wphono><br><ref onclick="lex('G1473')" ondblclick="searchLexicalEntry('G1473')"><wlex><grk>ἐγώ</grk></wlex></ref><br><ref onclick="rmac('P-1GP')"><wmorph>P-1GP</wmorph></ref><br><ref onclick="lex('G1473')" ondblclick="searchLexicalEntry('G1473')"><wsn>G1473</wsn></ref><br><wgloss>I/we</wgloss><br><wtrans>us</wtrans></div> <div class='int'><wform><grk id="w127283" cl='c24862' sn='G5485' morph='N-NSF' class="c24862 G5485" onclick="luW(3,'127283','24862','5485','N-NSF')" onmouseover="hl1('127283','24862','5485')" onmouseout="hl0('127283','24862','5485')" ondblclick="searchWord(2,127283)">χάρις</grk></wform><br><wsbl>charis</wsbl><br><wphono>khariys</wphono><br><ref onclick="lex('G5485')" ondblclick="searchLexicalEntry('G5485')"><wlex><grk>χάρις</grk></wlex></ref><br><ref onclick="rmac('N-NSF')"><wmorph>N-NSF</wmorph></ref><br><ref onclick="lex('G5485')" ondblclick="searchLexicalEntry('G5485')"><wsn>G5485</wsn></ref><br><wgloss>grace</wgloss><br><wtrans>grace,</wtrans></div> <div class='int'><wform><grk id="w127284" cl='c24862' sn='G1656' morph='N-NSN' class="c24862 G1656" onclick="luW(3,'127284','24862','1656','N-NSN')" onmouseover="hl1('127284','24862','1656')" onmouseout="hl0('127284','24862','1656')" ondblclick="searchWord(2,127284)">ἔλεος</grk></wform><br><wsbl>eleos</wsbl><br><wphono>eleos</wphono><br><ref onclick="lex('G1656')" ondblclick="searchLexicalEntry('G1656')"><wlex><grk>ἔλεος</grk></wlex></ref><br><ref onclick="rmac('N-NSN')"><wmorph>N-NSN</wmorph></ref><br><ref onclick="lex('G1656')" ondblclick="searchLexicalEntry('G1656')"><wsn>G1656</wsn></ref><br><wgloss>mercy</wgloss><br><wtrans>mercy,</wtrans></div> <div class='int'><wform><grk id="w127285" cl='c24862' sn='G1515' morph='N-NSF' class="c24862 G1515" onclick="luW(3,'127285','24862','1515','N-NSF')" onmouseover="hl1('127285','24862','1515')" onmouseout="hl0('127285','24862','1515')" ondblclick="searchWord(2,127285)">εἰρήνη</grk></wform><br><wsbl>eirēnē</wsbl><br><wphono>iyriyniy</wphono><br><ref onclick="lex('G1515')" ondblclick="searchLexicalEntry('G1515')"><wlex><grk>εἰρήνη</grk></wlex></ref><br><ref onclick="rmac('N-NSF')"><wmorph>N-NSF</wmorph></ref><br><ref onclick="lex('G1515')" ondblclick="searchLexicalEntry('G1515')"><wsn>G1515</wsn></ref><br><wgloss>peace</wgloss><br><wtrans>[and] peace</wtrans></div> <div class='int'><wform><grk id="w127286" cl='c24862' sn='G3844' morph='PREP' class="c24862 G3844" onclick="luW(3,'127286','24862','3844','PREP')" onmouseover="hl1('127286','24862','3844')" onmouseout="hl0('127286','24862','3844')" ondblclick="searchWord(2,127286)">παρὰ</grk></wform><br><wsbl>para</wsbl><br><wphono>para</wphono><br><ref onclick="lex('G3844')" ondblclick="searchLexicalEntry('G3844')"><wlex><grk>παρά</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G3844')" ondblclick="searchLexicalEntry('G3844')"><wsn>G3844</wsn></ref><br><wgloss>from/with/beside</wgloss><br><wtrans>from</wtrans></div> <div class='int'><wform><grk id="w127287" cl='c24862' sn='G2316' morph='N-GSM' class="c24862 G2316" onclick="luW(3,'127287','24862','2316','N-GSM')" onmouseover="hl1('127287','24862','2316')" onmouseout="hl0('127287','24862','2316')" ondblclick="searchWord(2,127287)">Θεοῦ</grk></wform><br><wsbl>Theou</wsbl><br><wphono>θeu</wphono><br><ref onclick="lex('G2316')" ondblclick="searchLexicalEntry('G2316')"><wlex><grk>θεός</grk></wlex></ref><br><ref onclick="rmac('N-GSM')"><wmorph>N-GSM</wmorph></ref><br><ref onclick="lex('G2316')" ondblclick="searchLexicalEntry('G2316')"><wsn>G2316</wsn></ref><br><wgloss>God</wgloss><br><wtrans>God</wtrans></div> <div class='int'><wform><grk id="w127288" cl='c24862' sn='G3962' morph='N-GSM' class="c24862 G3962" onclick="luW(3,'127288','24862','3962','N-GSM')" onmouseover="hl1('127288','24862','3962')" onmouseout="hl0('127288','24862','3962')" ondblclick="searchWord(2,127288)">Πατρός</grk></wform><br><wsbl>Patros</wsbl><br><wphono>patros</wphono><br><ref onclick="lex('G3962')" ondblclick="searchLexicalEntry('G3962')"><wlex><grk>πατήρ</grk></wlex></ref><br><ref onclick="rmac('N-GSM')"><wmorph>N-GSM</wmorph></ref><br><ref onclick="lex('G3962')" ondblclick="searchLexicalEntry('G3962')"><wsn>G3962</wsn></ref><br><wgloss>father</wgloss><br><wtrans>[the] Father</wtrans></div> <div class='int'><wform><grk id="w127289" cl='c24863' sn='G2532' morph='CONJ' class="c24863 G2532" onclick="luW(3,'127289','24863','2532','CONJ')" onmouseover="hl1('127289','24863','2532')" onmouseout="hl0('127289','24863','2532')" ondblclick="searchWord(2,127289)">καὶ</grk></wform><br><wsbl>kai</wsbl><br><wphono>ke</wphono><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wlex><grk>καί</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wsn>G2532</wsn></ref><br><wgloss>and</wgloss><br><wtrans>and</wtrans></div> <div class='int'><wform><grk id="w127290" cl='c24863' sn='G3844' morph='PREP' class="c24863 G3844" onclick="luW(3,'127290','24863','3844','PREP')" onmouseover="hl1('127290','24863','3844')" onmouseout="hl0('127290','24863','3844')" ondblclick="searchWord(2,127290)">παρὰ</grk></wform><br><wsbl>para</wsbl><br><wphono>para</wphono><br><ref onclick="lex('G3844')" ondblclick="searchLexicalEntry('G3844')"><wlex><grk>παρά</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G3844')" ondblclick="searchLexicalEntry('G3844')"><wsn>G3844</wsn></ref><br><wgloss>from/with/beside</wgloss><br><wtrans>from</wtrans></div> <div class='int'><wform><grk id="w127291" cl='c24863' sn='G2424' morph='N-GSM-P' class="c24863 G2424" onclick="luW(3,'127291','24863','2424','N-GSM-P')" onmouseover="hl1('127291','24863','2424')" onmouseout="hl0('127291','24863','2424')" ondblclick="searchWord(2,127291)">Ἰησοῦ</grk></wform><br><wsbl>Iēsou</wsbl><br><wphono>iyiysu</wphono><br><ref onclick="lex('G2424')" ondblclick="searchLexicalEntry('G2424')"><wlex><grk>Ἰησοῦς</grk></wlex></ref><br><ref onclick="rmac('N-GSM-P')"><wmorph>N-GSM-P</wmorph></ref><br><ref onclick="lex('G2424')" ondblclick="searchLexicalEntry('G2424')"><wsn>G2424</wsn></ref><br><wgloss>Jesus/Joshua</wgloss><br><wtrans>Jesus</wtrans></div> <div class='int'><wform><grk id="w127292" cl='c24863' sn='G5547' morph='N-GSM-T' class="c24863 G5547" onclick="luW(3,'127292','24863','5547','N-GSM-T')" onmouseover="hl1('127292','24863','5547')" onmouseout="hl0('127292','24863','5547')" ondblclick="searchWord(2,127292)">Χριστοῦ</grk></wform><br><wsbl>Christou</wsbl><br><wphono>khriystu</wphono><br><ref onclick="lex('G5547')" ondblclick="searchLexicalEntry('G5547')"><wlex><grk>Χριστός</grk></wlex></ref><br><ref onclick="rmac('N-GSM-T')"><wmorph>N-GSM-T</wmorph></ref><br><ref onclick="lex('G5547')" ondblclick="searchLexicalEntry('G5547')"><wsn>G5547</wsn></ref><br><wgloss>Christ</wgloss><br><wtrans>Christ,</wtrans></div> <div class='int'><wform><grk id="w127293" cl='c24863' sn='G3588' morph='T-GSM' class="c24863 G3588" onclick="luW(3,'127293','24863','3588','T-GSM')" onmouseover="hl1('127293','24863','3588')" onmouseout="hl0('127293','24863','3588')" ondblclick="searchWord(2,127293)">τοῦ</grk></wform><br><wsbl>tou</wsbl><br><wphono>tu</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-GSM')"><wmorph>T-GSM</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127294" cl='c24863' sn='G5207' morph='N-GSM' class="c24863 G5207" onclick="luW(3,'127294','24863','5207','N-GSM')" onmouseover="hl1('127294','24863','5207')" onmouseout="hl0('127294','24863','5207')" ondblclick="searchWord(2,127294)">Υἱοῦ</grk></wform><br><wsbl>Huiou</wsbl><br><wphono>iyu</wphono><br><ref onclick="lex('G5207')" ondblclick="searchLexicalEntry('G5207')"><wlex><grk>υἱός</grk></wlex></ref><br><ref onclick="rmac('N-GSM')"><wmorph>N-GSM</wmorph></ref><br><ref onclick="lex('G5207')" ondblclick="searchLexicalEntry('G5207')"><wsn>G5207</wsn></ref><br><wgloss>son</wgloss><br><wtrans>Son</wtrans></div> <div class='int'><wform><grk id="w127295" cl='c24863' sn='G3588' morph='T-GSM' class="c24863 G3588" onclick="luW(3,'127295','24863','3588','T-GSM')" onmouseover="hl1('127295','24863','3588')" onmouseout="hl0('127295','24863','3588')" ondblclick="searchWord(2,127295)">τοῦ</grk></wform><br><wsbl>tou</wsbl><br><wphono>tu</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-GSM')"><wmorph>T-GSM</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>of the</wtrans></div> <div class='int'><wform><grk id="w127296" cl='c24863' sn='G3962' morph='N-GSM' class="c24863 G3962" onclick="luW(3,'127296','24863','3962','N-GSM')" onmouseover="hl1('127296','24863','3962')" onmouseout="hl0('127296','24863','3962')" ondblclick="searchWord(2,127296)">Πατρός</grk></wform><br><wsbl>Patros</wsbl><br><wphono>patros</wphono><br><ref onclick="lex('G3962')" ondblclick="searchLexicalEntry('G3962')"><wlex><grk>πατήρ</grk></wlex></ref><br><ref onclick="rmac('N-GSM')"><wmorph>N-GSM</wmorph></ref><br><ref onclick="lex('G3962')" ondblclick="searchLexicalEntry('G3962')"><wsn>G3962</wsn></ref><br><wgloss>father</wgloss><br><wtrans>Father,</wtrans></div> <div class='int'><wform><grk id="w127297" cl='c24863' sn='G1722' morph='PREP' class="c24863 G1722" onclick="luW(3,'127297','24863','1722','PREP')" onmouseover="hl1('127297','24863','1722')" onmouseout="hl0('127297','24863','1722')" ondblclick="searchWord(2,127297)">ἐν</grk></wform><br><wsbl>en</wsbl><br><wphono>en</wphono><br><ref onclick="lex('G1722')" ondblclick="searchLexicalEntry('G1722')"><wlex><grk>ἐν</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G1722')" ondblclick="searchLexicalEntry('G1722')"><wsn>G1722</wsn></ref><br><wgloss>in/on/among</wgloss><br><wtrans>in</wtrans></div> <div class='int'><wform><grk id="w127298" cl='c24863' sn='G225' morph='N-DSF' class="c24863 G225" onclick="luW(3,'127298','24863','225','N-DSF')" onmouseover="hl1('127298','24863','225')" onmouseout="hl0('127298','24863','225')" ondblclick="searchWord(2,127298)">ἀληθείᾳ</grk></wform><br><wsbl>alētheia</wsbl><br><wphono>aliyθiya</wphono><br><ref onclick="lex('G225')" ondblclick="searchLexicalEntry('G225')"><wlex><grk>ἀλήθεια</grk></wlex></ref><br><ref onclick="rmac('N-DSF')"><wmorph>N-DSF</wmorph></ref><br><ref onclick="lex('G225')" ondblclick="searchLexicalEntry('G225')"><wsn>G225</wsn></ref><br><wgloss>truth</wgloss><br><wtrans>truth</wtrans></div> <div class='int'><wform><grk id="w127299" cl='c24863' sn='G2532' morph='CONJ' class="c24863 G2532" onclick="luW(3,'127299','24863','2532','CONJ')" onmouseover="hl1('127299','24863','2532')" onmouseout="hl0('127299','24863','2532')" ondblclick="searchWord(2,127299)">καὶ</grk></wform><br><wsbl>kai</wsbl><br><wphono>ke</wphono><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wlex><grk>καί</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wsn>G2532</wsn></ref><br><wgloss>and</wgloss><br><wtrans>and</wtrans></div> <div class='int'><wform><grk id="w127300" cl='c24863' sn='G26' morph='N-DSF' class="c24863 G26" onclick="luW(3,'127300','24863','26','N-DSF')" onmouseover="hl1('127300','24863','26')" onmouseout="hl0('127300','24863','26')" ondblclick="searchWord(2,127300)">ἀγάπῃ</grk></wform><br><wsbl>agapē</wsbl><br><wphono>agapiy</wphono><br><ref onclick="lex('G26')" ondblclick="searchLexicalEntry('G26')"><wlex><grk>ἀγάπη</grk></wlex></ref><br><ref onclick="rmac('N-DSF')"><wmorph>N-DSF</wmorph></ref><br><ref onclick="lex('G26')" ondblclick="searchLexicalEntry('G26')"><wsn>G26</wsn></ref><br><wgloss>love</wgloss><br><wtrans>love.</wtrans></div><br></verse> <verse><vid id="v63.1.4" onclick="luV(4)">4</vid> <br><div class='int'><wform><grk id="w127301" cl='c24864' sn='G5463' morph='V-2AOI-1S' class="c24864 G5463" onclick="luW(4,'127301','24864','5463','V-2AOI-1S')" onmouseover="hl1('127301','24864','5463')" onmouseout="hl0('127301','24864','5463')" ondblclick="searchWord(2,127301)">Ἐχάρην</grk></wform><br><wsbl>Echarēn</wsbl><br><wphono>ekhariyn</wphono><br><ref onclick="lex('G5463')" ondblclick="searchLexicalEntry('G5463')"><wlex><grk>χαίρω</grk></wlex></ref><br><ref onclick="rmac('V-2AOI-1S')"><wmorph>V-2AOI-1S</wmorph></ref><br><ref onclick="lex('G5463')" ondblclick="searchLexicalEntry('G5463')"><wsn>G5463</wsn></ref><br><wgloss>to rejoice</wgloss><br><wtrans>I rejoiced</wtrans></div> <div class='int'><wform><grk id="w127302" cl='c24864' sn='G3029' morph='ADV' class="c24864 G3029" onclick="luW(4,'127302','24864','3029','ADV')" onmouseover="hl1('127302','24864','3029')" onmouseout="hl0('127302','24864','3029')" ondblclick="searchWord(2,127302)">λίαν</grk></wform><br><wsbl>lian</wsbl><br><wphono>liyan</wphono><br><ref onclick="lex('G3029')" ondblclick="searchLexicalEntry('G3029')"><wlex><grk>λίαν</grk></wlex></ref><br><ref onclick="rmac('ADV')"><wmorph>ADV</wmorph></ref><br><ref onclick="lex('G3029')" ondblclick="searchLexicalEntry('G3029')"><wsn>G3029</wsn></ref><br><wgloss>greatly</wgloss><br><wtrans>exceedingly</wtrans></div> <div class='int'><wform><grk id="w127303" cl='c24865' sn='G3754' morph='CONJ' class="c24865 G3754" onclick="luW(4,'127303','24865','3754','CONJ')" onmouseover="hl1('127303','24865','3754')" onmouseout="hl0('127303','24865','3754')" ondblclick="searchWord(2,127303)">ὅτι</grk></wform><br><wsbl>hoti</wsbl><br><wphono>otiy</wphono><br><ref onclick="lex('G3754')" ondblclick="searchLexicalEntry('G3754')"><wlex><grk>ὅτι</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G3754')" ondblclick="searchLexicalEntry('G3754')"><wsn>G3754</wsn></ref><br><wgloss>that/since</wgloss><br><wtrans>that</wtrans></div> <div class='int'><wform><grk id="w127304" cl='c24865' sn='G2147' morph='V-RAI-1S' class="c24865 G2147" onclick="luW(4,'127304','24865','2147','V-RAI-1S')" onmouseover="hl1('127304','24865','2147')" onmouseout="hl0('127304','24865','2147')" ondblclick="searchWord(2,127304)">εὕρηκα</grk></wform><br><wsbl>heurēka</wsbl><br><wphono>evriyka</wphono><br><ref onclick="lex('G2147')" ondblclick="searchLexicalEntry('G2147')"><wlex><grk>εὑρίσκω</grk></wlex></ref><br><ref onclick="rmac('V-RAI-1S')"><wmorph>V-RAI-1S</wmorph></ref><br><ref onclick="lex('G2147')" ondblclick="searchLexicalEntry('G2147')"><wsn>G2147</wsn></ref><br><wgloss>to find/meet</wgloss><br><wtrans>I have found</wtrans></div> <div class='int'><wform><grk id="w127305" cl='c24865' sn='G1537' morph='PREP' class="c24865 G1537" onclick="luW(4,'127305','24865','1537','PREP')" onmouseover="hl1('127305','24865','1537')" onmouseout="hl0('127305','24865','1537')" ondblclick="searchWord(2,127305)">ἐκ</grk></wform><br><wsbl>ek</wsbl><br><wphono>ek</wphono><br><ref onclick="lex('G1537')" ondblclick="searchLexicalEntry('G1537')"><wlex><grk>ἐκ</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G1537')" ondblclick="searchLexicalEntry('G1537')"><wsn>G1537</wsn></ref><br><wgloss>of/from</wgloss><br><wtrans>[some] of</wtrans></div> <div class='int'><wform><grk id="w127306" cl='c24865' sn='G3588' morph='T-GPN' class="c24865 G3588" onclick="luW(4,'127306','24865','3588','T-GPN')" onmouseover="hl1('127306','24865','3588')" onmouseout="hl0('127306','24865','3588')" ondblclick="searchWord(2,127306)">τῶν</grk></wform><br><wsbl>tōn</wsbl><br><wphono>ton</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-GPN')"><wmorph>T-GPN</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127307" cl='c24865' sn='G5043' morph='N-GPN' class="c24865 G5043" onclick="luW(4,'127307','24865','5043','N-GPN')" onmouseover="hl1('127307','24865','5043')" onmouseout="hl0('127307','24865','5043')" ondblclick="searchWord(2,127307)">τέκνων</grk></wform><br><wsbl>teknōn</wsbl><br><wphono>teknon</wphono><br><ref onclick="lex('G5043')" ondblclick="searchLexicalEntry('G5043')"><wlex><grk>τέκνον</grk></wlex></ref><br><ref onclick="rmac('N-GPN')"><wmorph>N-GPN</wmorph></ref><br><ref onclick="lex('G5043')" ondblclick="searchLexicalEntry('G5043')"><wsn>G5043</wsn></ref><br><wgloss>child</wgloss><br><wtrans>children</wtrans></div> <div class='int'><wform><grk id="w127308" cl='c24865' sn='G4771' morph='P-2GS' class="c24865 G4771" onclick="luW(4,'127308','24865','4771','P-2GS')" onmouseover="hl1('127308','24865','4771')" onmouseout="hl0('127308','24865','4771')" ondblclick="searchWord(2,127308)">σου</grk></wform><br><wsbl>sou</wsbl><br><wphono>su</wphono><br><ref onclick="lex('G4771')" ondblclick="searchLexicalEntry('G4771')"><wlex><grk>σύ</grk></wlex></ref><br><ref onclick="rmac('P-2GS')"><wmorph>P-2GS</wmorph></ref><br><ref onclick="lex('G4771')" ondblclick="searchLexicalEntry('G4771')"><wsn>G4771</wsn></ref><br><wgloss>you</wgloss><br><wtrans>of you</wtrans></div> <div class='int'><wform><grk id="w127309" cl='c24866' sn='G4043' morph='V-PAP-APM' class="c24866 G4043" onclick="luW(4,'127309','24866','4043','V-PAP-APM')" onmouseover="hl1('127309','24866','4043')" onmouseout="hl0('127309','24866','4043')" ondblclick="searchWord(2,127309)">περιπατοῦντας</grk></wform><br><wsbl>peripatountas</wsbl><br><wphono>periypatuntas</wphono><br><ref onclick="lex('G4043')" ondblclick="searchLexicalEntry('G4043')"><wlex><grk>περιπατέω</grk></wlex></ref><br><ref onclick="rmac('V-PAP-APM')"><wmorph>V-PAP-APM</wmorph></ref><br><ref onclick="lex('G4043')" ondblclick="searchLexicalEntry('G4043')"><wsn>G4043</wsn></ref><br><wgloss>to walk</wgloss><br><wtrans>walking</wtrans></div> <div class='int'><wform><grk id="w127310" cl='c24866' sn='G1722' morph='PREP' class="c24866 G1722" onclick="luW(4,'127310','24866','1722','PREP')" onmouseover="hl1('127310','24866','1722')" onmouseout="hl0('127310','24866','1722')" ondblclick="searchWord(2,127310)">ἐν</grk></wform><br><wsbl>en</wsbl><br><wphono>en</wphono><br><ref onclick="lex('G1722')" ondblclick="searchLexicalEntry('G1722')"><wlex><grk>ἐν</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G1722')" ondblclick="searchLexicalEntry('G1722')"><wsn>G1722</wsn></ref><br><wgloss>in/on/among</wgloss><br><wtrans>in</wtrans></div> <div class='int'><wform><grk id="w127311" cl='c24866' sn='G225' morph='N-DSF' class="c24866 G225" onclick="luW(4,'127311','24866','225','N-DSF')" onmouseover="hl1('127311','24866','225')" onmouseout="hl0('127311','24866','225')" ondblclick="searchWord(2,127311)">ἀληθείᾳ</grk></wform><br><wsbl>alētheia</wsbl><br><wphono>aliyθiya</wphono><br><ref onclick="lex('G225')" ondblclick="searchLexicalEntry('G225')"><wlex><grk>ἀλήθεια</grk></wlex></ref><br><ref onclick="rmac('N-DSF')"><wmorph>N-DSF</wmorph></ref><br><ref onclick="lex('G225')" ondblclick="searchLexicalEntry('G225')"><wsn>G225</wsn></ref><br><wgloss>truth</wgloss><br><wtrans>truth,</wtrans></div> <div class='int'><wform><grk id="w127312" cl='c24867' sn='G2531' morph='CONJ' class="c24867 G2531" onclick="luW(4,'127312','24867','2531','CONJ')" onmouseover="hl1('127312','24867','2531')" onmouseout="hl0('127312','24867','2531')" ondblclick="searchWord(2,127312)">καθὼς</grk></wform><br><wsbl>kathōs</wsbl><br><wphono>kaθos</wphono><br><ref onclick="lex('G2531')" ondblclick="searchLexicalEntry('G2531')"><wlex><grk>καθώς</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2531')" ondblclick="searchLexicalEntry('G2531')"><wsn>G2531</wsn></ref><br><wgloss>as/just as</wgloss><br><wtrans>just as</wtrans></div> <div class='int'><wform><grk id="w127313" cl='c24867' sn='G1785' morph='N-ASF' class="c24867 G1785" onclick="luW(4,'127313','24867','1785','N-ASF')" onmouseover="hl1('127313','24867','1785')" onmouseout="hl0('127313','24867','1785')" ondblclick="searchWord(2,127313)">ἐντολὴν</grk></wform><br><wsbl>entolēn</wsbl><br><wphono>entoliyn</wphono><br><ref onclick="lex('G1785')" ondblclick="searchLexicalEntry('G1785')"><wlex><grk>ἐντολή</grk></wlex></ref><br><ref onclick="rmac('N-ASF')"><wmorph>N-ASF</wmorph></ref><br><ref onclick="lex('G1785')" ondblclick="searchLexicalEntry('G1785')"><wsn>G1785</wsn></ref><br><wgloss>commandment</wgloss><br><wtrans>commandment</wtrans></div> <div class='int'><wform><grk id="w127314" cl='c24867' sn='G2983' morph='V-2AAI-1P' class="c24867 G2983" onclick="luW(4,'127314','24867','2983','V-2AAI-1P')" onmouseover="hl1('127314','24867','2983')" onmouseout="hl0('127314','24867','2983')" ondblclick="searchWord(2,127314)">ἐλάβομεν</grk></wform><br><wsbl>elabomen</wsbl><br><wphono>elavomen</wphono><br><ref onclick="lex('G2983')" ondblclick="searchLexicalEntry('G2983')"><wlex><grk>λαμβάνω</grk></wlex></ref><br><ref onclick="rmac('V-2AAI-1P')"><wmorph>V-2AAI-1P</wmorph></ref><br><ref onclick="lex('G2983')" ondblclick="searchLexicalEntry('G2983')"><wsn>G2983</wsn></ref><br><wgloss>to take</wgloss><br><wtrans>we received</wtrans></div> <div class='int'><wform><grk id="w127315" cl='c24867' sn='G3844' morph='PREP' class="c24867 G3844" onclick="luW(4,'127315','24867','3844','PREP')" onmouseover="hl1('127315','24867','3844')" onmouseout="hl0('127315','24867','3844')" ondblclick="searchWord(2,127315)">παρὰ</grk></wform><br><wsbl>para</wsbl><br><wphono>para</wphono><br><ref onclick="lex('G3844')" ondblclick="searchLexicalEntry('G3844')"><wlex><grk>παρά</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G3844')" ondblclick="searchLexicalEntry('G3844')"><wsn>G3844</wsn></ref><br><wgloss>from/with/beside</wgloss><br><wtrans>from</wtrans></div> <div class='int'><wform><grk id="w127316" cl='c24867' sn='G3588' morph='T-GSM' class="c24867 G3588" onclick="luW(4,'127316','24867','3588','T-GSM')" onmouseover="hl1('127316','24867','3588')" onmouseout="hl0('127316','24867','3588')" ondblclick="searchWord(2,127316)">τοῦ</grk></wform><br><wsbl>tou</wsbl><br><wphono>tu</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-GSM')"><wmorph>T-GSM</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127317" cl='c24867' sn='G3962' morph='N-GSM' class="c24867 G3962" onclick="luW(4,'127317','24867','3962','N-GSM')" onmouseover="hl1('127317','24867','3962')" onmouseout="hl0('127317','24867','3962')" ondblclick="searchWord(2,127317)">Πατρός</grk></wform><br><wsbl>Patros</wsbl><br><wphono>patros</wphono><br><ref onclick="lex('G3962')" ondblclick="searchLexicalEntry('G3962')"><wlex><grk>πατήρ</grk></wlex></ref><br><ref onclick="rmac('N-GSM')"><wmorph>N-GSM</wmorph></ref><br><ref onclick="lex('G3962')" ondblclick="searchLexicalEntry('G3962')"><wsn>G3962</wsn></ref><br><wgloss>father</wgloss><br><wtrans>Father.</wtrans></div><br></verse> <verse><vid id="v63.1.5" onclick="luV(5)">5</vid> <br><div class='int'><wform><grk id="w127318" cl='c24868' sn='G2532' morph='CONJ' class="c24868 G2532" onclick="luW(5,'127318','24868','2532','CONJ')" onmouseover="hl1('127318','24868','2532')" onmouseout="hl0('127318','24868','2532')" ondblclick="searchWord(2,127318)">καὶ</grk></wform><br><wsbl>kai</wsbl><br><wphono>ke</wphono><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wlex><grk>καί</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wsn>G2532</wsn></ref><br><wgloss>and</wgloss><br><wtrans>And</wtrans></div> <div class='int'><wform><grk id="w127319" cl='c24868' sn='G3568' morph='ADV' class="c24868 G3568" onclick="luW(5,'127319','24868','3568','ADV')" onmouseover="hl1('127319','24868','3568')" onmouseout="hl0('127319','24868','3568')" ondblclick="searchWord(2,127319)">νῦν</grk></wform><br><wsbl>nyn</wsbl><br><wphono>niyn</wphono><br><ref onclick="lex('G3568')" ondblclick="searchLexicalEntry('G3568')"><wlex><grk>νῦν</grk></wlex></ref><br><ref onclick="rmac('ADV')"><wmorph>ADV</wmorph></ref><br><ref onclick="lex('G3568')" ondblclick="searchLexicalEntry('G3568')"><wsn>G3568</wsn></ref><br><wgloss>now</wgloss><br><wtrans>now</wtrans></div> <div class='int'><wform><grk id="w127320" cl='c24868' sn='G2065' morph='V-PAI-1S' class="c24868 G2065" onclick="luW(5,'127320','24868','2065','V-PAI-1S')" onmouseover="hl1('127320','24868','2065')" onmouseout="hl0('127320','24868','2065')" ondblclick="searchWord(2,127320)">ἐρωτῶ</grk></wform><br><wsbl>erōtō</wsbl><br><wphono>eroto</wphono><br><ref onclick="lex('G2065')" ondblclick="searchLexicalEntry('G2065')"><wlex><grk>ἐρωτάω</grk></wlex></ref><br><ref onclick="rmac('V-PAI-1S')"><wmorph>V-PAI-1S</wmorph></ref><br><ref onclick="lex('G2065')" ondblclick="searchLexicalEntry('G2065')"><wsn>G2065</wsn></ref><br><wgloss>to ask</wgloss><br><wtrans>I implore</wtrans></div> <div class='int'><wform><grk id="w127321" cl='c24868' sn='G4771' morph='P-2AS' class="c24868 G4771" onclick="luW(5,'127321','24868','4771','P-2AS')" onmouseover="hl1('127321','24868','4771')" onmouseout="hl0('127321','24868','4771')" ondblclick="searchWord(2,127321)">σε</grk></wform><br><wsbl>se</wsbl><br><wphono>se</wphono><br><ref onclick="lex('G4771')" ondblclick="searchLexicalEntry('G4771')"><wlex><grk>σύ</grk></wlex></ref><br><ref onclick="rmac('P-2AS')"><wmorph>P-2AS</wmorph></ref><br><ref onclick="lex('G4771')" ondblclick="searchLexicalEntry('G4771')"><wsn>G4771</wsn></ref><br><wgloss>you</wgloss><br><wtrans>you,</wtrans></div> <div class='int'><wform><grk id="w127322" cl='c24868' sn='G2959' morph='N-VSF' class="c24868 G2959" onclick="luW(5,'127322','24868','2959','N-VSF')" onmouseover="hl1('127322','24868','2959')" onmouseout="hl0('127322','24868','2959')" ondblclick="searchWord(2,127322)">κυρία</grk></wform><br><wsbl>kyria</wsbl><br><wphono>kiyriya</wphono><br><ref onclick="lex('G2959')" ondblclick="searchLexicalEntry('G2959')"><wlex><grk>Κυρία</grk></wlex></ref><br><ref onclick="rmac('N-VSF')"><wmorph>N-VSF</wmorph></ref><br><ref onclick="lex('G2959')" ondblclick="searchLexicalEntry('G2959')"><wsn>G2959</wsn></ref><br><wgloss>lady</wgloss><br><wtrans>lady,</wtrans></div> <div class='int'><wform><grk id="w127323" cl='c24869' sn='G3756' morph='PRT-N' class="c24869 G3756" onclick="luW(5,'127323','24869','3756','PRT-N')" onmouseover="hl1('127323','24869','3756')" onmouseout="hl0('127323','24869','3756')" ondblclick="searchWord(2,127323)">οὐχ</grk></wform><br><wsbl>ouch</wsbl><br><wphono>ukh</wphono><br><ref onclick="lex('G3756')" ondblclick="searchLexicalEntry('G3756')"><wlex><grk>οὐ</grk></wlex></ref><br><ref onclick="rmac('PRT-N')"><wmorph>PRT-N</wmorph></ref><br><ref onclick="lex('G3756')" ondblclick="searchLexicalEntry('G3756')"><wsn>G3756</wsn></ref><br><wgloss>no</wgloss><br><wtrans>not</wtrans></div> <div class='int'><wform><grk id="w127324" cl='c24869' sn='G5613' morph='CONJ' class="c24869 G5613" onclick="luW(5,'127324','24869','5613','CONJ')" onmouseover="hl1('127324','24869','5613')" onmouseout="hl0('127324','24869','5613')" ondblclick="searchWord(2,127324)">ὡς</grk></wform><br><wsbl>hōs</wsbl><br><wphono>os</wphono><br><ref onclick="lex('G5613')" ondblclick="searchLexicalEntry('G5613')"><wlex><grk>ὡς</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G5613')" ondblclick="searchLexicalEntry('G5613')"><wsn>G5613</wsn></ref><br><wgloss>which/how</wgloss><br><wtrans>as</wtrans></div> <div class='int'><wform><grk id="w127325" cl='c24869' sn='G1785' morph='N-ASF' class="c24869 G1785" onclick="luW(5,'127325','24869','1785','N-ASF')" onmouseover="hl1('127325','24869','1785')" onmouseout="hl0('127325','24869','1785')" ondblclick="searchWord(2,127325)">ἐντολὴν</grk></wform><br><wsbl>entolēn</wsbl><br><wphono>entoliyn</wphono><br><ref onclick="lex('G1785')" ondblclick="searchLexicalEntry('G1785')"><wlex><grk>ἐντολή</grk></wlex></ref><br><ref onclick="rmac('N-ASF')"><wmorph>N-ASF</wmorph></ref><br><ref onclick="lex('G1785')" ondblclick="searchLexicalEntry('G1785')"><wsn>G1785</wsn></ref><br><wgloss>commandment</wgloss><br><wtrans>a commandment</wtrans></div> <div class='int'><wform><grk id="w127326" cl='c24869' sn='G1125' morph='V-PAP-NSM' class="c24869 G1125" onclick="luW(5,'127326','24869','1125','V-PAP-NSM')" onmouseover="hl1('127326','24869','1125')" onmouseout="hl0('127326','24869','1125')" ondblclick="searchWord(2,127326)">γράφων</grk></wform><br><wsbl>graphōn</wsbl><br><wphono>grafon</wphono><br><ref onclick="lex('G1125')" ondblclick="searchLexicalEntry('G1125')"><wlex><grk>γράφω</grk></wlex></ref><br><ref onclick="rmac('V-PAP-NSM')"><wmorph>V-PAP-NSM</wmorph></ref><br><ref onclick="lex('G1125')" ondblclick="searchLexicalEntry('G1125')"><wsn>G1125</wsn></ref><br><wgloss>to write</wgloss><br><wtrans>I am writing</wtrans></div> <div class='int'><wform><grk id="w127327" cl='c24869' sn='G4771' morph='P-2DS' class="c24869 G4771" onclick="luW(5,'127327','24869','4771','P-2DS')" onmouseover="hl1('127327','24869','4771')" onmouseout="hl0('127327','24869','4771')" ondblclick="searchWord(2,127327)">σοι</grk></wform><br><wsbl>soi</wsbl><br><wphono>siy</wphono><br><ref onclick="lex('G4771')" ondblclick="searchLexicalEntry('G4771')"><wlex><grk>σύ</grk></wlex></ref><br><ref onclick="rmac('P-2DS')"><wmorph>P-2DS</wmorph></ref><br><ref onclick="lex('G4771')" ondblclick="searchLexicalEntry('G4771')"><wsn>G4771</wsn></ref><br><wgloss>you</wgloss><br><wtrans>to you</wtrans></div> <div class='int'><wform><grk id="w127328" cl='c24869' sn='G2537' morph='A-ASF' class="c24869 G2537" onclick="luW(5,'127328','24869','2537','A-ASF')" onmouseover="hl1('127328','24869','2537')" onmouseout="hl0('127328','24869','2537')" ondblclick="searchWord(2,127328)">καινὴν</grk></wform><br><wsbl>kainēn</wsbl><br><wphono>keniyn</wphono><br><ref onclick="lex('G2537')" ondblclick="searchLexicalEntry('G2537')"><wlex><grk>καινός</grk></wlex></ref><br><ref onclick="rmac('A-ASF')"><wmorph>A-ASF</wmorph></ref><br><ref onclick="lex('G2537')" ondblclick="searchLexicalEntry('G2537')"><wsn>G2537</wsn></ref><br><wgloss>new</wgloss><br><wtrans>new,</wtrans></div> <div class='int'><wform><grk id="w127329" cl='c24870' sn='G235' morph='CONJ' class="c24870 G235" onclick="luW(5,'127329','24870','235','CONJ')" onmouseover="hl1('127329','24870','235')" onmouseout="hl0('127329','24870','235')" ondblclick="searchWord(2,127329)">ἀλλὰ</grk></wform><br><wsbl>alla</wsbl><br><wphono>alla</wphono><br><ref onclick="lex('G235')" ondblclick="searchLexicalEntry('G235')"><wlex><grk>ἀλλά</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G235')" ondblclick="searchLexicalEntry('G235')"><wsn>G235</wsn></ref><br><wgloss>but</wgloss><br><wtrans>but</wtrans></div> <div class='int'><wform><grk id="w127330" cl='c24870' sn='G3739' morph='R-ASF' class="c24870 G3739" onclick="luW(5,'127330','24870','3739','R-ASF')" onmouseover="hl1('127330','24870','3739')" onmouseout="hl0('127330','24870','3739')" ondblclick="searchWord(2,127330)">ἣν</grk></wform><br><wsbl>hēn</wsbl><br><wphono>iyn</wphono><br><ref onclick="lex('G3739')" ondblclick="searchLexicalEntry('G3739')"><wlex><grk>ὅς, ἥ</grk></wlex></ref><br><ref onclick="rmac('R-ASF')"><wmorph>R-ASF</wmorph></ref><br><ref onclick="lex('G3739')" ondblclick="searchLexicalEntry('G3739')"><wsn>G3739</wsn></ref><br><wgloss>which</wgloss><br><wtrans>that which</wtrans></div> <div class='int'><wform><grk id="w127331" cl='c24870' sn='G2192' morph='V-IAI-1P' class="c24870 G2192" onclick="luW(5,'127331','24870','2192','V-IAI-1P')" onmouseover="hl1('127331','24870','2192')" onmouseout="hl0('127331','24870','2192')" ondblclick="searchWord(2,127331)">εἴχομεν</grk></wform><br><wsbl>eichomen</wsbl><br><wphono>iykhomen</wphono><br><ref onclick="lex('G2192')" ondblclick="searchLexicalEntry('G2192')"><wlex><grk>ἔχω</grk></wlex></ref><br><ref onclick="rmac('V-IAI-1P')"><wmorph>V-IAI-1P</wmorph></ref><br><ref onclick="lex('G2192')" ondblclick="searchLexicalEntry('G2192')"><wsn>G2192</wsn></ref><br><wgloss>to have/be</wgloss><br><wtrans>we have had</wtrans></div> <div class='int'><wform><grk id="w127332" cl='c24870' sn='G575' morph='PREP' class="c24870 G575" onclick="luW(5,'127332','24870','575','PREP')" onmouseover="hl1('127332','24870','575')" onmouseout="hl0('127332','24870','575')" ondblclick="searchWord(2,127332)">ἀπ᾽</grk></wform><br><wsbl>ap</wsbl><br><wphono>ap</wphono><br><ref onclick="lex('G575')" ondblclick="searchLexicalEntry('G575')"><wlex><grk>ἀπό</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G575')" ondblclick="searchLexicalEntry('G575')"><wsn>G575</wsn></ref><br><wgloss>from</wgloss><br><wtrans>from</wtrans></div> <div class='int'><wform><grk id="w127333" cl='c24870' sn='G746' morph='N-GSF' class="c24870 G746" onclick="luW(5,'127333','24870','746','N-GSF')" onmouseover="hl1('127333','24870','746')" onmouseout="hl0('127333','24870','746')" ondblclick="searchWord(2,127333)">ἀρχῆς</grk></wform><br><wsbl>archēs</wsbl><br><wphono>arkhiys</wphono><br><ref onclick="lex('G746')" ondblclick="searchLexicalEntry('G746')"><wlex><grk>ἀρχή</grk></wlex></ref><br><ref onclick="rmac('N-GSF')"><wmorph>N-GSF</wmorph></ref><br><ref onclick="lex('G746')" ondblclick="searchLexicalEntry('G746')"><wsn>G746</wsn></ref><br><wgloss>beginning</wgloss><br><wtrans>[the] beginning,</wtrans></div> <div class='int'><wform><grk id="w127334" cl='c24871' sn='G2443' morph='CONJ' class="c24871 G2443" onclick="luW(5,'127334','24871','2443','CONJ')" onmouseover="hl1('127334','24871','2443')" onmouseout="hl0('127334','24871','2443')" ondblclick="searchWord(2,127334)">ἵνα</grk></wform><br><wsbl>hina</wsbl><br><wphono>iyna</wphono><br><ref onclick="lex('G2443')" ondblclick="searchLexicalEntry('G2443')"><wlex><grk>ἵνα</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2443')" ondblclick="searchLexicalEntry('G2443')"><wsn>G2443</wsn></ref><br><wgloss>in order that/to</wgloss><br><wtrans>that</wtrans></div> <div class='int'><wform><grk id="w127335" cl='c24871' sn='G25' morph='V-PAS-1P' class="c24871 G25" onclick="luW(5,'127335','24871','25','V-PAS-1P')" onmouseover="hl1('127335','24871','25')" onmouseout="hl0('127335','24871','25')" ondblclick="searchWord(2,127335)">ἀγαπῶμεν</grk></wform><br><wsbl>agapōmen</wsbl><br><wphono>agapomen</wphono><br><ref onclick="lex('G25')" ondblclick="searchLexicalEntry('G25')"><wlex><grk>ἀγαπάω</grk></wlex></ref><br><ref onclick="rmac('V-PAS-1P')"><wmorph>V-PAS-1P</wmorph></ref><br><ref onclick="lex('G25')" ondblclick="searchLexicalEntry('G25')"><wsn>G25</wsn></ref><br><wgloss>to love</wgloss><br><wtrans>we should love</wtrans></div> <div class='int'><wform><grk id="w127336" cl='c24871' sn='G240' morph='C-APM' class="c24871 G240" onclick="luW(5,'127336','24871','240','C-APM')" onmouseover="hl1('127336','24871','240')" onmouseout="hl0('127336','24871','240')" ondblclick="searchWord(2,127336)">ἀλλήλους</grk></wform><br><wsbl>allēlous</wsbl><br><wphono>alliylus</wphono><br><ref onclick="lex('G240')" ondblclick="searchLexicalEntry('G240')"><wlex><grk>ἀλλήλων</grk></wlex></ref><br><ref onclick="rmac('C-APM')"><wmorph>C-APM</wmorph></ref><br><ref onclick="lex('G240')" ondblclick="searchLexicalEntry('G240')"><wsn>G240</wsn></ref><br><wgloss>one another</wgloss><br><wtrans>one another.</wtrans></div><br></verse> <verse><vid id="v63.1.6" onclick="luV(6)">6</vid> <br><div class='int'><wform><grk id="w127337" cl='c24872' sn='G2532' morph='CONJ' class="c24872 G2532" onclick="luW(6,'127337','24872','2532','CONJ')" onmouseover="hl1('127337','24872','2532')" onmouseout="hl0('127337','24872','2532')" ondblclick="searchWord(2,127337)">καὶ</grk></wform><br><wsbl>kai</wsbl><br><wphono>ke</wphono><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wlex><grk>καί</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wsn>G2532</wsn></ref><br><wgloss>and</wgloss><br><wtrans>And</wtrans></div> <div class='int'><wform><grk id="w127338" cl='c24872' sn='G3778' morph='D-NSF' class="c24872 G3778" onclick="luW(6,'127338','24872','3778','D-NSF')" onmouseover="hl1('127338','24872','3778')" onmouseout="hl0('127338','24872','3778')" ondblclick="searchWord(2,127338)">αὕτη</grk></wform><br><wsbl>hautē</wsbl><br><wphono>aftiy</wphono><br><ref onclick="lex('G3778')" ondblclick="searchLexicalEntry('G3778')"><wlex><grk>οὗτος</grk></wlex></ref><br><ref onclick="rmac('D-NSF')"><wmorph>D-NSF</wmorph></ref><br><ref onclick="lex('G3778')" ondblclick="searchLexicalEntry('G3778')"><wsn>G3778</wsn></ref><br><wgloss>this/he/she/it</wgloss><br><wtrans>this</wtrans></div> <div class='int'><wform><grk id="w127339" cl='c24872' sn='G1510' morph='V-PAI-3S' class="c24872 G1510" onclick="luW(6,'127339','24872','1510','V-PAI-3S')" onmouseover="hl1('127339','24872','1510')" onmouseout="hl0('127339','24872','1510')" ondblclick="searchWord(2,127339)">ἐστὶν</grk></wform><br><wsbl>estin</wsbl><br><wphono>estiyn</wphono><br><ref onclick="lex('G1510')" ondblclick="searchLexicalEntry('G1510')"><wlex><grk>εἰμί</grk></wlex></ref><br><ref onclick="rmac('V-PAI-3S')"><wmorph>V-PAI-3S</wmorph></ref><br><ref onclick="lex('G1510')" ondblclick="searchLexicalEntry('G1510')"><wsn>G1510</wsn></ref><br><wgloss>to be</wgloss><br><wtrans>is</wtrans></div> <div class='int'><wform><grk id="w127340" cl='c24872' sn='G3588' morph='T-NSF' class="c24872 G3588" onclick="luW(6,'127340','24872','3588','T-NSF')" onmouseover="hl1('127340','24872','3588')" onmouseout="hl0('127340','24872','3588')" ondblclick="searchWord(2,127340)">ἡ</grk></wform><br><wsbl>hē</wsbl><br><wphono>iy</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-NSF')"><wmorph>T-NSF</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>-</wtrans></div> <div class='int'><wform><grk id="w127341" cl='c24872' sn='G26' morph='N-NSF' class="c24872 G26" onclick="luW(6,'127341','24872','26','N-NSF')" onmouseover="hl1('127341','24872','26')" onmouseout="hl0('127341','24872','26')" ondblclick="searchWord(2,127341)">ἀγάπη</grk></wform><br><wsbl>agapē</wsbl><br><wphono>agapiy</wphono><br><ref onclick="lex('G26')" ondblclick="searchLexicalEntry('G26')"><wlex><grk>ἀγάπη</grk></wlex></ref><br><ref onclick="rmac('N-NSF')"><wmorph>N-NSF</wmorph></ref><br><ref onclick="lex('G26')" ondblclick="searchLexicalEntry('G26')"><wsn>G26</wsn></ref><br><wgloss>love</wgloss><br><wtrans>love,</wtrans></div> <div class='int'><wform><grk id="w127342" cl='c24873' sn='G2443' morph='ADV' class="c24873 G2443" onclick="luW(6,'127342','24873','2443','ADV')" onmouseover="hl1('127342','24873','2443')" onmouseout="hl0('127342','24873','2443')" ondblclick="searchWord(2,127342)">ἵνα</grk></wform><br><wsbl>hina</wsbl><br><wphono>iyna</wphono><br><ref onclick="lex('G2443')" ondblclick="searchLexicalEntry('G2443')"><wlex><grk>ἵνα</grk></wlex></ref><br><ref onclick="rmac('ADV')"><wmorph>ADV</wmorph></ref><br><ref onclick="lex('G2443')" ondblclick="searchLexicalEntry('G2443')"><wsn>G2443</wsn></ref><br><wgloss>in order that/to</wgloss><br><wtrans>that</wtrans></div> <div class='int'><wform><grk id="w127343" cl='c24873' sn='G4043' morph='V-PAS-1P' class="c24873 G4043" onclick="luW(6,'127343','24873','4043','V-PAS-1P')" onmouseover="hl1('127343','24873','4043')" onmouseout="hl0('127343','24873','4043')" ondblclick="searchWord(2,127343)">περιπατῶμεν</grk></wform><br><wsbl>peripatōmen</wsbl><br><wphono>periypatomen</wphono><br><ref onclick="lex('G4043')" ondblclick="searchLexicalEntry('G4043')"><wlex><grk>περιπατέω</grk></wlex></ref><br><ref onclick="rmac('V-PAS-1P')"><wmorph>V-PAS-1P</wmorph></ref><br><ref onclick="lex('G4043')" ondblclick="searchLexicalEntry('G4043')"><wsn>G4043</wsn></ref><br><wgloss>to walk</wgloss><br><wtrans>we should walk</wtrans></div> <div class='int'><wform><grk id="w127344" cl='c24873' sn='G2596' morph='PREP' class="c24873 G2596" onclick="luW(6,'127344','24873','2596','PREP')" onmouseover="hl1('127344','24873','2596')" onmouseout="hl0('127344','24873','2596')" ondblclick="searchWord(2,127344)">κατὰ</grk></wform><br><wsbl>kata</wsbl><br><wphono>kata</wphono><br><ref onclick="lex('G2596')" ondblclick="searchLexicalEntry('G2596')"><wlex><grk>κατά</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G2596')" ondblclick="searchLexicalEntry('G2596')"><wsn>G2596</wsn></ref><br><wgloss>according to</wgloss><br><wtrans>according to</wtrans></div> <div class='int'><wform><grk id="w127345" cl='c24873' sn='G3588' morph='T-APF' class="c24873 G3588" onclick="luW(6,'127345','24873','3588','T-APF')" onmouseover="hl1('127345','24873','3588')" onmouseout="hl0('127345','24873','3588')" ondblclick="searchWord(2,127345)">τὰς</grk></wform><br><wsbl>tas</wsbl><br><wphono>tas</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-APF')"><wmorph>T-APF</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127346" cl='c24873' sn='G1785' morph='N-APF' class="c24873 G1785" onclick="luW(6,'127346','24873','1785','N-APF')" onmouseover="hl1('127346','24873','1785')" onmouseout="hl0('127346','24873','1785')" ondblclick="searchWord(2,127346)">ἐντολὰς</grk></wform><br><wsbl>entolas</wsbl><br><wphono>entolas</wphono><br><ref onclick="lex('G1785')" ondblclick="searchLexicalEntry('G1785')"><wlex><grk>ἐντολή</grk></wlex></ref><br><ref onclick="rmac('N-APF')"><wmorph>N-APF</wmorph></ref><br><ref onclick="lex('G1785')" ondblclick="searchLexicalEntry('G1785')"><wsn>G1785</wsn></ref><br><wgloss>commandment</wgloss><br><wtrans>commandments</wtrans></div> <div class='int'><wform><grk id="w127347" cl='c24873' sn='G846' morph='P-GSM' class="c24873 G846" onclick="luW(6,'127347','24873','846','P-GSM')" onmouseover="hl1('127347','24873','846')" onmouseout="hl0('127347','24873','846')" ondblclick="searchWord(2,127347)">αὐτοῦ</grk></wform><br><wsbl>autou</wsbl><br><wphono>aftu</wphono><br><ref onclick="lex('G846')" ondblclick="searchLexicalEntry('G846')"><wlex><grk>αὐτός</grk></wlex></ref><br><ref onclick="rmac('P-GSM')"><wmorph>P-GSM</wmorph></ref><br><ref onclick="lex('G846')" ondblclick="searchLexicalEntry('G846')"><wsn>G846</wsn></ref><br><wgloss>he/she/it/self</wgloss><br><wtrans>of Him.</wtrans></div> <div class='int'><wform><grk id="w127348" cl='c24874' sn='G3778' morph='D-NSF' class="c24874 G3778" onclick="luW(6,'127348','24874','3778','D-NSF')" onmouseover="hl1('127348','24874','3778')" onmouseout="hl0('127348','24874','3778')" ondblclick="searchWord(2,127348)">αὕτη</grk></wform><br><wsbl>hautē</wsbl><br><wphono>aftiy</wphono><br><ref onclick="lex('G3778')" ondblclick="searchLexicalEntry('G3778')"><wlex><grk>οὗτος</grk></wlex></ref><br><ref onclick="rmac('D-NSF')"><wmorph>D-NSF</wmorph></ref><br><ref onclick="lex('G3778')" ondblclick="searchLexicalEntry('G3778')"><wsn>G3778</wsn></ref><br><wgloss>this/he/she/it</wgloss><br><wtrans>This</wtrans></div> <div class='int'><wform><grk id="w127349" cl='c24874' sn='G3588' morph='T-NSF' class="c24874 G3588" onclick="luW(6,'127349','24874','3588','T-NSF')" onmouseover="hl1('127349','24874','3588')" onmouseout="hl0('127349','24874','3588')" ondblclick="searchWord(2,127349)">ἡ</grk></wform><br><wsbl>hē</wsbl><br><wphono>iy</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-NSF')"><wmorph>T-NSF</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127350" cl='c24874' sn='G1785' morph='N-NSF' class="c24874 G1785" onclick="luW(6,'127350','24874','1785','N-NSF')" onmouseover="hl1('127350','24874','1785')" onmouseout="hl0('127350','24874','1785')" ondblclick="searchWord(2,127350)">ἐντολή</grk></wform><br><wsbl>entolē</wsbl><br><wphono>entoliy</wphono><br><ref onclick="lex('G1785')" ondblclick="searchLexicalEntry('G1785')"><wlex><grk>ἐντολή</grk></wlex></ref><br><ref onclick="rmac('N-NSF')"><wmorph>N-NSF</wmorph></ref><br><ref onclick="lex('G1785')" ondblclick="searchLexicalEntry('G1785')"><wsn>G1785</wsn></ref><br><wgloss>commandment</wgloss><br><wtrans>commandment</wtrans></div> <div class='int'><wform><grk id="w127351" cl='c24874' sn='G1510' morph='V-PAI-3S' class="c24874 G1510" onclick="luW(6,'127351','24874','1510','V-PAI-3S')" onmouseover="hl1('127351','24874','1510')" onmouseout="hl0('127351','24874','1510')" ondblclick="searchWord(2,127351)">ἐστιν</grk></wform><br><wsbl>estin</wsbl><br><wphono>estiyn</wphono><br><ref onclick="lex('G1510')" ondblclick="searchLexicalEntry('G1510')"><wlex><grk>εἰμί</grk></wlex></ref><br><ref onclick="rmac('V-PAI-3S')"><wmorph>V-PAI-3S</wmorph></ref><br><ref onclick="lex('G1510')" ondblclick="searchLexicalEntry('G1510')"><wsn>G1510</wsn></ref><br><wgloss>to be</wgloss><br><wtrans>is</wtrans></div> <div class='int'><wform><grk id="w127352" cl='c24875' sn='G2531' morph='CONJ' class="c24875 G2531" onclick="luW(6,'127352','24875','2531','CONJ')" onmouseover="hl1('127352','24875','2531')" onmouseout="hl0('127352','24875','2531')" ondblclick="searchWord(2,127352)">καθὼς</grk></wform><br><wsbl>kathōs</wsbl><br><wphono>kaθos</wphono><br><ref onclick="lex('G2531')" ondblclick="searchLexicalEntry('G2531')"><wlex><grk>καθώς</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2531')" ondblclick="searchLexicalEntry('G2531')"><wsn>G2531</wsn></ref><br><wgloss>as/just as</wgloss><br><wtrans>just as</wtrans></div> <div class='int'><wform><grk id="w127353" cl='c24875' sn='G191' morph='V-AAI-2P' class="c24875 G191" onclick="luW(6,'127353','24875','191','V-AAI-2P')" onmouseover="hl1('127353','24875','191')" onmouseout="hl0('127353','24875','191')" ondblclick="searchWord(2,127353)">ἠκούσατε</grk></wform><br><wsbl>ēkousate</wsbl><br><wphono>iykusate</wphono><br><ref onclick="lex('G191')" ondblclick="searchLexicalEntry('G191')"><wlex><grk>ἀκούω</grk></wlex></ref><br><ref onclick="rmac('V-AAI-2P')"><wmorph>V-AAI-2P</wmorph></ref><br><ref onclick="lex('G191')" ondblclick="searchLexicalEntry('G191')"><wsn>G191</wsn></ref><br><wgloss>to hear</wgloss><br><wtrans>you have heard</wtrans></div> <div class='int'><wform><grk id="w127354" cl='c24875' sn='G575' morph='PREP' class="c24875 G575" onclick="luW(6,'127354','24875','575','PREP')" onmouseover="hl1('127354','24875','575')" onmouseout="hl0('127354','24875','575')" ondblclick="searchWord(2,127354)">ἀπ᾽</grk></wform><br><wsbl>ap</wsbl><br><wphono>ap</wphono><br><ref onclick="lex('G575')" ondblclick="searchLexicalEntry('G575')"><wlex><grk>ἀπό</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G575')" ondblclick="searchLexicalEntry('G575')"><wsn>G575</wsn></ref><br><wgloss>from</wgloss><br><wtrans>from</wtrans></div> <div class='int'><wform><grk id="w127355" cl='c24875' sn='G746' morph='N-GSF' class="c24875 G746" onclick="luW(6,'127355','24875','746','N-GSF')" onmouseover="hl1('127355','24875','746')" onmouseout="hl0('127355','24875','746')" ondblclick="searchWord(2,127355)">ἀρχῆς</grk></wform><br><wsbl>archēs</wsbl><br><wphono>arkhiys</wphono><br><ref onclick="lex('G746')" ondblclick="searchLexicalEntry('G746')"><wlex><grk>ἀρχή</grk></wlex></ref><br><ref onclick="rmac('N-GSF')"><wmorph>N-GSF</wmorph></ref><br><ref onclick="lex('G746')" ondblclick="searchLexicalEntry('G746')"><wsn>G746</wsn></ref><br><wgloss>beginning</wgloss><br><wtrans>[the] beginning,</wtrans></div> <div class='int'><wform><grk id="w127356" cl='c24876' sn='G2443' morph='ADV' class="c24876 G2443" onclick="luW(6,'127356','24876','2443','ADV')" onmouseover="hl1('127356','24876','2443')" onmouseout="hl0('127356','24876','2443')" ondblclick="searchWord(2,127356)">ἵνα</grk></wform><br><wsbl>hina</wsbl><br><wphono>iyna</wphono><br><ref onclick="lex('G2443')" ondblclick="searchLexicalEntry('G2443')"><wlex><grk>ἵνα</grk></wlex></ref><br><ref onclick="rmac('ADV')"><wmorph>ADV</wmorph></ref><br><ref onclick="lex('G2443')" ondblclick="searchLexicalEntry('G2443')"><wsn>G2443</wsn></ref><br><wgloss>in order that/to</wgloss><br><wtrans>so that</wtrans></div> <div class='int'><wform><grk id="w127357" cl='c24876' sn='G1722' morph='PREP' class="c24876 G1722" onclick="luW(6,'127357','24876','1722','PREP')" onmouseover="hl1('127357','24876','1722')" onmouseout="hl0('127357','24876','1722')" ondblclick="searchWord(2,127357)">ἐν</grk></wform><br><wsbl>en</wsbl><br><wphono>en</wphono><br><ref onclick="lex('G1722')" ondblclick="searchLexicalEntry('G1722')"><wlex><grk>ἐν</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G1722')" ondblclick="searchLexicalEntry('G1722')"><wsn>G1722</wsn></ref><br><wgloss>in/on/among</wgloss><br><wtrans>in</wtrans></div> <div class='int'><wform><grk id="w127358" cl='c24876' sn='G846' morph='P-DSF' class="c24876 G846" onclick="luW(6,'127358','24876','846','P-DSF')" onmouseover="hl1('127358','24876','846')" onmouseout="hl0('127358','24876','846')" ondblclick="searchWord(2,127358)">αὐτῇ</grk></wform><br><wsbl>autē</wsbl><br><wphono>aftiy</wphono><br><ref onclick="lex('G846')" ondblclick="searchLexicalEntry('G846')"><wlex><grk>αὐτός</grk></wlex></ref><br><ref onclick="rmac('P-DSF')"><wmorph>P-DSF</wmorph></ref><br><ref onclick="lex('G846')" ondblclick="searchLexicalEntry('G846')"><wsn>G846</wsn></ref><br><wgloss>he/she/it/self</wgloss><br><wtrans>it</wtrans></div> <div class='int'><wform><grk id="w127359" cl='c24876' sn='G4043' morph='V-PAS-2P' class="c24876 G4043" onclick="luW(6,'127359','24876','4043','V-PAS-2P')" onmouseover="hl1('127359','24876','4043')" onmouseout="hl0('127359','24876','4043')" ondblclick="searchWord(2,127359)">περιπατῆτε</grk></wform><br><wsbl>peripatēte</wsbl><br><wphono>periypatiyte</wphono><br><ref onclick="lex('G4043')" ondblclick="searchLexicalEntry('G4043')"><wlex><grk>περιπατέω</grk></wlex></ref><br><ref onclick="rmac('V-PAS-2P')"><wmorph>V-PAS-2P</wmorph></ref><br><ref onclick="lex('G4043')" ondblclick="searchLexicalEntry('G4043')"><wsn>G4043</wsn></ref><br><wgloss>to walk</wgloss><br><wtrans>you should walk.</wtrans></div><br></verse> <verse><vid id="v63.1.7" onclick="luV(7)">7</vid> <br><div class='int'><wform><grk id="w127360" cl='c24877' sn='G3754' morph='CONJ' class="c24877 G3754" onclick="luW(7,'127360','24877','3754','CONJ')" onmouseover="hl1('127360','24877','3754')" onmouseout="hl0('127360','24877','3754')" ondblclick="searchWord(2,127360)">Ὅτι</grk></wform><br><wsbl>Hoti</wsbl><br><wphono>otiy</wphono><br><ref onclick="lex('G3754')" ondblclick="searchLexicalEntry('G3754')"><wlex><grk>ὅτι</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G3754')" ondblclick="searchLexicalEntry('G3754')"><wsn>G3754</wsn></ref><br><wgloss>that/since</wgloss><br><wtrans>For</wtrans></div> <div class='int'><wform><grk id="w127361" cl='c24877' sn='G4183' morph='A-NPM' class="c24877 G4183" onclick="luW(7,'127361','24877','4183','A-NPM')" onmouseover="hl1('127361','24877','4183')" onmouseout="hl0('127361','24877','4183')" ondblclick="searchWord(2,127361)">πολλοὶ</grk></wform><br><wsbl>polloi</wsbl><br><wphono>polliy</wphono><br><ref onclick="lex('G4183')" ondblclick="searchLexicalEntry('G4183')"><wlex><grk>πολύς</grk></wlex></ref><br><ref onclick="rmac('A-NPM')"><wmorph>A-NPM</wmorph></ref><br><ref onclick="lex('G4183')" ondblclick="searchLexicalEntry('G4183')"><wsn>G4183</wsn></ref><br><wgloss>much</wgloss><br><wtrans>many</wtrans></div> <div class='int'><wform><grk id="w127362" cl='c24877' sn='G4108' morph='A-NPM' class="c24877 G4108" onclick="luW(7,'127362','24877','4108','A-NPM')" onmouseover="hl1('127362','24877','4108')" onmouseout="hl0('127362','24877','4108')" ondblclick="searchWord(2,127362)">πλάνοι</grk></wform><br><wsbl>planoi</wsbl><br><wphono>planiy</wphono><br><ref onclick="lex('G4108')" ondblclick="searchLexicalEntry('G4108')"><wlex><grk>πλάνος</grk></wlex></ref><br><ref onclick="rmac('A-NPM')"><wmorph>A-NPM</wmorph></ref><br><ref onclick="lex('G4108')" ondblclick="searchLexicalEntry('G4108')"><wsn>G4108</wsn></ref><br><wgloss>deceiving</wgloss><br><wtrans>deceivers</wtrans></div> <div class='int'><wform><grk id="w127363" cl='c24877' sn='G1831' morph='V-2AAI-3P' class="c24877 G1831" onclick="luW(7,'127363','24877','1831','V-2AAI-3P')" onmouseover="hl1('127363','24877','1831')" onmouseout="hl0('127363','24877','1831')" ondblclick="searchWord(2,127363)">ἐξῆλθον</grk></wform><br><wsbl>exēlthon</wsbl><br><wphono>eksiylθon</wphono><br><ref onclick="lex('G1831')" ondblclick="searchLexicalEntry('G1831')"><wlex><grk>ἐξέρχομαι</grk></wlex></ref><br><ref onclick="rmac('V-2AAI-3P')"><wmorph>V-2AAI-3P</wmorph></ref><br><ref onclick="lex('G1831')" ondblclick="searchLexicalEntry('G1831')"><wsn>G1831</wsn></ref><br><wgloss>to go out</wgloss><br><wtrans>have entered</wtrans></div> <div class='int'><wform><grk id="w127364" cl='c24877' sn='G1519' morph='PREP' class="c24877 G1519" onclick="luW(7,'127364','24877','1519','PREP')" onmouseover="hl1('127364','24877','1519')" onmouseout="hl0('127364','24877','1519')" ondblclick="searchWord(2,127364)">εἰς</grk></wform><br><wsbl>eis</wsbl><br><wphono>iys</wphono><br><ref onclick="lex('G1519')" ondblclick="searchLexicalEntry('G1519')"><wlex><grk>εἰς</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G1519')" ondblclick="searchLexicalEntry('G1519')"><wsn>G1519</wsn></ref><br><wgloss>toward</wgloss><br><wtrans>into</wtrans></div> <div class='int'><wform><grk id="w127365" cl='c24877' sn='G3588' morph='T-ASM' class="c24877 G3588" onclick="luW(7,'127365','24877','3588','T-ASM')" onmouseover="hl1('127365','24877','3588')" onmouseout="hl0('127365','24877','3588')" ondblclick="searchWord(2,127365)">τὸν</grk></wform><br><wsbl>ton</wsbl><br><wphono>ton</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-ASM')"><wmorph>T-ASM</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127366" cl='c24877' sn='G2889' morph='N-ASM' class="c24877 G2889" onclick="luW(7,'127366','24877','2889','N-ASM')" onmouseover="hl1('127366','24877','2889')" onmouseout="hl0('127366','24877','2889')" ondblclick="searchWord(2,127366)">κόσμον</grk></wform><br><wsbl>kosmon</wsbl><br><wphono>kozmon</wphono><br><ref onclick="lex('G2889')" ondblclick="searchLexicalEntry('G2889')"><wlex><grk>κόσμος</grk></wlex></ref><br><ref onclick="rmac('N-ASM')"><wmorph>N-ASM</wmorph></ref><br><ref onclick="lex('G2889')" ondblclick="searchLexicalEntry('G2889')"><wsn>G2889</wsn></ref><br><wgloss>world</wgloss><br><wtrans>world,</wtrans></div> <div class='int'><wform><grk id="w127367" cl='c24878' sn='G3588' morph='T-NPM' class="c24878 G3588" onclick="luW(7,'127367','24878','3588','T-NPM')" onmouseover="hl1('127367','24878','3588')" onmouseout="hl0('127367','24878','3588')" ondblclick="searchWord(2,127367)">οἱ</grk></wform><br><wsbl>hoi</wsbl><br><wphono>iy</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-NPM')"><wmorph>T-NPM</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>those</wtrans></div> <div class='int'><wform><grk id="w127368" cl='c24878' sn='G3361' morph='PRT-N' class="c24878 G3361" onclick="luW(7,'127368','24878','3361','PRT-N')" onmouseover="hl1('127368','24878','3361')" onmouseout="hl0('127368','24878','3361')" ondblclick="searchWord(2,127368)">μὴ</grk></wform><br><wsbl>mē</wsbl><br><wphono>miy</wphono><br><ref onclick="lex('G3361')" ondblclick="searchLexicalEntry('G3361')"><wlex><grk>μή</grk></wlex></ref><br><ref onclick="rmac('PRT-N')"><wmorph>PRT-N</wmorph></ref><br><ref onclick="lex('G3361')" ondblclick="searchLexicalEntry('G3361')"><wsn>G3361</wsn></ref><br><wgloss>not</wgloss><br><wtrans>not</wtrans></div> <div class='int'><wform><grk id="w127369" cl='c24878' sn='G3670' morph='V-PAP-NPM' class="c24878 G3670" onclick="luW(7,'127369','24878','3670','V-PAP-NPM')" onmouseover="hl1('127369','24878','3670')" onmouseout="hl0('127369','24878','3670')" ondblclick="searchWord(2,127369)">ὁμολογοῦντες</grk></wform><br><wsbl>homologountes</wsbl><br><wphono>omologuntes</wphono><br><ref onclick="lex('G3670')" ondblclick="searchLexicalEntry('G3670')"><wlex><grk>ὁμολογέω</grk></wlex></ref><br><ref onclick="rmac('V-PAP-NPM')"><wmorph>V-PAP-NPM</wmorph></ref><br><ref onclick="lex('G3670')" ondblclick="searchLexicalEntry('G3670')"><wsn>G3670</wsn></ref><br><wgloss>to confess/profess</wgloss><br><wtrans>confessing</wtrans></div> <div class='int'><wform><grk id="w127370" cl='c24878' sn='G2424' morph='N-ASM-P' class="c24878 G2424" onclick="luW(7,'127370','24878','2424','N-ASM-P')" onmouseover="hl1('127370','24878','2424')" onmouseout="hl0('127370','24878','2424')" ondblclick="searchWord(2,127370)">Ἰησοῦν</grk></wform><br><wsbl>Iēsoun</wsbl><br><wphono>iyiysun</wphono><br><ref onclick="lex('G2424')" ondblclick="searchLexicalEntry('G2424')"><wlex><grk>Ἰησοῦς</grk></wlex></ref><br><ref onclick="rmac('N-ASM-P')"><wmorph>N-ASM-P</wmorph></ref><br><ref onclick="lex('G2424')" ondblclick="searchLexicalEntry('G2424')"><wsn>G2424</wsn></ref><br><wgloss>Jesus/Joshua</wgloss><br><wtrans>Jesus</wtrans></div> <div class='int'><wform><grk id="w127371" cl='c24878' sn='G5547' morph='N-ASM-T' class="c24878 G5547" onclick="luW(7,'127371','24878','5547','N-ASM-T')" onmouseover="hl1('127371','24878','5547')" onmouseout="hl0('127371','24878','5547')" ondblclick="searchWord(2,127371)">Χριστὸν</grk></wform><br><wsbl>Christon</wsbl><br><wphono>khriyston</wphono><br><ref onclick="lex('G5547')" ondblclick="searchLexicalEntry('G5547')"><wlex><grk>Χριστός</grk></wlex></ref><br><ref onclick="rmac('N-ASM-T')"><wmorph>N-ASM-T</wmorph></ref><br><ref onclick="lex('G5547')" ondblclick="searchLexicalEntry('G5547')"><wsn>G5547</wsn></ref><br><wgloss>Christ</wgloss><br><wtrans>Christ</wtrans></div> <div class='int'><wform><grk id="w127372" cl='c24878' sn='G2064' morph='V-PNP-ASM' class="c24878 G2064" onclick="luW(7,'127372','24878','2064','V-PNP-ASM')" onmouseover="hl1('127372','24878','2064')" onmouseout="hl0('127372','24878','2064')" ondblclick="searchWord(2,127372)">ἐρχόμενον</grk></wform><br><wsbl>erchomenon</wsbl><br><wphono>erkhomenon</wphono><br><ref onclick="lex('G2064')" ondblclick="searchLexicalEntry('G2064')"><wlex><grk>ἔρχομαι</grk></wlex></ref><br><ref onclick="rmac('V-PNP-ASM')"><wmorph>V-PNP-ASM</wmorph></ref><br><ref onclick="lex('G2064')" ondblclick="searchLexicalEntry('G2064')"><wsn>G2064</wsn></ref><br><wgloss>to come/go</wgloss><br><wtrans>coming</wtrans></div> <div class='int'><wform><grk id="w127373" cl='c24878' sn='G1722' morph='PREP' class="c24878 G1722" onclick="luW(7,'127373','24878','1722','PREP')" onmouseover="hl1('127373','24878','1722')" onmouseout="hl0('127373','24878','1722')" ondblclick="searchWord(2,127373)">ἐν</grk></wform><br><wsbl>en</wsbl><br><wphono>en</wphono><br><ref onclick="lex('G1722')" ondblclick="searchLexicalEntry('G1722')"><wlex><grk>ἐν</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G1722')" ondblclick="searchLexicalEntry('G1722')"><wsn>G1722</wsn></ref><br><wgloss>in/on/among</wgloss><br><wtrans>in</wtrans></div> <div class='int'><wform><grk id="w127374" cl='c24878' sn='G4561' morph='N-DSF' class="c24878 G4561" onclick="luW(7,'127374','24878','4561','N-DSF')" onmouseover="hl1('127374','24878','4561')" onmouseout="hl0('127374','24878','4561')" ondblclick="searchWord(2,127374)">σαρκί</grk></wform><br><wsbl>sarki</wsbl><br><wphono>sarkiy</wphono><br><ref onclick="lex('G4561')" ondblclick="searchLexicalEntry('G4561')"><wlex><grk>σάρξ</grk></wlex></ref><br><ref onclick="rmac('N-DSF')"><wmorph>N-DSF</wmorph></ref><br><ref onclick="lex('G4561')" ondblclick="searchLexicalEntry('G4561')"><wsn>G4561</wsn></ref><br><wgloss>flesh</wgloss><br><wtrans>flesh.</wtrans></div> <div class='int'><wform><grk id="w127375" cl='c24879' sn='G3778' morph='D-NSM' class="c24879 G3778" onclick="luW(7,'127375','24879','3778','D-NSM')" onmouseover="hl1('127375','24879','3778')" onmouseout="hl0('127375','24879','3778')" ondblclick="searchWord(2,127375)">οὗτός</grk></wform><br><wsbl>houtos</wsbl><br><wphono>utos</wphono><br><ref onclick="lex('G3778')" ondblclick="searchLexicalEntry('G3778')"><wlex><grk>οὗτος</grk></wlex></ref><br><ref onclick="rmac('D-NSM')"><wmorph>D-NSM</wmorph></ref><br><ref onclick="lex('G3778')" ondblclick="searchLexicalEntry('G3778')"><wsn>G3778</wsn></ref><br><wgloss>this/he/she/it</wgloss><br><wtrans>This</wtrans></div> <div class='int'><wform><grk id="w127376" cl='c24879' sn='G1510' morph='V-PAI-3S' class="c24879 G1510" onclick="luW(7,'127376','24879','1510','V-PAI-3S')" onmouseover="hl1('127376','24879','1510')" onmouseout="hl0('127376','24879','1510')" ondblclick="searchWord(2,127376)">ἐστιν</grk></wform><br><wsbl>estin</wsbl><br><wphono>estiyn</wphono><br><ref onclick="lex('G1510')" ondblclick="searchLexicalEntry('G1510')"><wlex><grk>εἰμί</grk></wlex></ref><br><ref onclick="rmac('V-PAI-3S')"><wmorph>V-PAI-3S</wmorph></ref><br><ref onclick="lex('G1510')" ondblclick="searchLexicalEntry('G1510')"><wsn>G1510</wsn></ref><br><wgloss>to be</wgloss><br><wtrans>is</wtrans></div> <div class='int'><wform><grk id="w127377" cl='c24879' sn='G3588' morph='T-NSM' class="c24879 G3588" onclick="luW(7,'127377','24879','3588','T-NSM')" onmouseover="hl1('127377','24879','3588')" onmouseout="hl0('127377','24879','3588')" ondblclick="searchWord(2,127377)">ὁ</grk></wform><br><wsbl>ho</wsbl><br><wphono>o</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-NSM')"><wmorph>T-NSM</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127378" cl='c24879' sn='G4108' morph='A-NSM' class="c24879 G4108" onclick="luW(7,'127378','24879','4108','A-NSM')" onmouseover="hl1('127378','24879','4108')" onmouseout="hl0('127378','24879','4108')" ondblclick="searchWord(2,127378)">πλάνος</grk></wform><br><wsbl>planos</wsbl><br><wphono>planos</wphono><br><ref onclick="lex('G4108')" ondblclick="searchLexicalEntry('G4108')"><wlex><grk>πλάνος</grk></wlex></ref><br><ref onclick="rmac('A-NSM')"><wmorph>A-NSM</wmorph></ref><br><ref onclick="lex('G4108')" ondblclick="searchLexicalEntry('G4108')"><wsn>G4108</wsn></ref><br><wgloss>deceiving</wgloss><br><wtrans>deceiver</wtrans></div> <div class='int'><wform><grk id="w127379" cl='c24879' sn='G2532' morph='CONJ' class="c24879 G2532" onclick="luW(7,'127379','24879','2532','CONJ')" onmouseover="hl1('127379','24879','2532')" onmouseout="hl0('127379','24879','2532')" ondblclick="searchWord(2,127379)">καὶ</grk></wform><br><wsbl>kai</wsbl><br><wphono>ke</wphono><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wlex><grk>καί</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wsn>G2532</wsn></ref><br><wgloss>and</wgloss><br><wtrans>and</wtrans></div> <div class='int'><wform><grk id="w127380" cl='c24879' sn='G3588' morph='T-NSM' class="c24879 G3588" onclick="luW(7,'127380','24879','3588','T-NSM')" onmouseover="hl1('127380','24879','3588')" onmouseout="hl0('127380','24879','3588')" ondblclick="searchWord(2,127380)">ὁ</grk></wform><br><wsbl>ho</wsbl><br><wphono>o</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-NSM')"><wmorph>T-NSM</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127381" cl='c24879' sn='G500' morph='N-NSM' class="c24879 G500" onclick="luW(7,'127381','24879','500','N-NSM')" onmouseover="hl1('127381','24879','500')" onmouseout="hl0('127381','24879','500')" ondblclick="searchWord(2,127381)">ἀντίχριστος</grk></wform><br><wsbl>antichristos</wsbl><br><wphono>antiykhriystos</wphono><br><ref onclick="lex('G500')" ondblclick="searchLexicalEntry('G500')"><wlex><grk>ἀντίχριστος</grk></wlex></ref><br><ref onclick="rmac('N-NSM')"><wmorph>N-NSM</wmorph></ref><br><ref onclick="lex('G500')" ondblclick="searchLexicalEntry('G500')"><wsn>G500</wsn></ref><br><wgloss>antichrist</wgloss><br><wtrans>antichrist.</wtrans></div><br></verse> <verse><vid id="v63.1.8" onclick="luV(8)">8</vid> <br><div class='int'><wform><grk id="w127382" cl='c24880' sn='G991' morph='V-PAM-2P' class="c24880 G991" onclick="luW(8,'127382','24880','991','V-PAM-2P')" onmouseover="hl1('127382','24880','991')" onmouseout="hl0('127382','24880','991')" ondblclick="searchWord(2,127382)">βλέπετε</grk></wform><br><wsbl>blepete</wsbl><br><wphono>vlepete</wphono><br><ref onclick="lex('G991')" ondblclick="searchLexicalEntry('G991')"><wlex><grk>βλέπω</grk></wlex></ref><br><ref onclick="rmac('V-PAM-2P')"><wmorph>V-PAM-2P</wmorph></ref><br><ref onclick="lex('G991')" ondblclick="searchLexicalEntry('G991')"><wsn>G991</wsn></ref><br><wgloss>to see</wgloss><br><wtrans>Watch</wtrans></div> <div class='int'><wform><grk id="w127383" cl='c24880' sn='G1438' morph='F-2APM' class="c24880 G1438" onclick="luW(8,'127383','24880','1438','F-2APM')" onmouseover="hl1('127383','24880','1438')" onmouseout="hl0('127383','24880','1438')" ondblclick="searchWord(2,127383)">ἑαυτούς</grk></wform><br><wsbl>heautous</wsbl><br><wphono>eaftus</wphono><br><ref onclick="lex('G1438')" ondblclick="searchLexicalEntry('G1438')"><wlex><grk>ἑαυτοῦ</grk></wlex></ref><br><ref onclick="rmac('F-2APM')"><wmorph>F-2APM</wmorph></ref><br><ref onclick="lex('G1438')" ondblclick="searchLexicalEntry('G1438')"><wsn>G1438</wsn></ref><br><wgloss>my/your/him-self</wgloss><br><wtrans>yourselves,</wtrans></div> <div class='int'><wform><grk id="w127384" cl='c24881' sn='G2443' morph='CONJ' class="c24881 G2443" onclick="luW(8,'127384','24881','2443','CONJ')" onmouseover="hl1('127384','24881','2443')" onmouseout="hl0('127384','24881','2443')" ondblclick="searchWord(2,127384)">ἵνα</grk></wform><br><wsbl>hina</wsbl><br><wphono>iyna</wphono><br><ref onclick="lex('G2443')" ondblclick="searchLexicalEntry('G2443')"><wlex><grk>ἵνα</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2443')" ondblclick="searchLexicalEntry('G2443')"><wsn>G2443</wsn></ref><br><wgloss>in order that/to</wgloss><br><wtrans>so that</wtrans></div> <div class='int'><wform><grk id="w127385" cl='c24881' sn='G3361' morph='PRT-N' class="c24881 G3361" onclick="luW(8,'127385','24881','3361','PRT-N')" onmouseover="hl1('127385','24881','3361')" onmouseout="hl0('127385','24881','3361')" ondblclick="searchWord(2,127385)">μὴ</grk></wform><br><wsbl>mē</wsbl><br><wphono>miy</wphono><br><ref onclick="lex('G3361')" ondblclick="searchLexicalEntry('G3361')"><wlex><grk>μή</grk></wlex></ref><br><ref onclick="rmac('PRT-N')"><wmorph>PRT-N</wmorph></ref><br><ref onclick="lex('G3361')" ondblclick="searchLexicalEntry('G3361')"><wsn>G3361</wsn></ref><br><wgloss>not</wgloss><br><wtrans>not</wtrans></div> <div class='int'><wform><grk id="w127386" cl='c24881' sn='G622' morph='V-AAS-2P' class="c24881 G622" onclick="luW(8,'127386','24881','622','V-AAS-2P')" onmouseover="hl1('127386','24881','622')" onmouseout="hl0('127386','24881','622')" ondblclick="searchWord(2,127386)">ἀπολέσητε</grk></wform><br><wsbl>apolesēte</wsbl><br><wphono>apolesiyte</wphono><br><ref onclick="lex('G622')" ondblclick="searchLexicalEntry('G622')"><wlex><grk>ἀπολλύω</grk></wlex></ref><br><ref onclick="rmac('V-AAS-2P')"><wmorph>V-AAS-2P</wmorph></ref><br><ref onclick="lex('G622')" ondblclick="searchLexicalEntry('G622')"><wsn>G622</wsn></ref><br><wgloss>to destroy</wgloss><br><wtrans>you should lose</wtrans></div> <div class='int'><wform><grk id="w127387" cl='c24881' sn='G3739' morph='R-APN' class="c24881 G3739" onclick="luW(8,'127387','24881','3739','R-APN')" onmouseover="hl1('127387','24881','3739')" onmouseout="hl0('127387','24881','3739')" ondblclick="searchWord(2,127387)">ἃ</grk></wform><br><wsbl>ha</wsbl><br><wphono>a</wphono><br><ref onclick="lex('G3739')" ondblclick="searchLexicalEntry('G3739')"><wlex><grk>ὅς, ἥ</grk></wlex></ref><br><ref onclick="rmac('R-APN')"><wmorph>R-APN</wmorph></ref><br><ref onclick="lex('G3739')" ondblclick="searchLexicalEntry('G3739')"><wsn>G3739</wsn></ref><br><wgloss>which</wgloss><br><wtrans>what things</wtrans></div> <div class='int'><wform><grk id="w127388" cl='c24881' sn='G2038' morph='V-ADI-1P' class="c24881 G2038" onclick="luW(8,'127388','24881','2038','V-ADI-1P')" onmouseover="hl1('127388','24881','2038')" onmouseout="hl0('127388','24881','2038')" ondblclick="searchWord(2,127388)">εἰργασάμεθα</grk></wform><br><wsbl>eirgasametha</wsbl><br><wphono>iyrgasameθa</wphono><br><ref onclick="lex('G2038')" ondblclick="searchLexicalEntry('G2038')"><wlex><grk>ἐργάζομαι</grk></wlex></ref><br><ref onclick="rmac('V-ADI-1P')"><wmorph>V-ADI-1P</wmorph></ref><br><ref onclick="lex('G2038')" ondblclick="searchLexicalEntry('G2038')"><wsn>G2038</wsn></ref><br><wgloss>to work</wgloss><br><wtrans>we have worked for,</wtrans></div> <div class='int'><wform><grk id="w127389" cl='c24882' sn='G235' morph='CONJ' class="c24882 G235" onclick="luW(8,'127389','24882','235','CONJ')" onmouseover="hl1('127389','24882','235')" onmouseout="hl0('127389','24882','235')" ondblclick="searchWord(2,127389)">ἀλλὰ</grk></wform><br><wsbl>alla</wsbl><br><wphono>alla</wphono><br><ref onclick="lex('G235')" ondblclick="searchLexicalEntry('G235')"><wlex><grk>ἀλλά</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G235')" ondblclick="searchLexicalEntry('G235')"><wsn>G235</wsn></ref><br><wgloss>but</wgloss><br><wtrans>but</wtrans></div> <div class='int'><wform><grk id="w127390" cl='c24882' sn='G3408' morph='N-ASM' class="c24882 G3408" onclick="luW(8,'127390','24882','3408','N-ASM')" onmouseover="hl1('127390','24882','3408')" onmouseout="hl0('127390','24882','3408')" ondblclick="searchWord(2,127390)">μισθὸν</grk></wform><br><wsbl>misthon</wsbl><br><wphono>miysθon</wphono><br><ref onclick="lex('G3408')" ondblclick="searchLexicalEntry('G3408')"><wlex><grk>μισθός</grk></wlex></ref><br><ref onclick="rmac('N-ASM')"><wmorph>N-ASM</wmorph></ref><br><ref onclick="lex('G3408')" ondblclick="searchLexicalEntry('G3408')"><wsn>G3408</wsn></ref><br><wgloss>wage</wgloss><br><wtrans>a reward</wtrans></div> <div class='int'><wform><grk id="w127391" cl='c24882' sn='G4134' morph='A-ASM' class="c24882 G4134" onclick="luW(8,'127391','24882','4134','A-ASM')" onmouseover="hl1('127391','24882','4134')" onmouseout="hl0('127391','24882','4134')" ondblclick="searchWord(2,127391)">πλήρη</grk></wform><br><wsbl>plērē</wsbl><br><wphono>pliyriy</wphono><br><ref onclick="lex('G4134')" ondblclick="searchLexicalEntry('G4134')"><wlex><grk>πλήρης</grk></wlex></ref><br><ref onclick="rmac('A-ASM')"><wmorph>A-ASM</wmorph></ref><br><ref onclick="lex('G4134')" ondblclick="searchLexicalEntry('G4134')"><wsn>G4134</wsn></ref><br><wgloss>full</wgloss><br><wtrans>full</wtrans></div> <div class='int'><wform><grk id="w127392" cl='c24882' sn='G618' morph='V-2AAS-2P' class="c24882 G618" onclick="luW(8,'127392','24882','618','V-2AAS-2P')" onmouseover="hl1('127392','24882','618')" onmouseout="hl0('127392','24882','618')" ondblclick="searchWord(2,127392)">ἀπολάβητε</grk></wform><br><wsbl>apolabēte</wsbl><br><wphono>apolaviyte</wphono><br><ref onclick="lex('G618')" ondblclick="searchLexicalEntry('G618')"><wlex><grk>ἀπολαμβάνω</grk></wlex></ref><br><ref onclick="rmac('V-2AAS-2P')"><wmorph>V-2AAS-2P</wmorph></ref><br><ref onclick="lex('G618')" ondblclick="searchLexicalEntry('G618')"><wsn>G618</wsn></ref><br><wgloss>to get back</wgloss><br><wtrans>you may receive.</wtrans></div><br></verse> <verse><vid id="v63.1.9" onclick="luV(9)">9</vid> <br><div class='int'><wform><grk id="w127393" cl='c24883' sn='G3956' morph='A-NSM' class="c24883 G3956" onclick="luW(9,'127393','24883','3956','A-NSM')" onmouseover="hl1('127393','24883','3956')" onmouseout="hl0('127393','24883','3956')" ondblclick="searchWord(2,127393)">πᾶς</grk></wform><br><wsbl>pas</wsbl><br><wphono>pas</wphono><br><ref onclick="lex('G3956')" ondblclick="searchLexicalEntry('G3956')"><wlex><grk>πᾶς</grk></wlex></ref><br><ref onclick="rmac('A-NSM')"><wmorph>A-NSM</wmorph></ref><br><ref onclick="lex('G3956')" ondblclick="searchLexicalEntry('G3956')"><wsn>G3956</wsn></ref><br><wgloss>all</wgloss><br><wtrans>Anyone</wtrans></div> <div class='int'><wform><grk id="w127394" cl='c24883' sn='G3588' morph='T-NSM' class="c24883 G3588" onclick="luW(9,'127394','24883','3588','T-NSM')" onmouseover="hl1('127394','24883','3588')" onmouseout="hl0('127394','24883','3588')" ondblclick="searchWord(2,127394)">ὁ</grk></wform><br><wsbl>ho</wsbl><br><wphono>o</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-NSM')"><wmorph>T-NSM</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>-</wtrans></div> <div class='int'><wform><grk id="w127395" cl='c24883' sn='G4254' morph='V-PAP-NSM' class="c24883 G4254" onclick="luW(9,'127395','24883','4254','V-PAP-NSM')" onmouseover="hl1('127395','24883','4254')" onmouseout="hl0('127395','24883','4254')" ondblclick="searchWord(2,127395)">προάγων</grk></wform><br><wsbl>proagōn</wsbl><br><wphono>proagon</wphono><br><ref onclick="lex('G4254')" ondblclick="searchLexicalEntry('G4254')"><wlex><grk>προάγω</grk></wlex></ref><br><ref onclick="rmac('V-PAP-NSM')"><wmorph>V-PAP-NSM</wmorph></ref><br><ref onclick="lex('G4254')" ondblclick="searchLexicalEntry('G4254')"><wsn>G4254</wsn></ref><br><wgloss>to go/bring before</wgloss><br><wtrans>going on ahead</wtrans></div> <div class='int'><wform><grk id="w127396" cl='c24884' sn='G2532' morph='CONJ' class="c24884 G2532" onclick="luW(9,'127396','24884','2532','CONJ')" onmouseover="hl1('127396','24884','2532')" onmouseout="hl0('127396','24884','2532')" ondblclick="searchWord(2,127396)">καὶ</grk></wform><br><wsbl>kai</wsbl><br><wphono>ke</wphono><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wlex><grk>καί</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wsn>G2532</wsn></ref><br><wgloss>and</wgloss><br><wtrans>and</wtrans></div> <div class='int'><wform><grk id="w127397" cl='c24884' sn='G3361' morph='PRT-N' class="c24884 G3361" onclick="luW(9,'127397','24884','3361','PRT-N')" onmouseover="hl1('127397','24884','3361')" onmouseout="hl0('127397','24884','3361')" ondblclick="searchWord(2,127397)">μὴ</grk></wform><br><wsbl>mē</wsbl><br><wphono>miy</wphono><br><ref onclick="lex('G3361')" ondblclick="searchLexicalEntry('G3361')"><wlex><grk>μή</grk></wlex></ref><br><ref onclick="rmac('PRT-N')"><wmorph>PRT-N</wmorph></ref><br><ref onclick="lex('G3361')" ondblclick="searchLexicalEntry('G3361')"><wsn>G3361</wsn></ref><br><wgloss>not</wgloss><br><wtrans>not</wtrans></div> <div class='int'><wform><grk id="w127398" cl='c24884' sn='G3306' morph='V-PAP-NSM' class="c24884 G3306" onclick="luW(9,'127398','24884','3306','V-PAP-NSM')" onmouseover="hl1('127398','24884','3306')" onmouseout="hl0('127398','24884','3306')" ondblclick="searchWord(2,127398)">μένων</grk></wform><br><wsbl>menōn</wsbl><br><wphono>menon</wphono><br><ref onclick="lex('G3306')" ondblclick="searchLexicalEntry('G3306')"><wlex><grk>μένω</grk></wlex></ref><br><ref onclick="rmac('V-PAP-NSM')"><wmorph>V-PAP-NSM</wmorph></ref><br><ref onclick="lex('G3306')" ondblclick="searchLexicalEntry('G3306')"><wsn>G3306</wsn></ref><br><wgloss>to stay</wgloss><br><wtrans>abiding</wtrans></div> <div class='int'><wform><grk id="w127399" cl='c24884' sn='G1722' morph='PREP' class="c24884 G1722" onclick="luW(9,'127399','24884','1722','PREP')" onmouseover="hl1('127399','24884','1722')" onmouseout="hl0('127399','24884','1722')" ondblclick="searchWord(2,127399)">ἐν</grk></wform><br><wsbl>en</wsbl><br><wphono>en</wphono><br><ref onclick="lex('G1722')" ondblclick="searchLexicalEntry('G1722')"><wlex><grk>ἐν</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G1722')" ondblclick="searchLexicalEntry('G1722')"><wsn>G1722</wsn></ref><br><wgloss>in/on/among</wgloss><br><wtrans>in</wtrans></div> <div class='int'><wform><grk id="w127400" cl='c24884' sn='G3588' morph='T-DSF' class="c24884 G3588" onclick="luW(9,'127400','24884','3588','T-DSF')" onmouseover="hl1('127400','24884','3588')" onmouseout="hl0('127400','24884','3588')" ondblclick="searchWord(2,127400)">τῇ</grk></wform><br><wsbl>tē</wsbl><br><wphono>tiy</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-DSF')"><wmorph>T-DSF</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127401" cl='c24884' sn='G1322' morph='N-DSF' class="c24884 G1322" onclick="luW(9,'127401','24884','1322','N-DSF')" onmouseover="hl1('127401','24884','1322')" onmouseout="hl0('127401','24884','1322')" ondblclick="searchWord(2,127401)">διδαχῇ</grk></wform><br><wsbl>didachē</wsbl><br><wphono>ðiyðakhiy</wphono><br><ref onclick="lex('G1322')" ondblclick="searchLexicalEntry('G1322')"><wlex><grk>διδαχή</grk></wlex></ref><br><ref onclick="rmac('N-DSF')"><wmorph>N-DSF</wmorph></ref><br><ref onclick="lex('G1322')" ondblclick="searchLexicalEntry('G1322')"><wsn>G1322</wsn></ref><br><wgloss>teaching</wgloss><br><wtrans>teaching</wtrans></div> <div class='int'><wform><grk id="w127402" cl='c24884' sn='G3588' morph='T-GSM' class="c24884 G3588" onclick="luW(9,'127402','24884','3588','T-GSM')" onmouseover="hl1('127402','24884','3588')" onmouseout="hl0('127402','24884','3588')" ondblclick="searchWord(2,127402)">τοῦ</grk></wform><br><wsbl>tou</wsbl><br><wphono>tu</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-GSM')"><wmorph>T-GSM</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>-</wtrans></div> <div class='int'><wform><grk id="w127403" cl='c24884' sn='G5547' morph='N-GSM-T' class="c24884 G5547" onclick="luW(9,'127403','24884','5547','N-GSM-T')" onmouseover="hl1('127403','24884','5547')" onmouseout="hl0('127403','24884','5547')" ondblclick="searchWord(2,127403)">Χριστοῦ</grk></wform><br><wsbl>Christou</wsbl><br><wphono>khriystu</wphono><br><ref onclick="lex('G5547')" ondblclick="searchLexicalEntry('G5547')"><wlex><grk>Χριστός</grk></wlex></ref><br><ref onclick="rmac('N-GSM-T')"><wmorph>N-GSM-T</wmorph></ref><br><ref onclick="lex('G5547')" ondblclick="searchLexicalEntry('G5547')"><wsn>G5547</wsn></ref><br><wgloss>Christ</wgloss><br><wtrans>of Christ,</wtrans></div> <div class='int'><wform><grk id="w127404" cl='c24884' sn='G2316' morph='N-ASM' class="c24884 G2316" onclick="luW(9,'127404','24884','2316','N-ASM')" onmouseover="hl1('127404','24884','2316')" onmouseout="hl0('127404','24884','2316')" ondblclick="searchWord(2,127404)">Θεὸν</grk></wform><br><wsbl>Theon</wsbl><br><wphono>θeon</wphono><br><ref onclick="lex('G2316')" ondblclick="searchLexicalEntry('G2316')"><wlex><grk>θεός</grk></wlex></ref><br><ref onclick="rmac('N-ASM')"><wmorph>N-ASM</wmorph></ref><br><ref onclick="lex('G2316')" ondblclick="searchLexicalEntry('G2316')"><wsn>G2316</wsn></ref><br><wgloss>God</wgloss><br><wtrans>God</wtrans></div> <div class='int'><wform><grk id="w127405" cl='c24884' sn='G3756' morph='PRT-N' class="c24884 G3756" onclick="luW(9,'127405','24884','3756','PRT-N')" onmouseover="hl1('127405','24884','3756')" onmouseout="hl0('127405','24884','3756')" ondblclick="searchWord(2,127405)">οὐκ</grk></wform><br><wsbl>ouk</wsbl><br><wphono>uk</wphono><br><ref onclick="lex('G3756')" ondblclick="searchLexicalEntry('G3756')"><wlex><grk>οὐ</grk></wlex></ref><br><ref onclick="rmac('PRT-N')"><wmorph>PRT-N</wmorph></ref><br><ref onclick="lex('G3756')" ondblclick="searchLexicalEntry('G3756')"><wsn>G3756</wsn></ref><br><wgloss>no</wgloss><br><wtrans>not</wtrans></div> <div class='int'><wform><grk id="w127406" cl='c24884' sn='G2192' morph='V-PAI-3S' class="c24884 G2192" onclick="luW(9,'127406','24884','2192','V-PAI-3S')" onmouseover="hl1('127406','24884','2192')" onmouseout="hl0('127406','24884','2192')" ondblclick="searchWord(2,127406)">ἔχει</grk></wform><br><wsbl>echei</wsbl><br><wphono>ekhiy</wphono><br><ref onclick="lex('G2192')" ondblclick="searchLexicalEntry('G2192')"><wlex><grk>ἔχω</grk></wlex></ref><br><ref onclick="rmac('V-PAI-3S')"><wmorph>V-PAI-3S</wmorph></ref><br><ref onclick="lex('G2192')" ondblclick="searchLexicalEntry('G2192')"><wsn>G2192</wsn></ref><br><wgloss>to have/be</wgloss><br><wtrans>has.</wtrans></div> <div class='int'><wform><grk id="w127407" cl='c24885' sn='G3588' morph='T-NSM' class="c24885 G3588" onclick="luW(9,'127407','24885','3588','T-NSM')" onmouseover="hl1('127407','24885','3588')" onmouseout="hl0('127407','24885','3588')" ondblclick="searchWord(2,127407)">ὁ</grk></wform><br><wsbl>ho</wsbl><br><wphono>o</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-NSM')"><wmorph>T-NSM</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>The [one]</wtrans></div> <div class='int'><wform><grk id="w127408" cl='c24885' sn='G3306' morph='V-PAP-NSM' class="c24885 G3306" onclick="luW(9,'127408','24885','3306','V-PAP-NSM')" onmouseover="hl1('127408','24885','3306')" onmouseout="hl0('127408','24885','3306')" ondblclick="searchWord(2,127408)">μένων</grk></wform><br><wsbl>menōn</wsbl><br><wphono>menon</wphono><br><ref onclick="lex('G3306')" ondblclick="searchLexicalEntry('G3306')"><wlex><grk>μένω</grk></wlex></ref><br><ref onclick="rmac('V-PAP-NSM')"><wmorph>V-PAP-NSM</wmorph></ref><br><ref onclick="lex('G3306')" ondblclick="searchLexicalEntry('G3306')"><wsn>G3306</wsn></ref><br><wgloss>to stay</wgloss><br><wtrans>abiding</wtrans></div> <div class='int'><wform><grk id="w127409" cl='c24885' sn='G1722' morph='PREP' class="c24885 G1722" onclick="luW(9,'127409','24885','1722','PREP')" onmouseover="hl1('127409','24885','1722')" onmouseout="hl0('127409','24885','1722')" ondblclick="searchWord(2,127409)">ἐν</grk></wform><br><wsbl>en</wsbl><br><wphono>en</wphono><br><ref onclick="lex('G1722')" ondblclick="searchLexicalEntry('G1722')"><wlex><grk>ἐν</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G1722')" ondblclick="searchLexicalEntry('G1722')"><wsn>G1722</wsn></ref><br><wgloss>in/on/among</wgloss><br><wtrans>in</wtrans></div> <div class='int'><wform><grk id="w127410" cl='c24885' sn='G3588' morph='T-DSF' class="c24885 G3588" onclick="luW(9,'127410','24885','3588','T-DSF')" onmouseover="hl1('127410','24885','3588')" onmouseout="hl0('127410','24885','3588')" ondblclick="searchWord(2,127410)">τῇ</grk></wform><br><wsbl>tē</wsbl><br><wphono>tiy</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-DSF')"><wmorph>T-DSF</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127411" cl='c24885' sn='G1322' morph='N-DSF' class="c24885 G1322" onclick="luW(9,'127411','24885','1322','N-DSF')" onmouseover="hl1('127411','24885','1322')" onmouseout="hl0('127411','24885','1322')" ondblclick="searchWord(2,127411)">διδαχῇ</grk></wform><br><wsbl>didachē</wsbl><br><wphono>ðiyðakhiy</wphono><br><ref onclick="lex('G1322')" ondblclick="searchLexicalEntry('G1322')"><wlex><grk>διδαχή</grk></wlex></ref><br><ref onclick="rmac('N-DSF')"><wmorph>N-DSF</wmorph></ref><br><ref onclick="lex('G1322')" ondblclick="searchLexicalEntry('G1322')"><wsn>G1322</wsn></ref><br><wgloss>teaching</wgloss><br><wtrans>teaching,</wtrans></div> <div class='int'><wform><grk id="w127412" cl='c24886' sn='G3778' morph='D-NSM' class="c24886 G3778" onclick="luW(9,'127412','24886','3778','D-NSM')" onmouseover="hl1('127412','24886','3778')" onmouseout="hl0('127412','24886','3778')" ondblclick="searchWord(2,127412)">οὗτος</grk></wform><br><wsbl>houtos</wsbl><br><wphono>utos</wphono><br><ref onclick="lex('G3778')" ondblclick="searchLexicalEntry('G3778')"><wlex><grk>οὗτος</grk></wlex></ref><br><ref onclick="rmac('D-NSM')"><wmorph>D-NSM</wmorph></ref><br><ref onclick="lex('G3778')" ondblclick="searchLexicalEntry('G3778')"><wsn>G3778</wsn></ref><br><wgloss>this/he/she/it</wgloss><br><wtrans>this [one]</wtrans></div> <div class='int'><wform><grk id="w127413" cl='c24886' sn='G2532' morph='CONJ' class="c24886 G2532" onclick="luW(9,'127413','24886','2532','CONJ')" onmouseover="hl1('127413','24886','2532')" onmouseout="hl0('127413','24886','2532')" ondblclick="searchWord(2,127413)">καὶ</grk></wform><br><wsbl>kai</wsbl><br><wphono>ke</wphono><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wlex><grk>καί</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wsn>G2532</wsn></ref><br><wgloss>and</wgloss><br><wtrans>both</wtrans></div> <div class='int'><wform><grk id="w127414" cl='c24886' sn='G3588' morph='T-ASM' class="c24886 G3588" onclick="luW(9,'127414','24886','3588','T-ASM')" onmouseover="hl1('127414','24886','3588')" onmouseout="hl0('127414','24886','3588')" ondblclick="searchWord(2,127414)">τὸν</grk></wform><br><wsbl>ton</wsbl><br><wphono>ton</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-ASM')"><wmorph>T-ASM</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127415" cl='c24886' sn='G3962' morph='N-ASM' class="c24886 G3962" onclick="luW(9,'127415','24886','3962','N-ASM')" onmouseover="hl1('127415','24886','3962')" onmouseout="hl0('127415','24886','3962')" ondblclick="searchWord(2,127415)">Πατέρα</grk></wform><br><wsbl>Patera</wsbl><br><wphono>patera</wphono><br><ref onclick="lex('G3962')" ondblclick="searchLexicalEntry('G3962')"><wlex><grk>πατήρ</grk></wlex></ref><br><ref onclick="rmac('N-ASM')"><wmorph>N-ASM</wmorph></ref><br><ref onclick="lex('G3962')" ondblclick="searchLexicalEntry('G3962')"><wsn>G3962</wsn></ref><br><wgloss>father</wgloss><br><wtrans>Father</wtrans></div> <div class='int'><wform><grk id="w127416" cl='c24886' sn='G2532' morph='CONJ' class="c24886 G2532" onclick="luW(9,'127416','24886','2532','CONJ')" onmouseover="hl1('127416','24886','2532')" onmouseout="hl0('127416','24886','2532')" ondblclick="searchWord(2,127416)">καὶ</grk></wform><br><wsbl>kai</wsbl><br><wphono>ke</wphono><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wlex><grk>καί</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wsn>G2532</wsn></ref><br><wgloss>and</wgloss><br><wtrans>and</wtrans></div> <div class='int'><wform><grk id="w127417" cl='c24886' sn='G3588' morph='T-ASM' class="c24886 G3588" onclick="luW(9,'127417','24886','3588','T-ASM')" onmouseover="hl1('127417','24886','3588')" onmouseout="hl0('127417','24886','3588')" ondblclick="searchWord(2,127417)">τὸν</grk></wform><br><wsbl>ton</wsbl><br><wphono>ton</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-ASM')"><wmorph>T-ASM</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127418" cl='c24886' sn='G5207' morph='N-ASM' class="c24886 G5207" onclick="luW(9,'127418','24886','5207','N-ASM')" onmouseover="hl1('127418','24886','5207')" onmouseout="hl0('127418','24886','5207')" ondblclick="searchWord(2,127418)">Υἱὸν</grk></wform><br><wsbl>Huion</wsbl><br><wphono>iyon</wphono><br><ref onclick="lex('G5207')" ondblclick="searchLexicalEntry('G5207')"><wlex><grk>υἱός</grk></wlex></ref><br><ref onclick="rmac('N-ASM')"><wmorph>N-ASM</wmorph></ref><br><ref onclick="lex('G5207')" ondblclick="searchLexicalEntry('G5207')"><wsn>G5207</wsn></ref><br><wgloss>son</wgloss><br><wtrans>Son</wtrans></div> <div class='int'><wform><grk id="w127419" cl='c24886' sn='G2192' morph='V-PAI-3S' class="c24886 G2192" onclick="luW(9,'127419','24886','2192','V-PAI-3S')" onmouseover="hl1('127419','24886','2192')" onmouseout="hl0('127419','24886','2192')" ondblclick="searchWord(2,127419)">ἔχει</grk></wform><br><wsbl>echei</wsbl><br><wphono>ekhiy</wphono><br><ref onclick="lex('G2192')" ondblclick="searchLexicalEntry('G2192')"><wlex><grk>ἔχω</grk></wlex></ref><br><ref onclick="rmac('V-PAI-3S')"><wmorph>V-PAI-3S</wmorph></ref><br><ref onclick="lex('G2192')" ondblclick="searchLexicalEntry('G2192')"><wsn>G2192</wsn></ref><br><wgloss>to have/be</wgloss><br><wtrans>has.</wtrans></div><br></verse> <verse><vid id="v63.1.10" onclick="luV(10)">10</vid> <br><div class='int'><wform><grk id="w127420" cl='c24887' sn='G1487' morph='CONJ' class="c24887 G1487" onclick="luW(10,'127420','24887','1487','CONJ')" onmouseover="hl1('127420','24887','1487')" onmouseout="hl0('127420','24887','1487')" ondblclick="searchWord(2,127420)">Εἴ</grk></wform><br><wsbl>Ei</wsbl><br><wphono>iy</wphono><br><ref onclick="lex('G1487')" ondblclick="searchLexicalEntry('G1487')"><wlex><grk>εἰ</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G1487')" ondblclick="searchLexicalEntry('G1487')"><wsn>G1487</wsn></ref><br><wgloss>if</wgloss><br><wtrans>If</wtrans></div> <div class='int'><wform><grk id="w127421" cl='c24887' sn='G5100' morph='X-NSM' class="c24887 G5100" onclick="luW(10,'127421','24887','5100','X-NSM')" onmouseover="hl1('127421','24887','5100')" onmouseout="hl0('127421','24887','5100')" ondblclick="searchWord(2,127421)">τις</grk></wform><br><wsbl>tis</wsbl><br><wphono>tiys</wphono><br><ref onclick="lex('G5100')" ondblclick="searchLexicalEntry('G5100')"><wlex><grk>τις</grk></wlex></ref><br><ref onclick="rmac('X-NSM')"><wmorph>X-NSM</wmorph></ref><br><ref onclick="lex('G5100')" ondblclick="searchLexicalEntry('G5100')"><wsn>G5100</wsn></ref><br><wgloss>one</wgloss><br><wtrans>anyone</wtrans></div> <div class='int'><wform><grk id="w127422" cl='c24887' sn='G2064' morph='V-PNI-3S' class="c24887 G2064" onclick="luW(10,'127422','24887','2064','V-PNI-3S')" onmouseover="hl1('127422','24887','2064')" onmouseout="hl0('127422','24887','2064')" ondblclick="searchWord(2,127422)">ἔρχεται</grk></wform><br><wsbl>erchetai</wsbl><br><wphono>erkhete</wphono><br><ref onclick="lex('G2064')" ondblclick="searchLexicalEntry('G2064')"><wlex><grk>ἔρχομαι</grk></wlex></ref><br><ref onclick="rmac('V-PNI-3S')"><wmorph>V-PNI-3S</wmorph></ref><br><ref onclick="lex('G2064')" ondblclick="searchLexicalEntry('G2064')"><wsn>G2064</wsn></ref><br><wgloss>to come/go</wgloss><br><wtrans>comes</wtrans></div> <div class='int'><wform><grk id="w127423" cl='c24887' sn='G4314' morph='PREP' class="c24887 G4314" onclick="luW(10,'127423','24887','4314','PREP')" onmouseover="hl1('127423','24887','4314')" onmouseout="hl0('127423','24887','4314')" ondblclick="searchWord(2,127423)">πρὸς</grk></wform><br><wsbl>pros</wsbl><br><wphono>pros</wphono><br><ref onclick="lex('G4314')" ondblclick="searchLexicalEntry('G4314')"><wlex><grk>πρός</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G4314')" ondblclick="searchLexicalEntry('G4314')"><wsn>G4314</wsn></ref><br><wgloss>to/with</wgloss><br><wtrans>to</wtrans></div> <div class='int'><wform><grk id="w127424" cl='c24887' sn='G4771' morph='P-2AP' class="c24887 G4771" onclick="luW(10,'127424','24887','4771','P-2AP')" onmouseover="hl1('127424','24887','4771')" onmouseout="hl0('127424','24887','4771')" ondblclick="searchWord(2,127424)">ὑμᾶς</grk></wform><br><wsbl>hymas</wsbl><br><wphono>iymas</wphono><br><ref onclick="lex('G4771')" ondblclick="searchLexicalEntry('G4771')"><wlex><grk>σύ</grk></wlex></ref><br><ref onclick="rmac('P-2AP')"><wmorph>P-2AP</wmorph></ref><br><ref onclick="lex('G4771')" ondblclick="searchLexicalEntry('G4771')"><wsn>G4771</wsn></ref><br><wgloss>you</wgloss><br><wtrans>you</wtrans></div> <div class='int'><wform><grk id="w127425" cl='c24888' sn='G2532' morph='CONJ' class="c24888 G2532" onclick="luW(10,'127425','24888','2532','CONJ')" onmouseover="hl1('127425','24888','2532')" onmouseout="hl0('127425','24888','2532')" ondblclick="searchWord(2,127425)">καὶ</grk></wform><br><wsbl>kai</wsbl><br><wphono>ke</wphono><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wlex><grk>καί</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wsn>G2532</wsn></ref><br><wgloss>and</wgloss><br><wtrans>and</wtrans></div> <div class='int'><wform><grk id="w127426" cl='c24888' sn='G3778' morph='D-ASF' class="c24888 G3778" onclick="luW(10,'127426','24888','3778','D-ASF')" onmouseover="hl1('127426','24888','3778')" onmouseout="hl0('127426','24888','3778')" ondblclick="searchWord(2,127426)">ταύτην</grk></wform><br><wsbl>tautēn</wsbl><br><wphono>taftiyn</wphono><br><ref onclick="lex('G3778')" ondblclick="searchLexicalEntry('G3778')"><wlex><grk>οὗτος</grk></wlex></ref><br><ref onclick="rmac('D-ASF')"><wmorph>D-ASF</wmorph></ref><br><ref onclick="lex('G3778')" ondblclick="searchLexicalEntry('G3778')"><wsn>G3778</wsn></ref><br><wgloss>this/he/she/it</wgloss><br><wtrans>this</wtrans></div> <div class='int'><wform><grk id="w127427" cl='c24888' sn='G3588' morph='T-ASF' class="c24888 G3588" onclick="luW(10,'127427','24888','3588','T-ASF')" onmouseover="hl1('127427','24888','3588')" onmouseout="hl0('127427','24888','3588')" ondblclick="searchWord(2,127427)">τὴν</grk></wform><br><wsbl>tēn</wsbl><br><wphono>tiyn</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-ASF')"><wmorph>T-ASF</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>-</wtrans></div> <div class='int'><wform><grk id="w127428" cl='c24888' sn='G1322' morph='N-ASF' class="c24888 G1322" onclick="luW(10,'127428','24888','1322','N-ASF')" onmouseover="hl1('127428','24888','1322')" onmouseout="hl0('127428','24888','1322')" ondblclick="searchWord(2,127428)">διδαχὴν</grk></wform><br><wsbl>didachēn</wsbl><br><wphono>ðiyðakhiyn</wphono><br><ref onclick="lex('G1322')" ondblclick="searchLexicalEntry('G1322')"><wlex><grk>διδαχή</grk></wlex></ref><br><ref onclick="rmac('N-ASF')"><wmorph>N-ASF</wmorph></ref><br><ref onclick="lex('G1322')" ondblclick="searchLexicalEntry('G1322')"><wsn>G1322</wsn></ref><br><wgloss>teaching</wgloss><br><wtrans>teaching</wtrans></div> <div class='int'><wform><grk id="w127429" cl='c24888' sn='G3756' morph='PRT-N' class="c24888 G3756" onclick="luW(10,'127429','24888','3756','PRT-N')" onmouseover="hl1('127429','24888','3756')" onmouseout="hl0('127429','24888','3756')" ondblclick="searchWord(2,127429)">οὐ</grk></wform><br><wsbl>ou</wsbl><br><wphono>u</wphono><br><ref onclick="lex('G3756')" ondblclick="searchLexicalEntry('G3756')"><wlex><grk>οὐ</grk></wlex></ref><br><ref onclick="rmac('PRT-N')"><wmorph>PRT-N</wmorph></ref><br><ref onclick="lex('G3756')" ondblclick="searchLexicalEntry('G3756')"><wsn>G3756</wsn></ref><br><wgloss>no</wgloss><br><wtrans>not</wtrans></div> <div class='int'><wform><grk id="w127430" cl='c24888' sn='G5342' morph='V-PAI-3S' class="c24888 G5342" onclick="luW(10,'127430','24888','5342','V-PAI-3S')" onmouseover="hl1('127430','24888','5342')" onmouseout="hl0('127430','24888','5342')" ondblclick="searchWord(2,127430)">φέρει</grk></wform><br><wsbl>pherei</wsbl><br><wphono>feriy</wphono><br><ref onclick="lex('G5342')" ondblclick="searchLexicalEntry('G5342')"><wlex><grk>φέρω</grk></wlex></ref><br><ref onclick="rmac('V-PAI-3S')"><wmorph>V-PAI-3S</wmorph></ref><br><ref onclick="lex('G5342')" ondblclick="searchLexicalEntry('G5342')"><wsn>G5342</wsn></ref><br><wgloss>to bear/lead</wgloss><br><wtrans>does bring,</wtrans></div> <div class='int'><wform><grk id="w127431" cl='c24889' sn='G3361' morph='PRT-N' class="c24889 G3361" onclick="luW(10,'127431','24889','3361','PRT-N')" onmouseover="hl1('127431','24889','3361')" onmouseout="hl0('127431','24889','3361')" ondblclick="searchWord(2,127431)">μὴ</grk></wform><br><wsbl>mē</wsbl><br><wphono>miy</wphono><br><ref onclick="lex('G3361')" ondblclick="searchLexicalEntry('G3361')"><wlex><grk>μή</grk></wlex></ref><br><ref onclick="rmac('PRT-N')"><wmorph>PRT-N</wmorph></ref><br><ref onclick="lex('G3361')" ondblclick="searchLexicalEntry('G3361')"><wsn>G3361</wsn></ref><br><wgloss>not</wgloss><br><wtrans>not</wtrans></div> <div class='int'><wform><grk id="w127432" cl='c24889' sn='G2983' morph='V-PAM-2P' class="c24889 G2983" onclick="luW(10,'127432','24889','2983','V-PAM-2P')" onmouseover="hl1('127432','24889','2983')" onmouseout="hl0('127432','24889','2983')" ondblclick="searchWord(2,127432)">λαμβάνετε</grk></wform><br><wsbl>lambanete</wsbl><br><wphono>lamvanete</wphono><br><ref onclick="lex('G2983')" ondblclick="searchLexicalEntry('G2983')"><wlex><grk>λαμβάνω</grk></wlex></ref><br><ref onclick="rmac('V-PAM-2P')"><wmorph>V-PAM-2P</wmorph></ref><br><ref onclick="lex('G2983')" ondblclick="searchLexicalEntry('G2983')"><wsn>G2983</wsn></ref><br><wgloss>to take</wgloss><br><wtrans>receive</wtrans></div> <div class='int'><wform><grk id="w127433" cl='c24889' sn='G846' morph='P-ASM' class="c24889 G846" onclick="luW(10,'127433','24889','846','P-ASM')" onmouseover="hl1('127433','24889','846')" onmouseout="hl0('127433','24889','846')" ondblclick="searchWord(2,127433)">αὐτὸν</grk></wform><br><wsbl>auton</wsbl><br><wphono>afton</wphono><br><ref onclick="lex('G846')" ondblclick="searchLexicalEntry('G846')"><wlex><grk>αὐτός</grk></wlex></ref><br><ref onclick="rmac('P-ASM')"><wmorph>P-ASM</wmorph></ref><br><ref onclick="lex('G846')" ondblclick="searchLexicalEntry('G846')"><wsn>G846</wsn></ref><br><wgloss>he/she/it/self</wgloss><br><wtrans>him</wtrans></div> <div class='int'><wform><grk id="w127434" cl='c24889' sn='G1519' morph='PREP' class="c24889 G1519" onclick="luW(10,'127434','24889','1519','PREP')" onmouseover="hl1('127434','24889','1519')" onmouseout="hl0('127434','24889','1519')" ondblclick="searchWord(2,127434)">εἰς</grk></wform><br><wsbl>eis</wsbl><br><wphono>iys</wphono><br><ref onclick="lex('G1519')" ondblclick="searchLexicalEntry('G1519')"><wlex><grk>εἰς</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G1519')" ondblclick="searchLexicalEntry('G1519')"><wsn>G1519</wsn></ref><br><wgloss>toward</wgloss><br><wtrans>into</wtrans></div> <div class='int'><wform><grk id="w127435" cl='c24889' sn='G3614' morph='N-ASF' class="c24889 G3614" onclick="luW(10,'127435','24889','3614','N-ASF')" onmouseover="hl1('127435','24889','3614')" onmouseout="hl0('127435','24889','3614')" ondblclick="searchWord(2,127435)">οἰκίαν</grk></wform><br><wsbl>oikian</wsbl><br><wphono>iykiyan</wphono><br><ref onclick="lex('G3614')" ondblclick="searchLexicalEntry('G3614')"><wlex><grk>οἰκία</grk></wlex></ref><br><ref onclick="rmac('N-ASF')"><wmorph>N-ASF</wmorph></ref><br><ref onclick="lex('G3614')" ondblclick="searchLexicalEntry('G3614')"><wsn>G3614</wsn></ref><br><wgloss>house</wgloss><br><wtrans>[the] house,</wtrans></div> <div class='int'><wform><grk id="w127436" cl='c24890' sn='G2532' morph='CONJ' class="c24890 G2532" onclick="luW(10,'127436','24890','2532','CONJ')" onmouseover="hl1('127436','24890','2532')" onmouseout="hl0('127436','24890','2532')" ondblclick="searchWord(2,127436)">καὶ</grk></wform><br><wsbl>kai</wsbl><br><wphono>ke</wphono><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wlex><grk>καί</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wsn>G2532</wsn></ref><br><wgloss>and</wgloss><br><wtrans>and</wtrans></div> <div class='int'><wform><grk id="w127437" cl='c24890' sn='G5463' morph='V-PAN' class="c24890 G5463" onclick="luW(10,'127437','24890','5463','V-PAN')" onmouseover="hl1('127437','24890','5463')" onmouseout="hl0('127437','24890','5463')" ondblclick="searchWord(2,127437)">χαίρειν</grk></wform><br><wsbl>chairein</wsbl><br><wphono>kheriyn</wphono><br><ref onclick="lex('G5463')" ondblclick="searchLexicalEntry('G5463')"><wlex><grk>χαίρω</grk></wlex></ref><br><ref onclick="rmac('V-PAN')"><wmorph>V-PAN</wmorph></ref><br><ref onclick="lex('G5463')" ondblclick="searchLexicalEntry('G5463')"><wsn>G5463</wsn></ref><br><wgloss>to rejoice</wgloss><br><wtrans>to rejoice</wtrans></div> <div class='int'><wform><grk id="w127438" cl='c24890' sn='G846' morph='P-DSM' class="c24890 G846" onclick="luW(10,'127438','24890','846','P-DSM')" onmouseover="hl1('127438','24890','846')" onmouseout="hl0('127438','24890','846')" ondblclick="searchWord(2,127438)">αὐτῷ</grk></wform><br><wsbl>autō</wsbl><br><wphono>afto</wphono><br><ref onclick="lex('G846')" ondblclick="searchLexicalEntry('G846')"><wlex><grk>αὐτός</grk></wlex></ref><br><ref onclick="rmac('P-DSM')"><wmorph>P-DSM</wmorph></ref><br><ref onclick="lex('G846')" ondblclick="searchLexicalEntry('G846')"><wsn>G846</wsn></ref><br><wgloss>he/she/it/self</wgloss><br><wtrans>him</wtrans></div> <div class='int'><wform><grk id="w127439" cl='c24890' sn='G3361' morph='PRT-N' class="c24890 G3361" onclick="luW(10,'127439','24890','3361','PRT-N')" onmouseover="hl1('127439','24890','3361')" onmouseout="hl0('127439','24890','3361')" ondblclick="searchWord(2,127439)">μὴ</grk></wform><br><wsbl>mē</wsbl><br><wphono>miy</wphono><br><ref onclick="lex('G3361')" ondblclick="searchLexicalEntry('G3361')"><wlex><grk>μή</grk></wlex></ref><br><ref onclick="rmac('PRT-N')"><wmorph>PRT-N</wmorph></ref><br><ref onclick="lex('G3361')" ondblclick="searchLexicalEntry('G3361')"><wsn>G3361</wsn></ref><br><wgloss>not</wgloss><br><wtrans>not</wtrans></div> <div class='int'><wform><grk id="w127440" cl='c24890' sn='G3004' morph='V-PAM-2P' class="c24890 G3004" onclick="luW(10,'127440','24890','3004','V-PAM-2P')" onmouseover="hl1('127440','24890','3004')" onmouseout="hl0('127440','24890','3004')" ondblclick="searchWord(2,127440)">λέγετε</grk></wform><br><wsbl>legete</wsbl><br><wphono>leyete</wphono><br><ref onclick="lex('G3004')" ondblclick="searchLexicalEntry('G3004')"><wlex><grk>λέγω</grk></wlex></ref><br><ref onclick="rmac('V-PAM-2P')"><wmorph>V-PAM-2P</wmorph></ref><br><ref onclick="lex('G3004')" ondblclick="searchLexicalEntry('G3004')"><wsn>G3004</wsn></ref><br><wgloss>to speak</wgloss><br><wtrans>tell;</wtrans></div><br></verse> <verse><vid id="v63.1.11" onclick="luV(11)">11</vid> <br><div class='int'><wform><grk id="w127441" cl='c24891' sn='G3588' morph='T-NSM' class="c24891 G3588" onclick="luW(11,'127441','24891','3588','T-NSM')" onmouseover="hl1('127441','24891','3588')" onmouseout="hl0('127441','24891','3588')" ondblclick="searchWord(2,127441)">ὁ</grk></wform><br><wsbl>ho</wsbl><br><wphono>o</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-NSM')"><wmorph>T-NSM</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the [one]</wtrans></div> <div class='int'><wform><grk id="w127442" cl='c24891' sn='G3004' morph='V-PAP-NSM' class="c24891 G3004" onclick="luW(11,'127442','24891','3004','V-PAP-NSM')" onmouseover="hl1('127442','24891','3004')" onmouseout="hl0('127442','24891','3004')" ondblclick="searchWord(2,127442)">λέγων</grk></wform><br><wsbl>legōn</wsbl><br><wphono>legon</wphono><br><ref onclick="lex('G3004')" ondblclick="searchLexicalEntry('G3004')"><wlex><grk>λέγω</grk></wlex></ref><br><ref onclick="rmac('V-PAP-NSM')"><wmorph>V-PAP-NSM</wmorph></ref><br><ref onclick="lex('G3004')" ondblclick="searchLexicalEntry('G3004')"><wsn>G3004</wsn></ref><br><wgloss>to speak</wgloss><br><wtrans>telling</wtrans></div> <div class='int'><wform><grk id="w127443" cl='c24891' sn='G1063' morph='CONJ' class="c24891 G1063" onclick="luW(11,'127443','24891','1063','CONJ')" onmouseover="hl1('127443','24891','1063')" onmouseout="hl0('127443','24891','1063')" ondblclick="searchWord(2,127443)">γὰρ</grk></wform><br><wsbl>gar</wsbl><br><wphono>gar</wphono><br><ref onclick="lex('G1063')" ondblclick="searchLexicalEntry('G1063')"><wlex><grk>γάρ</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G1063')" ondblclick="searchLexicalEntry('G1063')"><wsn>G1063</wsn></ref><br><wgloss>for</wgloss><br><wtrans>for</wtrans></div> <div class='int'><wform><grk id="w127444" cl='c24891' sn='G846' morph='P-DSM' class="c24891 G846" onclick="luW(11,'127444','24891','846','P-DSM')" onmouseover="hl1('127444','24891','846')" onmouseout="hl0('127444','24891','846')" ondblclick="searchWord(2,127444)">αὐτῷ</grk></wform><br><wsbl>autō</wsbl><br><wphono>afto</wphono><br><ref onclick="lex('G846')" ondblclick="searchLexicalEntry('G846')"><wlex><grk>αὐτός</grk></wlex></ref><br><ref onclick="rmac('P-DSM')"><wmorph>P-DSM</wmorph></ref><br><ref onclick="lex('G846')" ondblclick="searchLexicalEntry('G846')"><wsn>G846</wsn></ref><br><wgloss>he/she/it/self</wgloss><br><wtrans>him</wtrans></div> <div class='int'><wform><grk id="w127445" cl='c24891' sn='G5463' morph='V-PAN' class="c24891 G5463" onclick="luW(11,'127445','24891','5463','V-PAN')" onmouseover="hl1('127445','24891','5463')" onmouseout="hl0('127445','24891','5463')" ondblclick="searchWord(2,127445)">χαίρειν</grk></wform><br><wsbl>chairein</wsbl><br><wphono>kheriyn</wphono><br><ref onclick="lex('G5463')" ondblclick="searchLexicalEntry('G5463')"><wlex><grk>χαίρω</grk></wlex></ref><br><ref onclick="rmac('V-PAN')"><wmorph>V-PAN</wmorph></ref><br><ref onclick="lex('G5463')" ondblclick="searchLexicalEntry('G5463')"><wsn>G5463</wsn></ref><br><wgloss>to rejoice</wgloss><br><wtrans>to rejoice</wtrans></div> <div class='int'><wform><grk id="w127446" cl='c24892' sn='G2841' morph='V-PAI-3S' class="c24892 G2841" onclick="luW(11,'127446','24892','2841','V-PAI-3S')" onmouseover="hl1('127446','24892','2841')" onmouseout="hl0('127446','24892','2841')" ondblclick="searchWord(2,127446)">κοινωνεῖ</grk></wform><br><wsbl>koinōnei</wsbl><br><wphono>kiynoniy</wphono><br><ref onclick="lex('G2841')" ondblclick="searchLexicalEntry('G2841')"><wlex><grk>κοινωνέω</grk></wlex></ref><br><ref onclick="rmac('V-PAI-3S')"><wmorph>V-PAI-3S</wmorph></ref><br><ref onclick="lex('G2841')" ondblclick="searchLexicalEntry('G2841')"><wsn>G2841</wsn></ref><br><wgloss>to participate</wgloss><br><wtrans>partakes</wtrans></div> <div class='int'><wform><grk id="w127447" cl='c24892' sn='G3588' morph='T-DPN' class="c24892 G3588" onclick="luW(11,'127447','24892','3588','T-DPN')" onmouseover="hl1('127447','24892','3588')" onmouseout="hl0('127447','24892','3588')" ondblclick="searchWord(2,127447)">τοῖς</grk></wform><br><wsbl>tois</wsbl><br><wphono>tiys</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-DPN')"><wmorph>T-DPN</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>in the</wtrans></div> <div class='int'><wform><grk id="w127448" cl='c24892' sn='G2041' morph='N-DPN' class="c24892 G2041" onclick="luW(11,'127448','24892','2041','N-DPN')" onmouseover="hl1('127448','24892','2041')" onmouseout="hl0('127448','24892','2041')" ondblclick="searchWord(2,127448)">ἔργοις</grk></wform><br><wsbl>ergois</wsbl><br><wphono>eryiys</wphono><br><ref onclick="lex('G2041')" ondblclick="searchLexicalEntry('G2041')"><wlex><grk>ἔργον</grk></wlex></ref><br><ref onclick="rmac('N-DPN')"><wmorph>N-DPN</wmorph></ref><br><ref onclick="lex('G2041')" ondblclick="searchLexicalEntry('G2041')"><wsn>G2041</wsn></ref><br><wgloss>work</wgloss><br><wtrans>works</wtrans></div> <div class='int'><wform><grk id="w127449" cl='c24892' sn='G846' morph='P-GSM' class="c24892 G846" onclick="luW(11,'127449','24892','846','P-GSM')" onmouseover="hl1('127449','24892','846')" onmouseout="hl0('127449','24892','846')" ondblclick="searchWord(2,127449)">αὐτοῦ</grk></wform><br><wsbl>autou</wsbl><br><wphono>aftu</wphono><br><ref onclick="lex('G846')" ondblclick="searchLexicalEntry('G846')"><wlex><grk>αὐτός</grk></wlex></ref><br><ref onclick="rmac('P-GSM')"><wmorph>P-GSM</wmorph></ref><br><ref onclick="lex('G846')" ondblclick="searchLexicalEntry('G846')"><wsn>G846</wsn></ref><br><wgloss>he/she/it/self</wgloss><br><wtrans>of him</wtrans></div> <div class='int'><wform><grk id="w127450" cl='c24892' sn='G3588' morph='T-DPN' class="c24892 G3588" onclick="luW(11,'127450','24892','3588','T-DPN')" onmouseover="hl1('127450','24892','3588')" onmouseout="hl0('127450','24892','3588')" ondblclick="searchWord(2,127450)">τοῖς</grk></wform><br><wsbl>tois</wsbl><br><wphono>tiys</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-DPN')"><wmorph>T-DPN</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>-</wtrans></div> <div class='int'><wform><grk id="w127451" cl='c24892' sn='G4190' morph='A-DPN' class="c24892 G4190" onclick="luW(11,'127451','24892','4190','A-DPN')" onmouseover="hl1('127451','24892','4190')" onmouseout="hl0('127451','24892','4190')" ondblclick="searchWord(2,127451)">πονηροῖς</grk></wform><br><wsbl>ponērois</wsbl><br><wphono>poniyriys</wphono><br><ref onclick="lex('G4190')" ondblclick="searchLexicalEntry('G4190')"><wlex><grk>πονηρός</grk></wlex></ref><br><ref onclick="rmac('A-DPN')"><wmorph>A-DPN</wmorph></ref><br><ref onclick="lex('G4190')" ondblclick="searchLexicalEntry('G4190')"><wsn>G4190</wsn></ref><br><wgloss>evil/bad</wgloss><br><wtrans>evil.</wtrans></div><br></verse> <verse><vid id="v63.1.12" onclick="luV(12)">12</vid> <br><div class='int'><wform><grk id="w127452" cl='c24893' sn='G4183' morph='A-APN' class="c24893 G4183" onclick="luW(12,'127452','24893','4183','A-APN')" onmouseover="hl1('127452','24893','4183')" onmouseout="hl0('127452','24893','4183')" ondblclick="searchWord(2,127452)">Πολλὰ</grk></wform><br><wsbl>Polla</wsbl><br><wphono>polla</wphono><br><ref onclick="lex('G4183')" ondblclick="searchLexicalEntry('G4183')"><wlex><grk>πολύς</grk></wlex></ref><br><ref onclick="rmac('A-APN')"><wmorph>A-APN</wmorph></ref><br><ref onclick="lex('G4183')" ondblclick="searchLexicalEntry('G4183')"><wsn>G4183</wsn></ref><br><wgloss>much</wgloss><br><wtrans>Many things</wtrans></div> <div class='int'><wform><grk id="w127453" cl='c24893' sn='G2192' morph='V-PAP-NSM' class="c24893 G2192" onclick="luW(12,'127453','24893','2192','V-PAP-NSM')" onmouseover="hl1('127453','24893','2192')" onmouseout="hl0('127453','24893','2192')" ondblclick="searchWord(2,127453)">ἔχων</grk></wform><br><wsbl>echōn</wsbl><br><wphono>ekhon</wphono><br><ref onclick="lex('G2192')" ondblclick="searchLexicalEntry('G2192')"><wlex><grk>ἔχω</grk></wlex></ref><br><ref onclick="rmac('V-PAP-NSM')"><wmorph>V-PAP-NSM</wmorph></ref><br><ref onclick="lex('G2192')" ondblclick="searchLexicalEntry('G2192')"><wsn>G2192</wsn></ref><br><wgloss>to have/be</wgloss><br><wtrans>having</wtrans></div> <div class='int'><wform><grk id="w127454" cl='c24894' sn='G4771' morph='P-2DP' class="c24894 G4771" onclick="luW(12,'127454','24894','4771','P-2DP')" onmouseover="hl1('127454','24894','4771')" onmouseout="hl0('127454','24894','4771')" ondblclick="searchWord(2,127454)">ὑμῖν</grk></wform><br><wsbl>hymin</wsbl><br><wphono>iymiyn</wphono><br><ref onclick="lex('G4771')" ondblclick="searchLexicalEntry('G4771')"><wlex><grk>σύ</grk></wlex></ref><br><ref onclick="rmac('P-2DP')"><wmorph>P-2DP</wmorph></ref><br><ref onclick="lex('G4771')" ondblclick="searchLexicalEntry('G4771')"><wsn>G4771</wsn></ref><br><wgloss>you</wgloss><br><wtrans>to you</wtrans></div> <div class='int'><wform><grk id="w127455" cl='c24894' sn='G1125' morph='V-PAN' class="c24894 G1125" onclick="luW(12,'127455','24894','1125','V-PAN')" onmouseover="hl1('127455','24894','1125')" onmouseout="hl0('127455','24894','1125')" ondblclick="searchWord(2,127455)">γράφειν</grk></wform><br><wsbl>graphein</wsbl><br><wphono>grafiyn</wphono><br><ref onclick="lex('G1125')" ondblclick="searchLexicalEntry('G1125')"><wlex><grk>γράφω</grk></wlex></ref><br><ref onclick="rmac('V-PAN')"><wmorph>V-PAN</wmorph></ref><br><ref onclick="lex('G1125')" ondblclick="searchLexicalEntry('G1125')"><wsn>G1125</wsn></ref><br><wgloss>to write</wgloss><br><wtrans>to write,</wtrans></div> <div class='int'><wform><grk id="w127456" cl='c24895' sn='G3756' morph='PRT-N' class="c24895 G3756" onclick="luW(12,'127456','24895','3756','PRT-N')" onmouseover="hl1('127456','24895','3756')" onmouseout="hl0('127456','24895','3756')" ondblclick="searchWord(2,127456)">οὐκ</grk></wform><br><wsbl>ouk</wsbl><br><wphono>uk</wphono><br><ref onclick="lex('G3756')" ondblclick="searchLexicalEntry('G3756')"><wlex><grk>οὐ</grk></wlex></ref><br><ref onclick="rmac('PRT-N')"><wmorph>PRT-N</wmorph></ref><br><ref onclick="lex('G3756')" ondblclick="searchLexicalEntry('G3756')"><wsn>G3756</wsn></ref><br><wgloss>no</wgloss><br><wtrans>not</wtrans></div> <div class='int'><wform><grk id="w127457" cl='c24895' sn='G1014' morph='V-AOI-1S' class="c24895 G1014" onclick="luW(12,'127457','24895','1014','V-AOI-1S')" onmouseover="hl1('127457','24895','1014')" onmouseout="hl0('127457','24895','1014')" ondblclick="searchWord(2,127457)">ἐβουλήθην</grk></wform><br><wsbl>eboulēthēn</wsbl><br><wphono>evuliyθiyn</wphono><br><ref onclick="lex('G1014')" ondblclick="searchLexicalEntry('G1014')"><wlex><grk>βούλομαι</grk></wlex></ref><br><ref onclick="rmac('V-AOI-1S')"><wmorph>V-AOI-1S</wmorph></ref><br><ref onclick="lex('G1014')" ondblclick="searchLexicalEntry('G1014')"><wsn>G1014</wsn></ref><br><wgloss>to plan</wgloss><br><wtrans>I purposed</wtrans></div> <div class='int'><wform><grk id="w127458" cl='c24895' sn='G1223' morph='PREP' class="c24895 G1223" onclick="luW(12,'127458','24895','1223','PREP')" onmouseover="hl1('127458','24895','1223')" onmouseout="hl0('127458','24895','1223')" ondblclick="searchWord(2,127458)">διὰ</grk></wform><br><wsbl>dia</wsbl><br><wphono>ðiya</wphono><br><ref onclick="lex('G1223')" ondblclick="searchLexicalEntry('G1223')"><wlex><grk>διά</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G1223')" ondblclick="searchLexicalEntry('G1223')"><wsn>G1223</wsn></ref><br><wgloss>through/because of</wgloss><br><wtrans>with</wtrans></div> <div class='int'><wform><grk id="w127459" cl='c24895' sn='G5489' morph='N-GSM' class="c24895 G5489" onclick="luW(12,'127459','24895','5489','N-GSM')" onmouseover="hl1('127459','24895','5489')" onmouseout="hl0('127459','24895','5489')" ondblclick="searchWord(2,127459)">χάρτου</grk></wform><br><wsbl>chartou</wsbl><br><wphono>khartu</wphono><br><ref onclick="lex('G5489')" ondblclick="searchLexicalEntry('G5489')"><wlex><grk>χάρτης</grk></wlex></ref><br><ref onclick="rmac('N-GSM')"><wmorph>N-GSM</wmorph></ref><br><ref onclick="lex('G5489')" ondblclick="searchLexicalEntry('G5489')"><wsn>G5489</wsn></ref><br><wgloss>paper</wgloss><br><wtrans>paper</wtrans></div> <div class='int'><wform><grk id="w127460" cl='c24895' sn='G2532' morph='CONJ' class="c24895 G2532" onclick="luW(12,'127460','24895','2532','CONJ')" onmouseover="hl1('127460','24895','2532')" onmouseout="hl0('127460','24895','2532')" ondblclick="searchWord(2,127460)">καὶ</grk></wform><br><wsbl>kai</wsbl><br><wphono>ke</wphono><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wlex><grk>καί</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wsn>G2532</wsn></ref><br><wgloss>and</wgloss><br><wtrans>and</wtrans></div> <div class='int'><wform><grk id="w127461" cl='c24895' sn='G3188' morph='N-GSN' class="c24895 G3188" onclick="luW(12,'127461','24895','3188','N-GSN')" onmouseover="hl1('127461','24895','3188')" onmouseout="hl0('127461','24895','3188')" ondblclick="searchWord(2,127461)">μέλανος</grk></wform><br><wsbl>melanos</wsbl><br><wphono>melanos</wphono><br><ref onclick="lex('G3188')" ondblclick="searchLexicalEntry('G3188')"><wlex><grk>μέλαν</grk></wlex></ref><br><ref onclick="rmac('N-GSN')"><wmorph>N-GSN</wmorph></ref><br><ref onclick="lex('G3188')" ondblclick="searchLexicalEntry('G3188')"><wsn>G3188</wsn></ref><br><wgloss>ink</wgloss><br><wtrans>ink;</wtrans></div> <div class='int'><wform><grk id="w127462" cl='c24896' sn='G235' morph='CONJ' class="c24896 G235" onclick="luW(12,'127462','24896','235','CONJ')" onmouseover="hl1('127462','24896','235')" onmouseout="hl0('127462','24896','235')" ondblclick="searchWord(2,127462)">ἀλλὰ</grk></wform><br><wsbl>alla</wsbl><br><wphono>alla</wphono><br><ref onclick="lex('G235')" ondblclick="searchLexicalEntry('G235')"><wlex><grk>ἀλλά</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G235')" ondblclick="searchLexicalEntry('G235')"><wsn>G235</wsn></ref><br><wgloss>but</wgloss><br><wtrans>but</wtrans></div> <div class='int'><wform><grk id="w127463" cl='c24896' sn='G1679' morph='V-PAI-1S' class="c24896 G1679" onclick="luW(12,'127463','24896','1679','V-PAI-1S')" onmouseover="hl1('127463','24896','1679')" onmouseout="hl0('127463','24896','1679')" ondblclick="searchWord(2,127463)">ἐλπίζω</grk></wform><br><wsbl>elpizō</wsbl><br><wphono>elpiyzo</wphono><br><ref onclick="lex('G1679')" ondblclick="searchLexicalEntry('G1679')"><wlex><grk>ἐλπίζω</grk></wlex></ref><br><ref onclick="rmac('V-PAI-1S')"><wmorph>V-PAI-1S</wmorph></ref><br><ref onclick="lex('G1679')" ondblclick="searchLexicalEntry('G1679')"><wsn>G1679</wsn></ref><br><wgloss>to hope/expect</wgloss><br><wtrans>I hope</wtrans></div> <div class='int'><wform><grk id="w127464" cl='c24896' sn='G1096' morph='V-2ADN' class="c24896 G1096" onclick="luW(12,'127464','24896','1096','V-2ADN')" onmouseover="hl1('127464','24896','1096')" onmouseout="hl0('127464','24896','1096')" ondblclick="searchWord(2,127464)">γενέσθαι</grk></wform><br><wsbl>genesthai</wsbl><br><wphono>yenesθe</wphono><br><ref onclick="lex('G1096')" ondblclick="searchLexicalEntry('G1096')"><wlex><grk>γίνομαι</grk></wlex></ref><br><ref onclick="rmac('V-2ADN')"><wmorph>V-2ADN</wmorph></ref><br><ref onclick="lex('G1096')" ondblclick="searchLexicalEntry('G1096')"><wsn>G1096</wsn></ref><br><wgloss>to be</wgloss><br><wtrans>to come</wtrans></div> <div class='int'><wform><grk id="w127465" cl='c24896' sn='G4314' morph='PREP' class="c24896 G4314" onclick="luW(12,'127465','24896','4314','PREP')" onmouseover="hl1('127465','24896','4314')" onmouseout="hl0('127465','24896','4314')" ondblclick="searchWord(2,127465)">πρὸς</grk></wform><br><wsbl>pros</wsbl><br><wphono>pros</wphono><br><ref onclick="lex('G4314')" ondblclick="searchLexicalEntry('G4314')"><wlex><grk>πρός</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G4314')" ondblclick="searchLexicalEntry('G4314')"><wsn>G4314</wsn></ref><br><wgloss>to/with</wgloss><br><wtrans>to</wtrans></div> <div class='int'><wform><grk id="w127466" cl='c24896' sn='G4771' morph='P-2AP' class="c24896 G4771" onclick="luW(12,'127466','24896','4771','P-2AP')" onmouseover="hl1('127466','24896','4771')" onmouseout="hl0('127466','24896','4771')" ondblclick="searchWord(2,127466)">ὑμᾶς</grk></wform><br><wsbl>hymas</wsbl><br><wphono>iymas</wphono><br><ref onclick="lex('G4771')" ondblclick="searchLexicalEntry('G4771')"><wlex><grk>σύ</grk></wlex></ref><br><ref onclick="rmac('P-2AP')"><wmorph>P-2AP</wmorph></ref><br><ref onclick="lex('G4771')" ondblclick="searchLexicalEntry('G4771')"><wsn>G4771</wsn></ref><br><wgloss>you</wgloss><br><wtrans>you,</wtrans></div> <div class='int'><wform><grk id="w127467" cl='c24897' sn='G2532' morph='CONJ' class="c24897 G2532" onclick="luW(12,'127467','24897','2532','CONJ')" onmouseover="hl1('127467','24897','2532')" onmouseout="hl0('127467','24897','2532')" ondblclick="searchWord(2,127467)">καὶ</grk></wform><br><wsbl>kai</wsbl><br><wphono>ke</wphono><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wlex><grk>καί</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2532')" ondblclick="searchLexicalEntry('G2532')"><wsn>G2532</wsn></ref><br><wgloss>and</wgloss><br><wtrans>and</wtrans></div> <div class='int'><wform><grk id="w127468" cl='c24897' sn='G4750' morph='N-ASN' class="c24897 G4750" onclick="luW(12,'127468','24897','4750','N-ASN')" onmouseover="hl1('127468','24897','4750')" onmouseout="hl0('127468','24897','4750')" ondblclick="searchWord(2,127468)">στόμα</grk></wform><br><wsbl>stoma</wsbl><br><wphono>stoma</wphono><br><ref onclick="lex('G4750')" ondblclick="searchLexicalEntry('G4750')"><wlex><grk>στόμα</grk></wlex></ref><br><ref onclick="rmac('N-ASN')"><wmorph>N-ASN</wmorph></ref><br><ref onclick="lex('G4750')" ondblclick="searchLexicalEntry('G4750')"><wsn>G4750</wsn></ref><br><wgloss>mouth</wgloss><br><wtrans>mouth</wtrans></div> <div class='int'><wform><grk id="w127469" cl='c24897' sn='G4314' morph='PREP' class="c24897 G4314" onclick="luW(12,'127469','24897','4314','PREP')" onmouseover="hl1('127469','24897','4314')" onmouseout="hl0('127469','24897','4314')" ondblclick="searchWord(2,127469)">πρὸς</grk></wform><br><wsbl>pros</wsbl><br><wphono>pros</wphono><br><ref onclick="lex('G4314')" ondblclick="searchLexicalEntry('G4314')"><wlex><grk>πρός</grk></wlex></ref><br><ref onclick="rmac('PREP')"><wmorph>PREP</wmorph></ref><br><ref onclick="lex('G4314')" ondblclick="searchLexicalEntry('G4314')"><wsn>G4314</wsn></ref><br><wgloss>to/with</wgloss><br><wtrans>to</wtrans></div> <div class='int'><wform><grk id="w127470" cl='c24897' sn='G4750' morph='N-ASN' class="c24897 G4750" onclick="luW(12,'127470','24897','4750','N-ASN')" onmouseover="hl1('127470','24897','4750')" onmouseout="hl0('127470','24897','4750')" ondblclick="searchWord(2,127470)">στόμα</grk></wform><br><wsbl>stoma</wsbl><br><wphono>stoma</wphono><br><ref onclick="lex('G4750')" ondblclick="searchLexicalEntry('G4750')"><wlex><grk>στόμα</grk></wlex></ref><br><ref onclick="rmac('N-ASN')"><wmorph>N-ASN</wmorph></ref><br><ref onclick="lex('G4750')" ondblclick="searchLexicalEntry('G4750')"><wsn>G4750</wsn></ref><br><wgloss>mouth</wgloss><br><wtrans>mouth</wtrans></div> <div class='int'><wform><grk id="w127471" cl='c24897' sn='G2980' morph='V-AAN' class="c24897 G2980" onclick="luW(12,'127471','24897','2980','V-AAN')" onmouseover="hl1('127471','24897','2980')" onmouseout="hl0('127471','24897','2980')" ondblclick="searchWord(2,127471)">λαλῆσαι</grk></wform><br><wsbl>lalēsai</wsbl><br><wphono>laliyse</wphono><br><ref onclick="lex('G2980')" ondblclick="searchLexicalEntry('G2980')"><wlex><grk>λαλέω</grk></wlex></ref><br><ref onclick="rmac('V-AAN')"><wmorph>V-AAN</wmorph></ref><br><ref onclick="lex('G2980')" ondblclick="searchLexicalEntry('G2980')"><wsn>G2980</wsn></ref><br><wgloss>to speak</wgloss><br><wtrans>to speak,</wtrans></div> <div class='int'><wform><grk id="w127472" cl='c24898' sn='G2443' morph='CONJ' class="c24898 G2443" onclick="luW(12,'127472','24898','2443','CONJ')" onmouseover="hl1('127472','24898','2443')" onmouseout="hl0('127472','24898','2443')" ondblclick="searchWord(2,127472)">ἵνα</grk></wform><br><wsbl>hina</wsbl><br><wphono>iyna</wphono><br><ref onclick="lex('G2443')" ondblclick="searchLexicalEntry('G2443')"><wlex><grk>ἵνα</grk></wlex></ref><br><ref onclick="rmac('CONJ')"><wmorph>CONJ</wmorph></ref><br><ref onclick="lex('G2443')" ondblclick="searchLexicalEntry('G2443')"><wsn>G2443</wsn></ref><br><wgloss>in order that/to</wgloss><br><wtrans>so that</wtrans></div> <div class='int'><wform><grk id="w127473" cl='c24898' sn='G3588' morph='T-NSF' class="c24898 G3588" onclick="luW(12,'127473','24898','3588','T-NSF')" onmouseover="hl1('127473','24898','3588')" onmouseout="hl0('127473','24898','3588')" ondblclick="searchWord(2,127473)">ἡ</grk></wform><br><wsbl>hē</wsbl><br><wphono>iy</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-NSF')"><wmorph>T-NSF</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127474" cl='c24898' sn='G5479' morph='N-NSF' class="c24898 G5479" onclick="luW(12,'127474','24898','5479','N-NSF')" onmouseover="hl1('127474','24898','5479')" onmouseout="hl0('127474','24898','5479')" ondblclick="searchWord(2,127474)">χαρὰ</grk></wform><br><wsbl>chara</wsbl><br><wphono>khara</wphono><br><ref onclick="lex('G5479')" ondblclick="searchLexicalEntry('G5479')"><wlex><grk>χαρά</grk></wlex></ref><br><ref onclick="rmac('N-NSF')"><wmorph>N-NSF</wmorph></ref><br><ref onclick="lex('G5479')" ondblclick="searchLexicalEntry('G5479')"><wsn>G5479</wsn></ref><br><wgloss>joy</wgloss><br><wtrans>joy</wtrans></div> <div class='int'><wform><grk id="w127475" cl='c24898' sn='G1473' morph='P-1GP' class="c24898 G1473" onclick="luW(12,'127475','24898','1473','P-1GP')" onmouseover="hl1('127475','24898','1473')" onmouseout="hl0('127475','24898','1473')" ondblclick="searchWord(2,127475)">ἡμῶν</grk></wform><br><wsbl>hēmōn</wsbl><br><wphono>iymon</wphono><br><ref onclick="lex('G1473')" ondblclick="searchLexicalEntry('G1473')"><wlex><grk>ἐγώ</grk></wlex></ref><br><ref onclick="rmac('P-1GP')"><wmorph>P-1GP</wmorph></ref><br><ref onclick="lex('G1473')" ondblclick="searchLexicalEntry('G1473')"><wsn>G1473</wsn></ref><br><wgloss>I/we</wgloss><br><wtrans>of us</wtrans></div> <div class='int'><wform><grk id="w127476" cl='c24898' sn='G1510' morph='V-PAS-3S' class="c24898 G1510" onclick="luW(12,'127476','24898','1510','V-PAS-3S')" onmouseover="hl1('127476','24898','1510')" onmouseout="hl0('127476','24898','1510')" ondblclick="searchWord(2,127476)">ᾖ</grk></wform><br><wsbl>ē</wsbl><br><wphono>iy</wphono><br><ref onclick="lex('G1510')" ondblclick="searchLexicalEntry('G1510')"><wlex><grk>εἰμί</grk></wlex></ref><br><ref onclick="rmac('V-PAS-3S')"><wmorph>V-PAS-3S</wmorph></ref><br><ref onclick="lex('G1510')" ondblclick="searchLexicalEntry('G1510')"><wsn>G1510</wsn></ref><br><wgloss>to be</wgloss><br><wtrans>may be.</wtrans></div> <div class='int'><wform><grk id="w127477" cl='c24898' sn='G4137' morph='V-RPP-NSF' class="c24898 G4137" onclick="luW(12,'127477','24898','4137','V-RPP-NSF')" onmouseover="hl1('127477','24898','4137')" onmouseout="hl0('127477','24898','4137')" ondblclick="searchWord(2,127477)">πεπληρωμένη</grk></wform><br><wsbl>peplērōmenē</wsbl><br><wphono>pepliyromeniy</wphono><br><ref onclick="lex('G4137')" ondblclick="searchLexicalEntry('G4137')"><wlex><grk>πληρόω</grk></wlex></ref><br><ref onclick="rmac('V-RPP-NSF')"><wmorph>V-RPP-NSF</wmorph></ref><br><ref onclick="lex('G4137')" ondblclick="searchLexicalEntry('G4137')"><wsn>G4137</wsn></ref><br><wgloss>to fulfill</wgloss><br><wtrans>having been completed</wtrans></div><br></verse> <verse><vid id="v63.1.13" onclick="luV(13)">13</vid> <br><div class='int'><wform><grk id="w127478" cl='c24899' sn='G782' morph='V-PNI-3S' class="c24899 G782" onclick="luW(13,'127478','24899','782','V-PNI-3S')" onmouseover="hl1('127478','24899','782')" onmouseout="hl0('127478','24899','782')" ondblclick="searchWord(2,127478)">Ἀσπάζεταί</grk></wform><br><wsbl>Aspazetai</wsbl><br><wphono>aspazete</wphono><br><ref onclick="lex('G782')" ondblclick="searchLexicalEntry('G782')"><wlex><grk>ἀσπάζομαι</grk></wlex></ref><br><ref onclick="rmac('V-PNI-3S')"><wmorph>V-PNI-3S</wmorph></ref><br><ref onclick="lex('G782')" ondblclick="searchLexicalEntry('G782')"><wsn>G782</wsn></ref><br><wgloss>to pay respects to</wgloss><br><wtrans>Greet</wtrans></div> <div class='int'><wform><grk id="w127479" cl='c24899' sn='G4771' morph='P-2AS' class="c24899 G4771" onclick="luW(13,'127479','24899','4771','P-2AS')" onmouseover="hl1('127479','24899','4771')" onmouseout="hl0('127479','24899','4771')" ondblclick="searchWord(2,127479)">σε</grk></wform><br><wsbl>se</wsbl><br><wphono>se</wphono><br><ref onclick="lex('G4771')" ondblclick="searchLexicalEntry('G4771')"><wlex><grk>σύ</grk></wlex></ref><br><ref onclick="rmac('P-2AS')"><wmorph>P-2AS</wmorph></ref><br><ref onclick="lex('G4771')" ondblclick="searchLexicalEntry('G4771')"><wsn>G4771</wsn></ref><br><wgloss>you</wgloss><br><wtrans>you,</wtrans></div> <div class='int'><wform><grk id="w127480" cl='c24899' sn='G3588' morph='T-NPN' class="c24899 G3588" onclick="luW(13,'127480','24899','3588','T-NPN')" onmouseover="hl1('127480','24899','3588')" onmouseout="hl0('127480','24899','3588')" ondblclick="searchWord(2,127480)">τὰ</grk></wform><br><wsbl>ta</wsbl><br><wphono>ta</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-NPN')"><wmorph>T-NPN</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>the</wtrans></div> <div class='int'><wform><grk id="w127481" cl='c24899' sn='G5043' morph='N-NPN' class="c24899 G5043" onclick="luW(13,'127481','24899','5043','N-NPN')" onmouseover="hl1('127481','24899','5043')" onmouseout="hl0('127481','24899','5043')" ondblclick="searchWord(2,127481)">τέκνα</grk></wform><br><wsbl>tekna</wsbl><br><wphono>tekna</wphono><br><ref onclick="lex('G5043')" ondblclick="searchLexicalEntry('G5043')"><wlex><grk>τέκνον</grk></wlex></ref><br><ref onclick="rmac('N-NPN')"><wmorph>N-NPN</wmorph></ref><br><ref onclick="lex('G5043')" ondblclick="searchLexicalEntry('G5043')"><wsn>G5043</wsn></ref><br><wgloss>child</wgloss><br><wtrans>children</wtrans></div> <div class='int'><wform><grk id="w127482" cl='c24899' sn='G3588' morph='T-GSF' class="c24899 G3588" onclick="luW(13,'127482','24899','3588','T-GSF')" onmouseover="hl1('127482','24899','3588')" onmouseout="hl0('127482','24899','3588')" ondblclick="searchWord(2,127482)">τῆς</grk></wform><br><wsbl>tēs</wsbl><br><wphono>tiys</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-GSF')"><wmorph>T-GSF</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>of the</wtrans></div> <div class='int'><wform><grk id="w127483" cl='c24899' sn='G79' morph='N-GSF' class="c24899 G79" onclick="luW(13,'127483','24899','79','N-GSF')" onmouseover="hl1('127483','24899','79')" onmouseout="hl0('127483','24899','79')" ondblclick="searchWord(2,127483)">ἀδελφῆς</grk></wform><br><wsbl>adelphēs</wsbl><br><wphono>aðelfiys</wphono><br><ref onclick="lex('G79')" ondblclick="searchLexicalEntry('G79')"><wlex><grk>ἀδελφή</grk></wlex></ref><br><ref onclick="rmac('N-GSF')"><wmorph>N-GSF</wmorph></ref><br><ref onclick="lex('G79')" ondblclick="searchLexicalEntry('G79')"><wsn>G79</wsn></ref><br><wgloss>sister</wgloss><br><wtrans>sister</wtrans></div> <div class='int'><wform><grk id="w127484" cl='c24899' sn='G4771' morph='P-2GS' class="c24899 G4771" onclick="luW(13,'127484','24899','4771','P-2GS')" onmouseover="hl1('127484','24899','4771')" onmouseout="hl0('127484','24899','4771')" ondblclick="searchWord(2,127484)">σου</grk></wform><br><wsbl>sou</wsbl><br><wphono>su</wphono><br><ref onclick="lex('G4771')" ondblclick="searchLexicalEntry('G4771')"><wlex><grk>σύ</grk></wlex></ref><br><ref onclick="rmac('P-2GS')"><wmorph>P-2GS</wmorph></ref><br><ref onclick="lex('G4771')" ondblclick="searchLexicalEntry('G4771')"><wsn>G4771</wsn></ref><br><wgloss>you</wgloss><br><wtrans>of you</wtrans></div> <div class='int'><wform><grk id="w127485" cl='c24899' sn='G3588' morph='T-GSF' class="c24899 G3588" onclick="luW(13,'127485','24899','3588','T-GSF')" onmouseover="hl1('127485','24899','3588')" onmouseout="hl0('127485','24899','3588')" ondblclick="searchWord(2,127485)">τῆς</grk></wform><br><wsbl>tēs</wsbl><br><wphono>tiys</wphono><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wlex><grk>ὁ</grk></wlex></ref><br><ref onclick="rmac('T-GSF')"><wmorph>T-GSF</wmorph></ref><br><ref onclick="lex('G3588')" ondblclick="searchLexicalEntry('G3588')"><wsn>G3588</wsn></ref><br><wgloss>the/this/who</wgloss><br><wtrans>-</wtrans></div> <div class='int'><wform><grk id="w127486" cl='c24899' sn='G1588' morph='A-GSF' class="c24899 G1588" onclick="luW(13,'127486','24899','1588','A-GSF')" onmouseover="hl1('127486','24899','1588')" onmouseout="hl0('127486','24899','1588')" ondblclick="searchWord(2,127486)">ἐκλεκτῆς</grk></wform><br><wsbl>eklektēs</wsbl><br><wphono>eklektiys</wphono><br><ref onclick="lex('G1588')" ondblclick="searchLexicalEntry('G1588')"><wlex><grk>ἐκλεκτός</grk></wlex></ref><br><ref onclick="rmac('A-GSF')"><wmorph>A-GSF</wmorph></ref><br><ref onclick="lex('G1588')" ondblclick="searchLexicalEntry('G1588')"><wsn>G1588</wsn></ref><br><wgloss>select</wgloss><br><wtrans>elect.</wtrans></div><br></verse>"""

    content = greek_content

    # Fix known issues
    content = content.replace("<br<", "<br><")

    # convert verse link, like '<vid id="v19.117.1" onclick="luV(1)">'
    content = re.sub(r'<vid id="v([0-9]+?)\.([0-9]+?)\.([0-9]+?)" onclick="luV\(([0-9]+?)\)">', r'<vid id="v\1.\2.\3" onclick="luV(\1, \2, \3)">', content)
    
    # Convert onclick and ondblclick links
    content = re.sub(r'''(onclick|ondblclick)="(luV|luW|lex|bdbid|etcbcmorph|rmac|searchLexicalEntry|searchWord)\((.*?)\)"''', r'''\1="emitEvent('\2', [\3]); return false;"''', content)
    content = re.sub(r"""(onclick|ondblclick)='(luV|luW|lex|bdbid|etcbcmorph|rmac|searchLexicalEntry|searchWord)\((.*?)\)'""", r"""\1='emitEvent("\2", [\3]); return false;'""", content)

    # Inject CSS to handle the custom tags and layout
    if "</heb>" in content:
        ui.add_head_html("""
        <style>
            /* Main container for the Bible text - ensures RTL flow for verses */
            .bible-text {
                direction: rtl;
                font-family: sans-serif;
                padding: 20px;
                background-color: #fafafa;
            }
            /* Verse ID Number */
            vid {
                color: navy;
                font-weight: bold;
                font-size: 0.9rem;
                margin-left: 10px; /* appears on the right due to RTL */
                cursor: pointer;
            }
            /* Hebrew Word Layer */
            wform, heb, bdbheb, bdbarc, hu {
                font-family: 'SBL Hebrew', 'Ezra SIL', serif;
                font-size: 1.6rem;
                color: #2c3e50;
                direction: rtl;
                display: inline-block;
                line-height: 1.2em;
                margin-top: 0;
                margin-bottom: -2px;
                cursor: pointer;
            }
            /* Lexical Form & Strong's Number Layers */
            wlex {
                display: block;
                font-family: 'SBL Hebrew', serif;
                font-size: 1rem;
                color: #555;
                cursor: pointer;
            }
        </style>
        """)
    else:
        ui.add_head_html("""
        <style>
            /* Main container for the Bible text - LTR flow for Greek */
            .bible-text {
                direction: ltr;
                font-family: sans-serif;
                padding: 20px;
                background-color: #fafafa;
            }
            /* Verse ID Number */
            vid {
                color: navy;
                font-weight: bold;
                font-size: 0.9rem;
                margin-right: 10px;
                cursor: pointer;
            }
            /* Greek Word Layer (targets <grk> tag) */
            wform, grk, kgrk, gu {
                font-family: 'SBL Greek', 'Galatia SIL', 'Times New Roman', serif; /* CHANGED */
                font-size: 1.6rem;
                color: #2c3e50;
                direction: ltr;
                display: inline-block;
                line-height: 1.2em;
                margin-top: 0;
                margin-bottom: -2px;
                cursor: pointer;
            }
            /* Lexical Form (lemma) & Strong's Number Layers */
            wlex {
                display: block;
                font-family: 'SBL Greek', 'Galatia SIL', 'Times New Roman', serif; /* CHANGED */
                font-size: 1rem;
                color: #555;
                cursor: pointer;
            }
        </style>
        """)
    ui.add_head_html(ORIGINAL_CSS)

    # Header
    chapter_title = "Psalm 117" if "</heb>" in content else "2 John" # For testing only
    ui.label(f'Original Interlinear Bible (OIB) - {chapter_title}').classes('text-2xl font-bold q-mb-md text-center w-full')

    # Render the HTML inside a styled container
    # REMEMBER: sanitize=False is required to keep your onclick/onmouseover attributes
    ui.html(f'<div class="bible-text">{content}</div>', sanitize=False).classes(f'w-full pb-[60vh] {(tab1+"_chapter") if area == 1 else (tab2+"_chapter")}')

    # After the page is built and ready, run our JavaScript
    if (not area == 1) and tab1 and tab2:
        ui.run_javascript(f"""
            {SYNC_JS}
            
            {get_sync_fx(tab1, tab2)}
        """)

    # scrolling, e.g.
    ui.run_javascript(f'scrollToVerse("v{b}.{c}.{v}")')